@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # Copyright Not Yet, see how much I trust you
 #
-#	openrpg-dev@lists.sourceforge.net
+#       openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,19 +22,19 @@
 # Author: Ric Soard
 # Maintainer:
 # Version:
-#   $Id: hackmaster.py,v 0.4 2003/08/12 
+#   $Id: hackmaster.py,v 0.4 2003/08/12
 #
 # Description: special die roller for HackMaster(C)(TM) RPG
 #               has penetration damage - .damage(bonus,honor)
 #               has attack - .attack(bonus, honor)
 #               has severity .severity(honor)
 #               has help - .help()
-#           
+#
 #
 import random
 from die import *
 
-__version__ = "$Id: hackmaster.py,v 1.2 2004/06/20 04:58:48 tdb30_ Exp $"
+__version__ = "$Id: hackmaster.py,v 1.8 2006/11/15 12:11:22 digitalxero Exp $"
 
 #hackmaster Class basically passes into functional classes
 class hackmaster(std):
@@ -49,10 +49,10 @@ class hackmaster(std):
 
     def help(self):
         return HMhelp(self)
-    
+
     def severity(self, honor):
         return HMSeverity(self, honor)
-    
+
 
 # HM Damage roller - rolles penetration as per the PHB - re-rolles on max die - 1, adds honor to the penetration rolls
 # and this appears to be invisible to the user ( if a 4 on a d4 is rolled a 3 will appear and be followed by another
@@ -73,15 +73,15 @@ class HMdamage(std):
         self.hon = hon
 
 # This function is called by default to display the die string to the chat window.
-# Our die string attempts to explain the results        
-    def __str__(self):        
+# Our die string attempts to explain the results
+    def __str__(self):
         myStr = "Damage "
         myStr += "[Damage Roll, Modifiers, Honor]: " + " [" + str(self.data[0])
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
         myStr += "] = (" + str(self.sum()) + ")"
-        
+
         return myStr
 
 # This function checks to see if we need to reroll for penetration
@@ -114,18 +114,18 @@ class HMattack(std):
         self.append(static_di(self.mod))
         #this is a static die that adds honor, we want high rolls so it's +1
         self.append(static_di(self.hon))
-        
+
 
     def check_crit(self):
         if self.data[0] == self.data[0].sides:
             self.crit = 1
         if self.data[0] == 1:
             self.fumble = 1
- 
+
 
     #this function is the out put to the chat window, it basicaly just displays the roll unless
     #it's a natural 20, or a natural 1
-    def __str__(self):        
+    def __str__(self):
         if self.crit > 0:
             myStr = "Critical Hit!!: "
         elif self.fumble > 0:
@@ -136,7 +136,7 @@ class HMattack(std):
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
-        myStr += "] = (" + str(self.sum()) + ")"        
+        myStr += "] = (" + str(self.sum()) + ")"
         return myStr
 
 class HMhelp(std):
@@ -145,27 +145,27 @@ class HMhelp(std):
         self.source = source
 
     def __str__(self):
-        myStr = " <br> .attack(Bonus, Honor): <br>"
-        myStr += " The attack roll rolles the dice and adds your bonus <br>" 
-        myStr += " and honor modifier and returns you final roll. <br>" 
-        myStr += " On a natural 20 the dieroller displays Critical Hit!! <br>"
-        myStr += " On a natural 1 the dieroller displays FUMBLE!! <br>"
-        myStr += " Example A 1st level fighter with +1 to hit and a +2 sword and High Honor <br>"
-        myStr += " would roll [1d20.attack(3,1)] <br>"
-        myStr += " .damage(Bonus, Honor): <br>"
-        myStr += " The damage roll rolls the dice and rerolls on a max roll for <br>"
-        myStr += " penetration damage, the penetration die is -1 and is rerolled on a max roll <br>"
-        myStr += " The roller returns the damage dice, monidifiers, and honor <br>"
-        myStr += " Example A magic-user uses a quaterstaff +1 with high honor, he would roll <br>"
-        myStr += " [1d6.damage(1,1)] <br>"
-        myStr += " .severity(honor): <br>"
-        myStr += " the severity is for critical hit resolution - the character rolls <br>"
-        myStr += " a d8 and adds honor bonus. the die is rerolled on natural 8 and natural 1 with a -1 modifier <br>"
-        myStr += " on an 8 the reroll is added on a 1 the reroll is subtracted <br>"
-        myStr += " Example [1d8.severity(1)] <br>"
-        myStr += " .help() : <br>"
-        myStr += " displays this message <br>"
-        
+        myStr = " <br /> .attack(Bonus, Honor): <br />"
+        myStr += " The attack roll rolles the dice and adds your bonus <br />"
+        myStr += " and honor modifier and returns you final roll. <br />"
+        myStr += " On a natural 20 the dieroller displays Critical Hit!! <br />"
+        myStr += " On a natural 1 the dieroller displays FUMBLE!! <br />"
+        myStr += " Example A 1st level fighter with +1 to hit and a +2 sword and High Honor <br />"
+        myStr += " would roll [1d20.attack(3,1)] <br />"
+        myStr += " .damage(Bonus, Honor): <br />"
+        myStr += " The damage roll rolls the dice and rerolls on a max roll for <br />"
+        myStr += " penetration damage, the penetration die is -1 and is rerolled on a max roll <br />"
+        myStr += " The roller returns the damage dice, monidifiers, and honor <br />"
+        myStr += " Example A magic-user uses a quaterstaff +1 with high honor, he would roll <br />"
+        myStr += " [1d6.damage(1,1)] <br />"
+        myStr += " .severity(honor): <br />"
+        myStr += " the severity is for critical hit resolution - the character rolls <br />"
+        myStr += " a d8 and adds honor bonus. the die is rerolled on natural 8 and natural 1 with a -1 modifier <br />"
+        myStr += " on an 8 the reroll is added on a 1 the reroll is subtracted <br />"
+        myStr += " Example [1d8.severity(1)] <br />"
+        myStr += " .help() : <br />"
+        myStr += " displays this message <br />"
+
         return myStr
 
 # the severity roll is for critical resolution. The die is rerolled and added
@@ -179,15 +179,15 @@ class HMSeverity(std):
         self.append(di(8))
         self.CheckReroll()
         self.append(static_di(self.hon))
-        
+
 
     def __str__(self):
-       myStr = "[Severity Dice, Honor]" + " [" + str(self.data[0])
-       for a in self.data[1:]:
+        myStr = "[Severity Dice, Honor]" + " [" + str(self.data[0])
+        for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
-       myStr += "] = (" + str(self.sum()) + ")"        
-       return myStr
+        myStr += "] = (" + str(self.sum()) + ")"
+        return myStr
 
     def CheckReroll(self):
         if self.data[0] == self.data[0].sides:
@@ -195,7 +195,7 @@ class HMSeverity(std):
         if self.data[0] == 1:
             self.crit_chain(0,-1)
 
-    #this function needes moved for severity      
+    #this function needes moved for severity
     def crit_chain(self,num,neg):
         result = int(random.uniform(1,self.data[num].sides+1))
         self.data[num].value += (((result - 1) * neg) + self.hon)
