@@ -34,7 +34,7 @@ from time import time, clock
 import random
 
 
-__version__ = "$Id: hero.py,v 1.9 2005/04/26 08:15:51 snowdog_ Exp $"
+__version__ = "$Id: hero.py,v 1.15 2006/11/04 21:24:19 digitalxero Exp $"
 
 # Hero stands for "Hero system" not 20 sided die :)
 
@@ -67,31 +67,31 @@ class herocv(std):
         std.__init__(self,source)
         self.cv = cv
         self.mod = mod
-        
- 
-    def __str__(self):        
+
+
+    def __str__(self):
         myStr = "[" + str(self.data[0])
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
-        myStr += "] = (" + str(self.sum()) + ")"      
-        
-        myStr += " with a CV of " + str(self.cv) 
-        myStr += " and a modifier of " + str(self.mod) 
+        myStr += "] = (" + str(self.sum()) + ")"
+
+        myStr += " with a CV of " + str(self.cv)
+        myStr += " and a modifier of " + str(self.mod)
         cvhit = 11 + self.cv - self.sum() + self.mod
-        myStr += " hits up to <b>DCV <font color='#ff0000'>" + str(cvhit) + "</font></b>"             
+        myStr += " hits up to <b>DCV <font color='#ff0000'>" + str(cvhit) + "</font></b>"
         return myStr
-    
+
 class herosk(std):
     def __init__(self,source=[],sk=11,mod=0):
         std.__init__(self,source)
         self.sk = sk
         self.mod = mod
-                
+
     def is_success(self):
         return (((self.sum()-self.mod) <= self.sk))
-         
-    def __str__(self):        
+
+    def __str__(self):
         myStr = "[" + str(self.data[0])
         for a in self.data[1:]:
             myStr += ","
@@ -103,36 +103,35 @@ class herosk(std):
             swapmod= -self.mod
         myStr += strAdd + str(swapmod)
         modSum = self.sum()-self.mod
-        myStr += " = (" + str(modSum) + ")"      
-        myStr += " vs " + str(self.sk) 
-        
-        if self.is_success(): 
+        myStr += " = (" + str(modSum) + ")"
+        myStr += " vs " + str(self.sk)
+
+        if self.is_success():
             myStr += " or less <font color='#ff0000'>Success!"
         else:
             myStr += " or less <font color='#ff0000'>Failure!"
 
         Diff = self.sk - modSum
         myStr += " by " + str(Diff) +" </font>"
-            
+
         return myStr
 
 class herok(std):
     def __init__(self,source=[],mod=0):
         std.__init__(self,source)
         self.mod = mod
-        self.gen = random.random()
-       
-    def __str__(self):        
+
+    def __str__(self):
         myStr = "[" + str(self.data[0])
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
-        myStr += "] = (<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>)"   
-        stunx = self.gen.randint(1,6)-1
+        myStr += "] = (<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>)"
+        stunx = random.randint(1,6)-1
         if stunx <= 1:
             stunx = 1
         myStr += " <b>Body</b> and a stunx of (" + str(stunx)
-        stunx=stunx + self.mod   
+        stunx = stunx + self.mod
         myStr += " + " + str(self.mod)
         stunsum = round(self.sum()) * stunx
         myStr += ") for a total of (<font color='#ff0000'><b>" + str(int(stunsum)) + "</b></font>) <b>Stun</b>"
@@ -142,18 +141,17 @@ class herohl(std):
     def __init__(self,source=[],mod=0):
         std.__init__(self,source)
         self.mod = mod
-        self.gen = random.random()
-       
-    def __str__(self):        
+
+    def __str__(self):
         myStr = "[" + str(self.data[0])
-        side = self.gen.randint(1,6)
+        side = random.randint(1,6)
         sidestr = "Left "
         if side >=4:
             sidestr = "Right "
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
-        myStr += "] = (<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>) " 
+        myStr += "] = (<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>) "
         location = int(round(self.sum()))
         if location <= 5:
             myStr += "Location: <B>Head</B>, StunX:<B>x5</B>, NStun:<B>x2</B>, Bodyx:<B>x2</B>"
@@ -187,17 +185,16 @@ class herohk(std):
     def __init__(self,source=[],mod=0):
         std.__init__(self,source)
         self.mod = mod
-        self.gen = random.random()
-       
-    def __str__(self):        
+
+    def __str__(self):
         myStr = "[" + str(self.data[0])
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
-        myStr += "] = (<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>)"   
+        myStr += "] = (<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>)"
         stunx = 1
         myStr += " <b>Body</b> "
-        stunx=stunx + self.mod   
+        stunx = stunx + self.mod
         stunsum = round(self.sum()) * stunx
         myStr += " for a total of (<font color='#ff0000'><b>" + str(int(stunsum)) + "</b></font>) <b>Stun</b>"
         return myStr
@@ -206,15 +203,15 @@ class heron(std):
     def __init__(self,source=[],mod=0):
         std.__init__(self,source)
         self.bodtot=0
-       
-    def __str__(self):        
+
+    def __str__(self):
         myStr = "[" + str(self.data[0])
         if self.data[0] == 6:
             self.bodtot=self.bodtot+2
         else:
             self.bodtot=self.bodtot+1
         if self.data[0] <= 1:
-            self.bodtot=self.bodtot-1 
+            self.bodtot=self.bodtot-1
         for a in self.data[1:]:
             myStr += ","
             myStr += str(a)
@@ -223,9 +220,8 @@ class heron(std):
             else:
                 self.bodtot=self.bodtot+1
             if a <= 1:
-                self.bodtot=self.bodtot-1        
-        myStr += "] = (<font color='#ff0000'><b>" + str(self.bodtot) + "</b></font>)"   
+                self.bodtot=self.bodtot-1
+        myStr += "] = (<font color='#ff0000'><b>" + str(self.bodtot) + "</b></font>)"
         myStr += " <b>Body</b> and "
         myStr += "(<font color='#ff0000'><b>" + str(int(round(self.sum()))) + "</b></font>) <b>Stun</b>"
         return myStr
-
