@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#       openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,12 +22,12 @@
 # Author: OpenRPG Team
 # Maintainer:
 # Version:
-#   $Id: utils.py,v 1.11 2005/10/24 17:32:15 mduo13 Exp $
+#   $Id: utils.py,v 1.20 2006/11/11 23:36:01 digitalxero Exp $
 #
 # Description: Classes to help manage the die roller
 #
 
-__version__ = "$Id: utils.py,v 1.11 2005/10/24 17:32:15 mduo13 Exp $"
+__version__ = "$Id: utils.py,v 1.20 2006/11/11 23:36:01 digitalxero Exp $"
 
 from die import *
 # add addtional rollers here
@@ -39,53 +39,59 @@ from sr4 import *
 from hackmaster import *
 from wodex import *
 from srex import *
+from gurps import *
+from runequest import *
 
 import re
 
-rollers = ['std','wod','d20','hero','shadowrun', 'sr4','hackmaster','srex','wodex']
+rollers = ['std','wod','d20','hero','shadowrun', 'sr4','hackmaster','srex','wodex', 'gurps', 'runequest']
 
 class roller_manager:
-    def __init__(self,roller_class="d20"):        
+    def __init__(self,roller_class="d20"):
         try:
-            self.set_roller(roller_class)
+            self.setRoller(roller_class)
         except:
             self.roller_class = "std"
-        
-    def set_roller(self,roller_class):
+
+    def setRoller(self,roller_class):
         try:
             rollers.index(roller_class)
             self.roller_class = roller_class
         except:
-            raise Exception, "Invalid die roller!" 
+            raise Exception, "Invalid die roller!"
 
-    def get_roller(self):
+    def getRoller(self):
         return self.roller_class
-            
-    def get_rollers(self):
-        return rollers        
-        
+
+    def listRollers(self):
+        return rollers
+
     def stdDieToDClass(self,match):
         s = match.group(0)
         (num,sides) = s.split('d')
 
         if sides.strip().upper() == 'F':
             sides = '15'
-        if int(num)>100 or int(sides)>10000:
+        if int(num) > 100 or int(sides) > 10000:
             return "none"
         else:
-            return "(" + num.strip() + "**"+self.roller_class+"(" + sides.strip() + "))"
+            if eval("(" + num.strip() + "**" + self.roller_class + "(" + sides.strip() + "))") == None:
+                return "(0)"
+            return "(" + num.strip() + "**" + self.roller_class + "(" + sides.strip() + "))"
 
     #  Use this to convert ndm-style (3d6) dice to d_base format
     def convertTheDieString(self,s):
-       reg = re.compile("\d+\s*[a-zA-Z]+\s*[\dFf]+")
-       (result,num_matches) = re.subn(reg,self.stdDieToDClass,s)
-       return result
+        reg = re.compile("\d+\s*[a-zA-Z]+\s*[\dFf]+")
+        (result, num_matches) = reg.subn(self.stdDieToDClass, s)
+        if num_matches == 0 or result == 'none':
+            try:
+                s2 = self.roller_class + "(0)." + s
+                test = eval(s2)
+                return s2
+            except:
+                pass
+        return result
 
 
-    def resolveDieStr(self,s):      
-       return str(eval(self.convertTheDieString(s)))
-
-    
-    
-    
-    
+    def proccessRoll(self,s):
+        return str(eval(self.convertTheDieString(s)))
