@@ -6,6 +6,12 @@
 # All directory locations are now handled by the load_paths() function
 # in the dirpath_tools.py file  -- Snowdog 3-8-05
 
+# CHANGE LOG
+# -----------------------------
+# * Reworked path verification process to attempt to fall back on the
+#   current working directory if approot fails to verify before
+#   asking the user to locate the root directory -- Snowdog 12-20-05
+
 import sys
 import os
 from dirpath_tools import *
@@ -19,20 +25,18 @@ except:
     #attempt to load default path
     root_dir = os.getcwd()   #default ORPG root dir
 
+dir_struct = {}
+
+if not verify_home_path(root_dir):
+    root_dir = os.getcwd()
+    if not verify_home_path(root_dir):
+        root_dir = get_user_located_root()
+        while not verify_home_path(root_dir):
+            root_dir = get_user_located_root()
+
 #switch backslashes to forward slashes just for display on screen only (avoids issues with escaped characters)
 clean = str(root_dir)
 clean = str.replace(clean,'\\','/')
 print "Rooting OpenRPG at: "+clean
 
-dir_struct = {}
-    
-while not verify_home_path(root_dir):
-    root_dir = get_user_located_root()  
 load_paths(dir_struct, root_dir)
-
-
-
-
-
-
-
