@@ -21,12 +21,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: chatmacro.py,v 1.6 2005/06/05 20:12:34 digitalxero Exp $
+#   $Id: chatmacro.py,v 1.15 2006/11/15 12:11:23 digitalxero Exp $
 #
 # Description: The file contains code for the form based nodehanlers
 #
 
-__version__ = "$Id: chatmacro.py,v 1.6 2005/06/05 20:12:34 digitalxero Exp $"
+__version__ = "$Id: chatmacro.py,v 1.15 2006/11/15 12:11:23 digitalxero Exp $"
 
 from core import *
 
@@ -53,7 +53,7 @@ class macro_handler(node_handler):
         for line in actionlist:
             if(line != ""):
                 if line[0] != "/": ## it's not a slash command
-                    action = self.chat.ParsePost(self.chat.colorize(self.chat.mytextcolor, line),true,true)
+                    action = self.chat.ParsePost(line, True, True)
                 else:
                     action = line
                     self.chat.chat_cmds.docmd(action)
@@ -65,33 +65,35 @@ class macro_handler(node_handler):
     def tohtml(self):
         title = self.master_dom.getAttribute("name")
         txt = self.text._get_nodeValue()
-        txt = string.replace(txt,'\n',"<br>")
-        return "<P><b>"+title+":</b><br>"+txt
+        txt = string.replace(txt,'\n',"<br />")
+        return "<P><b>"+title+":</b><br />"+txt
 
-P_TITLE = wxNewId()
-P_BODY = wxNewId()
-B_CHAT = wxNewId()
+P_TITLE = wx.NewId()
+P_BODY = wx.NewId()
+B_CHAT = wx.NewId()
 
-class macro_edit_panel(wxBoxedSizer):
+class macro_edit_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxBoxedSizer.__init__(self, parent, "Chat Macro")
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
-        self.text = {   P_TITLE : orpgTextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name')),
-                        P_BODY : orpgTextCtrl(self,P_BODY,handler.text._get_nodeValue(),style=wxTE_MULTILINE)
-                      }
-        #P_BODY : wxTextCtrl(self, P_BODY,handler.text._get_nodeValue(), style=wxTE_MULTILINE)
-        sizer = wxBoxSizer(wxVERTICAL)
-        sizer.Add(wxStaticText(self, -1, "Title:"), 0, wxEXPAND)
-        sizer.Add(self.text[P_TITLE], 0, wxEXPAND)
-        sizer.Add(wxStaticText(self, -1, "Text Body:"), 0, wxEXPAND)
-        sizer.Add(self.text[P_BODY], 1, wxEXPAND)
-        sizer.Add(wxButton(self, B_CHAT, "Send To Chat"),0,wxEXPAND)
-        EVT_SIZE(self, self.on_size)
-        EVT_TEXT(self, P_TITLE, self.on_text)
-        EVT_TEXT(self, P_BODY, self.on_text)
-        EVT_BUTTON(self, B_CHAT, self.handler.on_use)
-        self.set_sizer(sizer)
-        #EVT_TEXT(self, P_BODY, self.on_text)
+        sizer = wx.StaticBoxSizer(wx.StaticBox(self, -1, "Chat Macro"), wx.VERTICAL)
+        self.text = {}
+        self.text[P_TITLE] = wx.TextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
+        self.text[P_BODY] = wx.TextCtrl(self, P_BODY, handler.text._get_nodeValue(), style=wx.TE_MULTILINE)
+
+        #P_BODY : wx.TextCtrl(self, P_BODY,handler.text._get_nodeValue(), style=wx.TE_MULTILINE)
+
+        sizer.Add(wx.StaticText(self, -1, "Title:"), 0, wx.EXPAND)
+        sizer.Add(self.text[P_TITLE], 0, wx.EXPAND)
+        sizer.Add(wx.StaticText(self, -1, "Text Body:"), 0, wx.EXPAND)
+        sizer.Add(self.text[P_BODY], 1, wx.EXPAND)
+        sizer.Add(wx.Button(self, B_CHAT, "Send To Chat"),0,wx.EXPAND)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_TITLE)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_BODY)
+        self.Bind(wx.EVT_BUTTON, self.handler.on_use, id=B_CHAT)
+        self.SetSizer(sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
 
     def on_text(self,evt):
         id = evt.GetId()
@@ -103,5 +105,3 @@ class macro_edit_panel(wxBoxedSizer):
             self.handler.rename(txt)
         elif id == P_BODY:
             self.handler.set_text(txt)
-
-
