@@ -21,14 +21,15 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: forms.py,v 1.32 2005/10/22 22:13:00 mduo13 Exp $
+#   $Id: forms.py,v 1.50 2006/11/15 12:11:24 digitalxero Exp $
 #
 # Description: The file contains code for the form based nodehanlers
 #
 
-__version__ = "$Id: forms.py,v 1.32 2005/10/22 22:13:00 mduo13 Exp $"
+__version__ = "$Id: forms.py,v 1.50 2006/11/15 12:11:24 digitalxero Exp $"
 
 from containers import *
+import wx.lib.scrolledpanel
 
 def bool2int(b):
     #in wxPython 2.5+, evt.Checked() returns True or False instead of 1.0 or 0.
@@ -64,12 +65,10 @@ class form_handler(container_handler):
             else:
                 self.tree.load_xml(c,self.mytree_node)
         if not self.atts:
-           elem = minidom.Element('form')
-           elem.setAttribute("width","400")
-           elem.setAttribute("height","600")
-           self.atts = self.master_dom.appendChild(elem)
-
-
+            elem = self.xml.minidom.Element('form')
+            elem.setAttribute("width","400")
+            elem.setAttribute("height","600")
+            self.atts = self.master_dom.appendChild(elem)
 
     def get_design_panel(self,parent):
         return form_edit_panel(parent,self)
@@ -82,79 +81,83 @@ class form_handler(container_handler):
         container_handler.on_drop(self,evt)
 
 
-class form_panel(wxScrolledWindow):
+class form_panel(wx.lib.scrolledpanel.ScrolledPanel):
     def __init__(self, parent, handler):
-        wxScrolledWindow.__init__(self, parent, -1,style=wxVSCROLL | wxSUNKEN_BORDER  )
+        wx.lib.scrolledpanel.ScrolledPanel.__init__(self, parent, wx.ID_ANY, style=wx.NO_BORDER|wx.VSCROLL|wx.HSCROLL)
         self.height = int(handler.atts.getAttribute("height"))
-        self.SetScrollbars(10, 10,80, self.height/10)
+        self.width = int(handler.atts.getAttribute("width"))
+
+
+        self.SetSize((0,0))
         self.handler = handler
-        #self.parent = parent
-        self.main_sizer = wxBoxSizer(wxVERTICAL)
-        self.panels = {}
+        self.parent = parent
+        self.main_sizer = wx.BoxSizer(wx.VERTICAL)
         tree = self.handler.tree
-        maximum = tree.GetChildrenCount(handler.mytree_node,0)
-        cookie = 0
-        try:
-            (child,cookie)=tree.GetFirstChild(handler.mytree_node,cookie)
-        except: # If this happens we probably have a newer version of wxPython
-            (child,cookie)=tree.GetFirstChild(handler.mytree_node)
-        obj = tree.GetPyData(child)
-        for m in range(maximum):
-            panel = obj.get_use_panel(self)
-            name = obj.master_dom.getAttribute("name")
-            size = obj.get_size_constraint()
-            if panel:
-                panel.SetSize(wxSize(100,25)) # makes sure the window hs height
-                self.main_sizer.Add(panel, size, wxEXPAND)
-                self.main_sizer.Add(wxSize(10,10))
-            if m < maximum-1:
-                child = tree.GetNextSibling(child)
-                obj = tree.GetPyData(child)
+        child = tree.GetFirstChild(handler.mytree_node)
+        if child[0].IsOk():
+            handler.traverse(child[0], self.create_child_wnd, 0, None, False)
+
         self.SetSizer(self.main_sizer)
-        EVT_SIZE(self, self.on_size)
+        self.SetAutoLayout(True)
 
-    def on_size(self,evt):
-        s = self.GetClientSizeTuple()
-        self.SetScrollbars(10, 10,s[0]/10, self.height/10)
-        dc = wxClientDC(self)
-        x = dc.DeviceToLogicalX(0)
-        y = dc.DeviceToLogicalY(0)
-        self.main_sizer.SetDimension(x+10,y+10,s[0]-30,self.height-20)
-        evt.Skip()
+        self.SetupScrolling()
 
-F_HEIGHT = wxNewId()
-F_WIDTH = wxNewId()
-class form_edit_panel(wxBoxedSizer):
+        parent.SetSize(self.GetSize())
+        self.Fit()
+
+
+    def SetSize(self, xy):
+        (x, y) = self.GetSize()
+        (nx, ny) = xy
+        if x < nx:
+            x = nx+10
+        y += ny+11
+        wx.lib.scrolledpanel.ScrolledPanel.SetSize(self, (x, y))
+
+
+    def create_child_wnd(self, obj, evt):
+        panel = obj.get_use_panel(self)
+        size = obj.get_size_constraint()
+        if panel:
+            self.main_sizer.Add(panel, size, wx.EXPAND)
+            self.main_sizer.Add(wx.Size(10,10))
+
+
+
+F_HEIGHT = wx.NewId()
+F_WIDTH = wx.NewId()
+class form_edit_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxBoxedSizer.__init__(self, parent, "Form Properties")
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
-        sizer = wxBoxSizer(wxVERTICAL)
-        wh_sizer = wxBoxSizer(wxHORIZONTAL)
-        self.text = {   P_TITLE : orpgTextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name')),
-                        F_HEIGHT : orpgTextCtrl(self, F_HEIGHT, handler.atts.getAttribute('height')),
-                        F_WIDTH : orpgTextCtrl(self, F_WIDTH, handler.atts.getAttribute('width'))
+        sizer = wx.StaticBoxSizer(wx.StaticBox(self, -1, "Form Properties"), wx.VERTICAL)
+        wh_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        self.text = {   P_TITLE : wx.TextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name')),
+                        F_HEIGHT : wx.TextCtrl(self, F_HEIGHT, handler.atts.getAttribute('height')),
+                        F_WIDTH : wx.TextCtrl(self, F_WIDTH, handler.atts.getAttribute('width'))
                       }
 
-        wh_sizer.Add(wxStaticText(self, -1, "Width:"), 0, wxALIGN_CENTER)
-        wh_sizer.Add(wxSize(10,10))
-        wh_sizer.Add(self.text[F_WIDTH], 0, wxEXPAND)
-        wh_sizer.Add(wxSize(10,10))
-        wh_sizer.Add(wxStaticText(self, -1, "Height:"), 0, wxALIGN_CENTER)
-        wh_sizer.Add(wxSize(10,10))
-        wh_sizer.Add(self.text[F_HEIGHT], 0, wxEXPAND)
+        wh_sizer.Add(wx.StaticText(self, -1, "Width:"), 0, wx.ALIGN_CENTER)
+        wh_sizer.Add(wx.Size(10,10))
+        wh_sizer.Add(self.text[F_WIDTH], 0, wx.EXPAND)
+        wh_sizer.Add(wx.Size(10,10))
+        wh_sizer.Add(wx.StaticText(self, -1, "Height:"), 0, wx.ALIGN_CENTER)
+        wh_sizer.Add(wx.Size(10,10))
+        wh_sizer.Add(self.text[F_HEIGHT], 0, wx.EXPAND)
 
-        sizer.Add(wxStaticText(self, -1, "Title:"), 0, wxEXPAND)
-        sizer.Add(self.text[P_TITLE], 0, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(wh_sizer,0,wxEXPAND)
+        sizer.Add(wx.StaticText(self, -1, "Title:"), 0, wx.EXPAND)
+        sizer.Add(self.text[P_TITLE], 0, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(wh_sizer,0,wx.EXPAND)
 
-#        self.box_sizer = wxBoxedSizer( self, "Form Properties" )
-        self.set_sizer(sizer)
+        self.SetSizer(sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
+        parent.SetSize(self.GetBestSize())
 
- #       EVT_SIZE(self, self.on_size)
-        EVT_TEXT(self, P_TITLE, self.on_text)
-        EVT_TEXT(self, F_HEIGHT, self.on_text)
-        EVT_TEXT(self, F_WIDTH, self.on_text)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_TITLE)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=F_HEIGHT)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=F_WIDTH)
 
     def on_text(self,evt):
         id = evt.GetId()
@@ -240,118 +243,117 @@ class textctrl_handler(node_handler):
 
     def tohtml(self):
         txt = self.text._get_nodeValue()
-        txt = string.replace(txt,'\n',"<br>")
+        txt = string.replace(txt,'\n',"<br />")
         if not self.is_hide_title():
             txt = "<b>"+self.master_dom.getAttribute("name")+":</b> "+txt
         return txt
 
 
-FORM_TEXT_CTRL = wxNewId()
-FORM_SEND_BUTTON = wxNewId()
+FORM_TEXT_CTRL = wx.NewId()
+FORM_SEND_BUTTON = wx.NewId()
 
-class text_panel(wxPanel):
+class text_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxPanel.__init__(self, parent, -1)
+        wx.Panel.__init__(self, parent, -1)
         self.chat = handler.chat
         self.handler = handler
         if handler.is_multi_line():
-            text_style = wxTE_MULTILINE
-            sizer_style = wxEXPAND
-            sizer = wxBoxSizer(wxVERTICAL)
+            text_style = wx.TE_MULTILINE
+            sizer_style = wx.EXPAND
+            sizer = wx.BoxSizer(wx.VERTICAL)
         else:
-            sizer_style = wxALIGN_CENTER
+            sizer_style = wx.ALIGN_CENTER
             text_style = 0
-            sizer = wxBoxSizer(wxHORIZONTAL)
+            sizer = wx.BoxSizer(wx.HORIZONTAL)
 
         txt = handler.text._get_nodeValue()
-        self.text = orpgTextCtrl(self, FORM_TEXT_CTRL, txt,style=text_style)
-        sizer.Add(wxStaticText(self, -1, handler.master_dom.getAttribute('name')+": "), 0, sizer_style)
-        sizer.Add(wxSize(5,0))
+        self.text = wx.TextCtrl(self, FORM_TEXT_CTRL, txt, style=text_style)
+        sizer.Add(wx.StaticText(self, -1, handler.master_dom.getAttribute('name')+": "), 0, sizer_style)
+        sizer.Add(wx.Size(5,0))
         sizer.Add(self.text, 1, sizer_style)
 
         if handler.has_send_button():
-            sizer.Add(wxButton(self, FORM_SEND_BUTTON, "Send"), 0, sizer_style)
+            sizer.Add(wx.Button(self, FORM_SEND_BUTTON, "Send"), 0, sizer_style)
 
         self.sizer = sizer
         self.SetSizer(sizer)
-        EVT_SIZE(self, self.on_size)
-        EVT_TEXT(self, FORM_TEXT_CTRL, self.on_text)
-        EVT_BUTTON(self, FORM_SEND_BUTTON, self.on_send)
+        self.SetAutoLayout(True)
+
+        parent.SetSize(self.GetBestSize())
+        self.Bind(wx.EVT_TEXT, self.on_text, id=FORM_TEXT_CTRL)
+        self.Bind(wx.EVT_BUTTON, self.on_send, id=FORM_SEND_BUTTON)
 
     def on_text(self,evt):
         txt = self.text.GetValue()
         txt = strip_text(txt)
         self.handler.text._set_nodeValue(txt)
-       #print txt
-
-    def on_size(self,evt):
-        s = self.GetClientSizeTuple()
-        self.sizer.SetDimension(0,0,s[0],s[1])
 
     def on_send(self,evt):
         txt = self.text.GetValue()
         if not self.handler.is_raw_send():
-            #self.chat.ParsePost(self.tohtml(),true,true)
-            self.chat.ParsePost(self.chat.colorize(self.chat.mytextcolor, self.handler.tohtml()),true,true)
+            #self.chat.ParsePost(self.tohtml(),True,True)
+            self.chat.ParsePost(self.handler.tohtml(),True,True)
             return 1
         actionlist = txt.split("\n")
         for line in actionlist:
             if(line != ""):
                 if line[0] != "/": ## it's not a slash command
-                    self.chat.ParsePost(self.chat.colorize(self.chat.mytextcolor, line),true,true)
+                    self.chat.ParsePost(line,True,True)
                 else:
                     action = line
                     self.chat.chat_cmds.docmd(action)
         return 1
 
-F_MULTI = wxNewId()
-F_SEND_BUTTON = wxNewId()
-F_RAW_SEND = wxNewId()
-F_HIDE_TITLE = wxNewId()
-F_TEXT = wxNewId()
+F_MULTI = wx.NewId()
+F_SEND_BUTTON = wx.NewId()
+F_RAW_SEND = wx.NewId()
+F_HIDE_TITLE = wx.NewId()
+F_TEXT = wx.NewId()
 
-class textctrl_edit_panel(wxBoxedSizer):
+class textctrl_edit_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxBoxedSizer.__init__(self, parent, "Text Properties")
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
-        sizer = wxBoxSizer(wxVERTICAL)
+        sizer = wx.StaticBoxSizer(wx.StaticBox(self, -1, "Text Properties"), wx.VERTICAL)
 
-        self.title = orpgTextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
-        self.multi = wxCheckBox(self, F_MULTI, " Multi-Line")
+        self.title = wx.TextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
+        self.multi = wx.CheckBox(self, F_MULTI, " Multi-Line")
         self.multi.SetValue(handler.is_multi_line())
-        self.raw_send = wxCheckBox(self, F_RAW_SEND, " Send as Macro")
+        self.raw_send = wx.CheckBox(self, F_RAW_SEND, " Send as Macro")
         self.raw_send.SetValue(handler.is_raw_send())
-        self.hide_title = wxCheckBox(self, F_HIDE_TITLE, " Hide Title")
+        self.hide_title = wx.CheckBox(self, F_HIDE_TITLE, " Hide Title")
         self.hide_title.SetValue(handler.is_hide_title())
-        self.send_button = wxCheckBox(self, F_SEND_BUTTON, " Send Button")
+        self.send_button = wx.CheckBox(self, F_SEND_BUTTON, " Send Button")
         self.send_button.SetValue(handler.has_send_button())
 
-        sizer.Add(wxStaticText(self, P_TITLE, "Title:"), 0, wxEXPAND)
-        sizer.Add(self.title, 0, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(self.multi, 0, wxEXPAND)
-        sizer.Add(self.raw_send, 0, wxEXPAND)
-        sizer.Add(self.hide_title, 0, wxEXPAND)
-        sizer.Add(self.send_button, 0 , wxEXPAND)
-        sizer.Add(wxSize(10,10))
+        sizer.Add(wx.StaticText(self, P_TITLE, "Title:"), 0, wx.EXPAND)
+        sizer.Add(self.title, 0, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(self.multi, 0, wx.EXPAND)
+        sizer.Add(self.raw_send, 0, wx.EXPAND)
+        sizer.Add(self.hide_title, 0, wx.EXPAND)
+        sizer.Add(self.send_button, 0 , wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
         if handler.is_multi_line():
-            sizer_style = wxEXPAND
-            text_style = wxTE_MULTILINE
+            sizer_style = wx.EXPAND
+            text_style = wx.TE_MULTILINE
             multi = 1
         else:
-            sizer_style = wxEXPAND
+            sizer_style=wx.EXPAND
             text_style = 0
             multi = 0
-        self.text = orpgTextCtrl(self, F_TEXT, handler.text._get_nodeValue(),style=text_style)
-        sizer.Add(wxSize(5,0))
+        self.text = wx.TextCtrl(self, F_TEXT, handler.text._get_nodeValue(),style=text_style)
+        sizer.Add(wx.Size(5,0))
         sizer.Add(self.text, multi, sizer_style)
-        self.set_sizer(sizer)
-        EVT_TEXT(self, P_TITLE, self.on_text)
-        EVT_TEXT(self, F_TEXT, self.on_text)
-        EVT_CHECKBOX(self, F_MULTI, self.on_button)
-        EVT_CHECKBOX(self, F_RAW_SEND, self.on_raw_button)
-        EVT_CHECKBOX(self, F_HIDE_TITLE, self.on_hide_button)
-        EVT_CHECKBOX(self, F_SEND_BUTTON, self.on_send_button)
+        self.SetSizer(sizer)
+        self.SetAutoLayout(True)
+
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_TITLE)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=F_TEXT)
+        self.Bind(wx.EVT_CHECKBOX, self.on_button, id=F_MULTI)
+        self.Bind(wx.EVT_CHECKBOX, self.on_raw_button, id=F_RAW_SEND)
+        self.Bind(wx.EVT_CHECKBOX, self.on_hide_button, id=F_HIDE_TITLE)
+        self.Bind(wx.EVT_CHECKBOX, self.on_send_button, id=F_SEND_BUTTON)
 
     def on_text(self,evt):
         id = evt.GetId()
@@ -481,7 +483,7 @@ class listbox_handler(node_handler):
     def set_selected_node(self,index,selected=1):
         if self.get_type() != L_CHECK:
             self.clear_selections()
-        self.options[index].setAttribute("selected",str(selected))
+        self.options[index].setAttribute("selected", str(bool2int(selected)))
 
     def clear_selections(self):
         for opt in self.options:
@@ -515,7 +517,10 @@ class listbox_handler(node_handler):
         safe_get_text_node(self.options[index])._set_nodeValue(value)
 
     def has_send_button(self):
-        return int(self.list.getAttribute("send_button"))
+        if self.list.getAttribute("send_button") == '0':
+            return False
+        else:
+            return True
 
     def get_size_constraint(self):
         if self.get_type() == L_DROP:
@@ -534,13 +539,13 @@ class listbox_handler(node_handler):
 
 
 
-F_LIST = wxNewId()
-F_SEND = wxNewId()
+F_LIST = wx.NewId()
+F_SEND = wx.NewId()
 
 
-class listbox_panel(wxPanel):
+class listbox_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxPanel.__init__(self, parent, -1)
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
         self.chat = handler.chat
         opts = handler.get_options()
@@ -549,13 +554,16 @@ class listbox_panel(wxPanel):
         label = handler.master_dom.getAttribute('name')
 
         if type == L_DROP:
-            self.list = wxComboBox(self,F_LIST,cur_opt,choices=opts,style=wxCB_READONLY)
+            self.list = wx.ComboBox(self, F_LIST, cur_opt, choices=opts, style=wx.CB_READONLY)
+            if self.list.GetSize()[0] > 200:
+                self.list.Destroy()
+                self.list = wx.ComboBox(self, F_LIST, cur_opt, size=(200, -1), choices=opts, style=wx.CB_READONLY)
         elif type == L_LIST:
-            self.list = wxListBox(self,F_LIST,choices=opts)
+            self.list = wx.ListBox(self,F_LIST,choices=opts)
         elif type == L_RADIO:
-            self.list = wxRadioBox(self,F_LIST,label,choices=opts,majorDimension=3)
+            self.list = wx.RadioBox(self,F_LIST,label,choices=opts,majorDimension=3)
         elif type == L_CHECK:
-            self.list = wxCheckListBox(self,F_LIST,choices=opts)
+            self.list = wx.CheckListBox(self,F_LIST,choices=opts)
             self.set_checks()
 
         for i in handler.get_selections_text():
@@ -564,129 +572,119 @@ class listbox_panel(wxPanel):
             else:
                 self.list.SetStringSelection( i )
 
-        if type==L_DROP:
-            sizer = wxBoxSizer(wxHORIZONTAL)
-            sizer_style = wxALIGN_CENTER
+        if type == L_DROP:
+            sizer = wx.BoxSizer(wx.HORIZONTAL)
+
         else:
-            sizer = wxBoxSizer(wxVERTICAL)
-            sizer_style = wxEXPAND
+            sizer = wx.BoxSizer(wx.VERTICAL)
 
         if type != L_RADIO:
-            sizer.Add(wxStaticText(self, -1, label+": "), 0, sizer_style)
-            sizer.Add(wxSize(5,0))
+            sizer.Add(wx.StaticText(self, -1, label+": "), 0, wx.EXPAND)
+            sizer.Add(wx.Size(5,0))
 
-        sizer.Add(self.list, 1, sizer_style)
+        sizer.Add(self.list, 1, wx.EXPAND)
 
         if handler.has_send_button():
-            sizer.Add(wxButton(self, F_SEND, "Send"), 0, sizer_style)
-            EVT_BUTTON(self, F_SEND, self.handler.on_send_to_chat)
+            sizer.Add(wx.Button(self, F_SEND, "Send"), 0, wx.EXPAND)
+            self.Bind(wx.EVT_BUTTON, self.handler.on_send_to_chat, id=F_SEND)
 
         self.sizer = sizer
-        EVT_SIZE(self, self.on_size)
         self.SetSizer(sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
+
+        parent.SetSize(self.GetBestSize())
 
         if type == L_DROP:
-            EVT_COMBOBOX(self,F_LIST,self.on_change)
+            self.Bind(wx.EVT_COMBOBOX, self.on_change, id=F_LIST)
         elif type == L_LIST:
-            EVT_LISTBOX(self,F_LIST,self.on_change)
+            self.Bind(wx.EVT_LISTBOX, self.on_change, id=F_LIST)
         elif type == L_RADIO:
-            EVT_RADIOBOX(self,F_LIST,self.on_change)
+            self.Bind(wx.EVT_RADIOBOX, self.on_change, id=F_LIST)
         elif type == L_CHECK:
-            EVT_CHECKLISTBOX(self,F_LIST,self.on_check)
+            self.Bind(wx.EVT_CHECKLISTBOX, self.on_check, id=F_LIST)
 
 
         self.type = type
 
-        #EVT_TEXT(self, FORM_TEXT_CTRL, self.on_text)
 
     def on_change(self,evt):
-        #print "selected:" + str(self.list.GetSelection())
         self.handler.set_selected_node(self.list.GetSelection())
 
     def on_check(self,evt):
-        for i in range(self.list.Number()):
-            self.handler.set_selected_node(i,self.list.IsChecked(i))
+        for i in xrange(self.list.GetCount()):
+            self.handler.set_selected_node(i, bool2int(self.list.IsChecked(i)))
 
     def set_checks(self):
         for i in self.handler.get_selections_index():
             self.list.Check(i)
 
-    def on_size(self,evt):
-        s = self.GetClientSizeTuple()
-        self.sizer.SetDimension(0,0,s[0],s[1])
-
- #    def on_send(self,evt):
-#         txt = self.handler.get_selected_text()
-#         if(txt != ""):
-#             if txt[0] != "/": ## it's not a slash command
-#                 action = self.chat.ParsePost(self.chat.colorize(self.chat.mytextcolor, txt),true,true)
-#             else:
-#                 action = self.chat.ParseDice(txt)
-#                 self.chat.emote.docmd(txt)
 
 
+BUT_ADD = wx.NewId()
+BUT_REM = wx.NewId()
+BUT_EDIT = wx.NewId()
+F_TYPE = wx.NewId()
+F_NO_TITLE = wx.NewId()
 
-BUT_ADD = wxNewId()
-BUT_REM = wxNewId()
-BUT_EDIT = wxNewId()
-F_TYPE = wxNewId()
-F_NO_TITLE = wxNewId()
-
-class listbox_edit_panel(wxBoxedSizer):
+class listbox_edit_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxBoxedSizer.__init__(self, parent, "List Box Properties")
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
-        sizer = wxBoxSizer(wxVERTICAL)
+        sizer = wx.StaticBoxSizer(wx.StaticBox(self, -1, "List Box Properties"), wx.VERTICAL)
 
-        self.text = orpgTextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
+        self.text = wx.TextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
 
         opts = handler.get_options()
-        self.listbox = wxListBox(self,F_LIST,choices=opts)
+        self.listbox = wx.ListBox(self,F_LIST,choices=opts)
         opts = ['Drop Down', 'List Box', 'Radio Box', 'Check List']
-        self.type_radios = wxRadioBox(self,F_TYPE,"List Type",choices=opts)
+        self.type_radios = wx.RadioBox(self,F_TYPE,"List Type",choices=opts)
         self.type_radios.SetSelection(handler.get_type())
 
-        self.send_button = wxCheckBox(self, F_SEND_BUTTON, " Send Button")
+        self.send_button = wx.CheckBox(self, F_SEND_BUTTON, " Send Button")
         self.send_button.SetValue(handler.has_send_button())
 
-        self.hide_title = wxCheckBox(self, F_NO_TITLE, " Hide Title")
+        self.hide_title = wx.CheckBox(self, F_NO_TITLE, " Hide Title")
         self.hide_title.SetValue(handler.is_hide_title())
 
-        but_sizer = wxBoxSizer(wxHORIZONTAL)
-        but_sizer.Add(wxButton(self, BUT_ADD, "Add"), 1, wxEXPAND)
-        but_sizer.Add(wxSize(10,10))
-        but_sizer.Add(wxButton(self, BUT_EDIT, "Edit"), 1, wxEXPAND)
-        but_sizer.Add(wxSize(10,10))
-        but_sizer.Add(wxButton(self, BUT_REM, "Remove"), 1, wxEXPAND)
+        but_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        but_sizer.Add(wx.Button(self, BUT_ADD, "Add"), 1, wx.EXPAND)
+        but_sizer.Add(wx.Size(10,10))
+        but_sizer.Add(wx.Button(self, BUT_EDIT, "Edit"), 1, wx.EXPAND)
+        but_sizer.Add(wx.Size(10,10))
+        but_sizer.Add(wx.Button(self, BUT_REM, "Remove"), 1, wx.EXPAND)
 
-        sizer.Add(wxStaticText(self, -1, "Title:"), 0, wxEXPAND)
-        sizer.Add(self.text, 0, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(self.type_radios, 0, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(self.send_button, 0 , wxEXPAND)
-        sizer.Add(self.hide_title, 0, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(wxStaticText(self, -1, "Options:"), 0, wxEXPAND)
-        sizer.Add(self.listbox,1,wxEXPAND);
-        sizer.Add(but_sizer,0,wxEXPAND)
+        sizer.Add(wx.StaticText(self, -1, "Title:"), 0, wx.EXPAND)
+        sizer.Add(self.text, 0, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(self.type_radios, 0, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(self.send_button, 0 , wx.EXPAND)
+        sizer.Add(self.hide_title, 0, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(wx.StaticText(self, -1, "Options:"), 0, wx.EXPAND)
+        sizer.Add(self.listbox,1,wx.EXPAND);
+        sizer.Add(but_sizer,0,wx.EXPAND)
 
-        self.set_sizer(sizer)
+        self.SetSizer(sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
+        parent.SetSize(self.GetBestSize())
 
-        EVT_TEXT(self, P_TITLE, self.on_text)
-        EVT_BUTTON(self, BUT_EDIT, self.on_edit)
-        EVT_BUTTON(self, BUT_REM, self.on_remove)
-        EVT_BUTTON(self, BUT_ADD, self.on_add)
-        EVT_RADIOBOX(self, F_TYPE, self.on_type)
-        EVT_CHECKBOX(self, F_NO_TITLE, self.on_hide_button)
-        EVT_CHECKBOX(self, F_SEND_BUTTON, self.on_send_button)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_TITLE)
+        self.Bind(wx.EVT_BUTTON, self.on_edit, id=BUT_EDIT)
+        self.Bind(wx.EVT_BUTTON, self.on_remove, id=BUT_REM)
+        self.Bind(wx.EVT_BUTTON, self.on_add, id=BUT_ADD)
+        self.Bind(wx.EVT_RADIOBOX, self.on_type, id=F_TYPE)
+        self.Bind(wx.EVT_CHECKBOX, self.on_hide_button, id=F_NO_TITLE)
+        self.Bind(wx.EVT_CHECKBOX, self.on_send_button, id=F_SEND_BUTTON)
 
     def on_type(self,evt):
         self.handler.set_type(evt.GetInt())
 
     def on_add(self,evt):
-        dlg = wxTextEntryDialog(self, 'Enter option?','Add Option', '')
-        if dlg.ShowModal() == wxID_OK:
+        dlg = wx.TextEntryDialog(self, 'Enter option?','Add Option', '')
+        if dlg.ShowModal() == wx.ID_OK:
             self.handler.add_option(dlg.GetValue())
         dlg.Destroy()
         self.reload_options()
@@ -701,8 +699,8 @@ class listbox_edit_panel(wxBoxedSizer):
         index = self.listbox.GetSelection()
         if index >= 0:
             txt = self.handler.get_option(index)
-            dlg = wxTextEntryDialog(self, 'Enter option?','Edit Option', txt)
-            if dlg.ShowModal() == wxID_OK:
+            dlg = wx.TextEntryDialog(self, 'Enter option?','Edit Option', txt)
+            if dlg.ShowModal() == wx.ID_OK:
                 self.handler.edit_option(index,dlg.GetValue())
             dlg.Destroy()
             self.reload_options()
@@ -721,10 +719,11 @@ class listbox_edit_panel(wxBoxedSizer):
             self.handler.rename(txt)
 
     def on_send_button(self,evt):
-        self.handler.list.setAttribute("send_button",str(evt.Checked()))
+        self.handler.list.setAttribute("send_button", str( bool2int(evt.Checked()) ))
 
     def on_hide_button(self,evt):
-        self.handler.list.setAttribute("hide_title",str(evt.Checked()))
+        print "hide_title, " + str(bool2int(evt.Checked()))
+        self.handler.list.setAttribute("hide_title", str( bool2int(evt.Checked()) ))
 
 
 ###############################
@@ -757,35 +756,35 @@ class link_handler(node_handler):
         title = self.master_dom.getAttribute("name")
         return "<a href=\""+href+"\" >"+title+"</a>"
 
-class link_panel(wxStaticText):
+class link_panel(wx.StaticText):
     def __init__(self,parent,handler):
         self.handler = handler
         label = handler.master_dom.getAttribute('name')
-        wxStaticText.__init__(self,parent,-1,label)
-        self.SetForegroundColour(wxBLUE)
-        EVT_LEFT_DOWN(self,self.handler.on_use)
+        wx.StaticText.__init__(self,parent,-1,label)
+        self.SetForegroundColour(wx.BLUE)
+        self.Bind(wx.EVT_LEFT_DOWN, self.handler.on_use)
 
 
-P_URL = wxNewId()
+P_URL = wx.NewId()
 
-class link_edit_panel(wxBoxedSizer):
+class link_edit_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxBoxedSizer.__init__(self, parent, "Link Properties")
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
-        sizer = wxBoxSizer(wxVERTICAL)
+        sizer = wx.StaticBoxSizer(wx.StaticBox(self, -1, "Link Properties"), wx.VERTICAL)
 
         self.text = {}
-        self.text[P_TITLE] = orpgTextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
-        self.text[P_URL] = orpgTextCtrl(self, P_URL, handler.link.getAttribute('href'))
+        self.text[P_TITLE] = wx.TextCtrl(self, P_TITLE, handler.master_dom.getAttribute('name'))
+        self.text[P_URL] = wx.TextCtrl(self, P_URL, handler.link.getAttribute('href'))
 
-        sizer.Add(wxStaticText(self, -1, "Title:"), 0, wxEXPAND)
-        sizer.Add(self.text[P_TITLE], 0, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(wxStaticText(self, -1, "URL:"), 0, wxEXPAND)
-        sizer.Add(self.text[P_URL], 0, wxEXPAND)
-        self.set_sizer(sizer)
-        EVT_TEXT(self, P_TITLE, self.on_text)
-        EVT_TEXT(self, P_URL, self.on_text)
+        sizer.Add(wx.StaticText(self, -1, "Title:"), 0, wx.EXPAND)
+        sizer.Add(self.text[P_TITLE], 0, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(wx.StaticText(self, -1, "URL:"), 0, wx.EXPAND)
+        sizer.Add(self.text[P_URL], 0, wx.EXPAND)
+        self.SetSizer(sizer)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_TITLE)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=P_URL)
 
     def on_text(self,evt):
         id = evt.GetId()
@@ -816,7 +815,7 @@ class webimg_handler(node_handler):
     def get_use_panel(self,parent):
         img = img_helper().load_url(self.link.getAttribute("href"))
         #print img
-        return wxStaticBitmap(parent,-1,img,size=wxSize(img.GetWidth(),img.GetHeight()))
+        return wx.StaticBitmap(parent,-1,img,size= wx.Size(img.GetWidth(),img.GetHeight()))
 
     def tohtml(self):
         href = self.link.getAttribute("href")
