@@ -21,7 +21,7 @@
 # Author: Andrew Bennett
 # Maintainer:
 # Version:
-#   $Id: map_miniature_nodehandler.py,v 1.7 2005/06/05 20:12:36 digitalxero Exp $
+#   $Id: map_miniature_nodehandler.py,v 1.14 2006/11/04 21:24:21 digitalxero Exp $
 #
 # Description: nodehandler for miniature images
 #
@@ -33,23 +33,6 @@ from orpg.mapper.miniatures_msg import mini_msg
 from orpg.mapper.images import imageCache
 import urllib
 
-from orpg.gametree.gametree import STD_MENU_DELETE
-# from orpg.gametree.gametree import STD_MENU_EDIT
-from orpg.gametree.gametree import STD_MENU_RENAME
-from orpg.gametree.gametree import STD_MENU_SEND
-from orpg.gametree.gametree import STD_MENU_SAVE
-from orpg.gametree.gametree import STD_MENU_ICON
-from orpg.gametree.gametree import STD_MENU_CLONE
-from orpg.gametree.gametree import STD_MENU_ABOUT
-from orpg.gametree.gametree import STD_MENU_HTML
-from orpg.gametree.gametree import STD_MENU_EMAIL
-from orpg.gametree.gametree import STD_MENU_WHISPER
-from orpg.gametree.gametree import STD_MENU_WIZARD
-from orpg.gametree.gametree import wxNewId
-
-
-#STD_MENU_MAP = wxNewId()
-
 
 class map_miniature_handler(node_handler):
 
@@ -65,16 +48,13 @@ class map_miniature_handler(node_handler):
 
         self.mapper = openrpg.get_component("map")
         self.session = openrpg.get_component("session")
-        self.myopenrpg=openrpg
+        self.openrpg=openrpg
 
 
         self.miniature_dom = self.master_dom.getElementsByTagName("miniature")
         if self.miniature_dom:
             self.miniature_dom = self.miniature_dom[0]   # convert to scalar
 
-
-
-
     def get_scaled_bitmap(self,x,y):
 
         global imageCache
@@ -92,37 +72,37 @@ class map_miniature_handler(node_handler):
                 ext = string.lower(path[pos+1:])
                 img_type = 0
                 if ext == "gif":
-                    img_type = wxBITMAP_TYPE_GIF
+                    img_type = wx.BITMAP_TYPE_GIF
                 elif (ext == "jpg") | (ext == "jpeg"):
-                    img_type = wxBITMAP_TYPE_JPEG
+                    img_type = wx.BITMAP_TYPE_JPEG
                 elif ext == "bmp":
-                    img_type = wxBITMAP_TYPE_BMP
+                    img_type = wx.BITMAP_TYPE_BMP
                 elif ext == "png":
-                    img_type = wxBITMAP_TYPE_PNG
+                    img_type = wx.BITMAP_TYPE_PNG
                 else:
                     bmp = None
                     raise Exception, "not a valid image type!"
                 data = urllib.urlretrieve(path)
-                bmp = wxBitmap(data[0],img_type)
+                bmp = wx.Bitmap(data[0],img_type)
 
             if bmp:
-                img = wxImageFromBitmap(bmp)
+                img = wx.ImageFromBitmap(bmp)
                 scaled_img = img.Scale(x,y)
                 scaled_bmp = scaled_img.ConvertToBitmap()
                 scratch = scaled_img.ConvertToBitmap()
 
-                memDC = wxMemoryDC()
+                memDC = wx.MemoryDC()
                 memDC.BeginDrawing()
                 memDC.SelectObject(scaled_bmp)
 
-                memDC.SetBrush(wxWHITE_BRUSH)
-                memDC.SetPen(wxWHITE_PEN)
+                memDC.SetBrush(wx.WHITE_BRUSH)
+                memDC.SetPen(wx.WHITE_PEN)
 
                 memDC.DrawRectangle(0,0,x,y)
-                memDC.SetPen(wxNullPen)
-                memDC.SetBrush(wxNullBrush)
+                memDC.SetPen(wx.NullPen)
+                memDC.SetBrush(wx.NullBrush)
                 memDC.DrawBitmap(scratch,0,0,1)
-                memDC.SelectObject(wxNullBitmap)
+                memDC.SelectObject(wx.NullBitmap)
                 memDC.EndDrawing()
                 del memDC
                 return scaled_bmp
@@ -151,7 +131,7 @@ class map_miniature_handler(node_handler):
 
         new_xml = self.get_to_map_XML()
         if (self.session.my_role() <> self.session.ROLE_GM) and (self.session.my_role() <> self.session.ROLE_PLAYER):
-            self.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
+            self.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
             return
 
         if new_xml:
