@@ -21,18 +21,18 @@
 # Author: Ted Berg
 # Maintainer:
 # Version:
-#   $Id: minilib.py,v 1.14 2004/05/11 03:31:26 markt1964 Exp $
+#   $Id: minilib.py,v 1.24 2006/11/04 21:24:21 digitalxero Exp $
 #
 # Description: nodehandler for a collection of miniatures.
 #
 
-__version__ = "$Id: minilib.py,v 1.14 2004/05/11 03:31:26 markt1964 Exp $"
+__version__ = "$Id: minilib.py,v 1.24 2006/11/04 21:24:21 digitalxero Exp $"
 
-"""Nodehandler for collections of miniatures.  User can add, delete, edit 
+"""Nodehandler for collections of miniatures.  User can add, delete, edit
 miniatures as sending them to the map singly or in batches.
 """
 from core import *
-import orpg.dirpath 
+import orpg.dirpath
 import string
 import map_miniature_nodehandler
 import orpg.mapper.map_msg
@@ -43,11 +43,12 @@ import orpg.mapper.map_msg
 # DLG_DIALOG = 2
 # DLG_MYMINIFRAME = 3
 # DLG_DEFAULT = 4
-LISTBOX_ID = 10
-MINICOUNT_ID = 20
-OK_BUTTON = 30
-CANCEL_BUTTON = 40
-LAYER_MINIATURES='miniatures'
+LISTBOX_ID = wx.ID_ANY
+MINICOUNT_ID = wx.ID_ANY
+OK_BUTTON = wx.ID_ANY
+ADD_BUTTON = wx.ID_ANY
+CANCEL_BUTTON = wx.ID_ANY
+LAYER_MINIATURES = 'miniatures'
 
 # Constants
 TO_MINILIB_MAP = { 'path' : 'url', 'label' : 'name', 'id' : None, 'action':None }
@@ -91,12 +92,12 @@ class minilib_handler( node_handler ):
         self.sanity_check_nodes()
 
     def get_design_panel( self, parent ):
-        """returns an instance of the miniature library edit control ( see 
+        """returns an instance of the miniature library edit control ( see
         on_design ).  This is for use with the the 'edit multiple nodes in a
         single frame' code.
         """
         return minpedit( parent, self )
-            
+
     def get_use_panel( self, parent ):
         """returns an instance of the miniature library view control ( see
         on_use ).  This is for use with the the 'view multiple nodes in a
@@ -125,24 +126,24 @@ class minilib_handler( node_handler ):
             show = 'yes'
             if flag:
                 show = 'no'
-                
+
             str += """<tr>
                 <td> %s </td>
                 <td><img src="%s"></td>
                 <td> %s </td>
                 <td> %s </td>
             </tr>""" % ( label, url, url, show )
-                    
+
         str += "</table>"
         print str
         return str
-    
+
     def html_view( self ):
         """see to_html
         """
         return self.tohtml()
-     
-    def on_drop( self, evt ):
+
+    def on_drop(self, evt):
         drag_obj = self.tree.drag_obj
         if drag_obj == self or self.tree.is_parent_node( self.mytree_node, drag_obj.mytree_node ):
             return
@@ -154,19 +155,15 @@ class minilib_handler( node_handler ):
             obj = xml_dom.firstChild
             print obj.getAttributeKeys()
             dict = {}
-            unique = ''              
+            unique = ''
             for attrib in obj.getAttributeKeys():
                 key = TO_MINILIB_MAP.get( attrib, attrib )
                 if key != None:
                     dict[ key ] = obj.getAttribute( attrib )
-            # if dict[ ATTRIBUTE_NAME ][-1] in string.digits:
-            #     unique = '1'
-            # while dict[ ATTRIBUTE_NAME ][-1] in string.digits:
-            #     dict[ ATTRIBUTE_NAME ] = dict[ ATTRIBUTE_NAME ][:-1]
             dict[ ATTRIBUTE_UNIQUE ] = unique
             self.new_mini( dict )
 
-        
+
     def new_mini( self, data={}, add=1 ):
         mini = minidom.Element( TAG_MINIATURE )
         for key in data.keys():
@@ -181,63 +178,61 @@ class minilib_handler( node_handler ):
 
     def add_mini( self, mini ):
         self.master_dom.appendChild( mini )
-    
+
     def add_leaf( self, mini, icon='gear' ):
         tree = self.tree
         icons = tree.icons
         key = mini.getAttribute( ATTRIBUTE_NAME )
         self.mydata.append( mini )
         # new_tree_node = tree.AppendItem( self.mytree_node, key, icons[ icon ], icons[ icon ] )
-        # handler = mini_handler( mini, new_tree_node, self.myopenrpg, self )
+        # handler = mini_handler( mini, new_tree_node, self.openrpg, self )
         # tree.SetPyData( new_tree_node, handler )
-        
+
     def update_leaves( self ):
         self.mydata = []
         nl = self.master_dom.getElementsByTagName( TAG_MINIATURE )
         for n in nl:
             self.add_leaf( n )
-        
+
 
     def on_drag( self, evt ):
         print 'drag event caught'
 
-    def send_mini_to_map( self, mini, count=1 ):
+    def send_mini_to_map( self, mini, count=1, addName=True ):
         if mini == None:
             return
         if mini.getAttribute( ATTRIBUTE_URL ) == '' or mini.getAttribute( ATTRIBUTE_URL ) == 'http://':
-            self.chat.ParsePost( self.chat.colorize(self.chat.syscolor, '"%s" is not a valid URL, the mini "%s" will not be added to the map' % ( mini.getAttribute( ATTRIBUTE_URL ), mini.getAttribute( ATTRIBUTE_NAME ) )) ) 
+            self.chat.ParsePost( self.chat.colorize(self.chat.syscolor, '"%s" is not a valid URL, the mini "%s" will not be added to the map' % ( mini.getAttribute( ATTRIBUTE_URL ), mini.getAttribute( ATTRIBUTE_NAME ) )) )
             return
-        session = self.myopenrpg.get_component( COMPONENT_SESSION )
+        session = self.openrpg.get_component( COMPONENT_SESSION )
         if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER):
-            self.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
+            self.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
             return
-        map = self.myopenrpg.get_component( COMPONENT_MAP )
+        map = self.openrpg.get_component( COMPONENT_MAP )
         for loop in range( count ):
-            msg = self.get_miniature_XML( mini )
+            msg = self.get_miniature_XML( mini, addName)
             msg = str("<map action='update'><miniatures>" + msg + "</miniatures></map>")
             map.new_data( msg )
             session.send( msg )
-        
-    def get_miniature_XML( self, mini ):
+
+    def get_miniature_XML( self, mini, addName = True ):
         msg = orpg.mapper.map_msg.mini_msg()
-        map = self.myopenrpg.get_component( COMPONENT_MAP )
-        session = self.myopenrpg.get_component( COMPONENT_SESSION )
+        map = self.openrpg.get_component( COMPONENT_MAP )
+        session = self.openrpg.get_component( COMPONENT_SESSION )
         msg.init_prop( ATTRIBUTE_ID, session.get_next_id() )
         for k in mini.getAttributeKeys():
             # translate our attributes to map attributes
             key = FROM_MINILIB_MAP.get( k, k )
             if key != None:
-                msg.init_prop( key, mini.getAttribute( k ) )
+                if not addName and k == 'name':
+                    pass
+                else:
+                    msg.init_prop( key, mini.getAttribute( k ) )
         unique = self.is_unique( mini )
-        label = mini.getAttribute( ATTRIBUTE_NAME )
-#        use_serial = map.canvas.use_serial
-#        auto_label = map.canvas..auto_label
-        # if auto_label:
-        #     if use_serial:
-        #         label = '%s %d' % ( label, map.canvas.layers[ LAYER_MINIATURE ].next_serial() )
-        #         msg.set_prop( ATTRIBUTE_NAME, label )
-        # else:
-            # msg.set_prop( ATTRIBUTE_NAME, '' )
+        if addName:
+            label = mini.getAttribute( ATTRIBUTE_NAME )
+        else:
+            label = ''
         return msg.get_all_xml()
 
     def is_unique( self, mini ):
@@ -247,31 +242,31 @@ class minilib_handler( node_handler ):
             val = eval( unique )
         except:
             val = len( unique )
-        return val            
+        return val
 
     def sanity_check_nodes( self ):
         nl = self.master_dom.getElementsByTagName( TAG_MINIATURE )
         for node in nl:
-          if node.getAttribute( ATTRIBUTE_POSX ) == '':
-              node.setAttribute( ATTRIBUTE_POSX, '0' )
-          if node.getAttribute( ATTRIBUTE_POSY ) == '':
-              node.setAttribute( ATTRIBUTE_POSY, '0' )
-    
+            if node.getAttribute( ATTRIBUTE_POSX ) == '':
+                node.setAttribute( ATTRIBUTE_POSX, '0' )
+            if node.getAttribute( ATTRIBUTE_POSY ) == '':
+                node.setAttribute( ATTRIBUTE_POSY, '0' )
+
     def get_mini( self, index ):
         try:
-          nl = self.master_dom.getElementsByTagName( TAG_MINIATURE )
-          return nl[ index ]
+            nl = self.master_dom.getElementsByTagName( TAG_MINIATURE )
+            return nl[ index ]
         except:
-          return None
+            return None
 
 class mini_handler( node_handler ):
     def __init__( self, xml_dom, tree_node, openrpg, handler ):
         node_handler.__init__( self, xml_dom, tree_node, openrpg )
         self.handler = handler
-    
+
     def on_ldclick( self, evt ):
         self.handler.send_mini_to_map( self.master_dom )
-  
+
     def on_drop( self, evt ):
         pass
 
@@ -279,49 +274,52 @@ class mini_handler( node_handler ):
         print 'hi'
         evt.Skip()
 
-class minilib_use_panel( wxPanel ):
+class minilib_use_panel(wx.Panel):
     """This panel will be displayed when the user double clicks on the
     miniature library node.  It is a sorted listbox of miniature labels,
-    a text field for entering a count ( for batch adds ) and 'add'/'done' 
+    a text field for entering a count ( for batch adds ) and 'add'/'done'
     buttons.
     """
     def __init__( self, frame, handler ):
-        """Constructor.  
+        """Constructor.
         """
-        wxPanel.__init__( self, frame, -1 )
+        wx.Panel.__init__( self, frame, -1 )
         self.handler = handler
         self.frame = frame
-        
+
         self.map = self.handler.openrpg.get_component('map')
         names = self.buildList()
         # self.keys = self.list.keys()
         # self.keys.sort()
 
-        
+
         s = self.GetClientSizeTuple()
-        
-        self.sizer = wxBoxSizer( wxVERTICAL )
-        box = wxBoxSizer( wxHORIZONTAL )
-        self.listbox = wxListBox( self, LISTBOX_ID, ( 10, 10 ), (s[0] - 10, 
-            s[1] - 30 ), names, wxLB_SINGLE )
-        self.count = wxTextCtrl( self, MINICOUNT_ID, '1' )
 
-        box.Add( wxStaticText( self, -1, 'Minis to add' ), 0, wxEXPAND )
-        box.Add(wxSize(10,10))
-        box.Add( self.count, 1, wxEXPAND )
-        
-        self.sizer.Add( self.listbox, 1, wxEXPAND )
-        self.sizer.Add( box, 0, wxEXPAND )
+        self.sizer = wx.BoxSizer( wx.VERTICAL )
+        box = wx.BoxSizer( wx.HORIZONTAL )
+        self.listbox = wx.ListBox( self, LISTBOX_ID, ( 10, 10 ), (s[0] - 10,
+            s[1] - 30 ), names, wx.LB_EXTENDED )
+        self.count = wx.TextCtrl( self, MINICOUNT_ID, '1' )
 
-        box = wxBoxSizer( wxHORIZONTAL )
-        box.Add( wxButton( self, OK_BUTTON, 'Add' ), 0, wxEXPAND )
-        box.Add( wxButton( self, CANCEL_BUTTON, 'Done' ), 0, wxEXPAND )
-        self.sizer.Add(wxSize(10,10))
-        self.sizer.Add( box, 0, wxEXPAND )
-        EVT_SIZE( self, self.on_size )
-        EVT_BUTTON( self, OK_BUTTON, self.on_ok )
-        EVT_BUTTON( self, CANCEL_BUTTON, self.on_cancel )
+        box.Add( wx.StaticText( self, -1, 'Minis to add' ), 0, wx.EXPAND )
+        box.Add(wx.Size(10,10))
+        box.Add( self.count, 1, wx.EXPAND )
+
+        self.sizer.Add( self.listbox, 1, wx.EXPAND )
+        self.sizer.Add( box, 0, wx.EXPAND )
+
+        box = wx.BoxSizer( wx.HORIZONTAL )
+        box.Add( wx.Button( self, OK_BUTTON, 'Add' ), 0, wx.EXPAND )
+        box.Add( wx.Button( self, ADD_BUTTON, 'Add No Lable' ), 0, wx.EXPAND )
+        box.Add( wx.Button( self, CANCEL_BUTTON, 'Done' ), 0, wx.EXPAND )
+
+        self.sizer.Add(wx.Size(10,10))
+        self.sizer.Add( box, 0, wx.EXPAND )
+        self.Bind(wx.EVT_BUTTON, self.on_ok, id=OK_BUTTON)
+        self.Bind(wx.EVT_BUTTON, self.on_ok, id=ADD_BUTTON)
         self.SetSizer(self.sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
 
     def buildList( self ):
         """Returns a dictionary of label => game tree miniature DOM node mappings.
@@ -330,7 +328,7 @@ class minilib_use_panel( wxPanel ):
         self.list = []
         for mini in list:
             self.list.append( mini.getAttribute( ATTRIBUTE_NAME ) )
-        return self.list            
+        return self.list
         # self.list = {}
         # for mini in list:
         #     name = mini.getAttribute( ATTRIBUTE_NAME )
@@ -338,24 +336,11 @@ class minilib_use_panel( wxPanel ):
         #         name = self.map.canvas.get_label_from_url( mini.getAttribute( ATTRIBUTE_URL ) )
         #     self.list[ name ] = mini
 
-    def on_size( self, evt ):
-        """Adjusts the sizer dimensions.  Is this really necessary?
-        """
-        s = self.GetClientSizeTuple()
-        self.sizer.SetDimension( 10, 10, s[0] - 20 , s[1] - 20 )
-        
     def on_ok( self, evt ):
         """Event handler for the 'add' button.
         """
-        #key = self.keys[ self.listbox.GetSelection() ]
-        index = self.listbox.GetSelection()
-        # nl = self.handler.master_dom.getElementsByTagName( TAG_MINIATURE )
-        # name = nl[ index ].getAttribute( ATTRIBUTE_NAME )
-        # url = nl[ index ].getAttribute( ATTRIBUTE_URL )
-        # unique = nl[ index ].getAttribute( ATTRIBUTE_UNIQUE )
-        #url = self.list[ key ].getAttribute( ATTRIBUTE_URL )
-        #unique = self.list[ key ].getAttribute( ATTRIBUTE_UNIQUE )
-        
+        btn = self.FindWindowById(evt.GetId())
+        sendName = True
         try:
             count = eval( self.count.GetValue() )
         except:
@@ -367,71 +352,64 @@ class minilib_use_panel( wxPanel ):
             unique = eval( unique )
         except:
             pass
-        self.handler.send_mini_to_map( self.handler.get_mini( index ), count )
-        # for loop in range( 0, count ):
-        #     self.handler.send_mini_to_map( nl[ index ] )
-        #     #self.map.canvas.add_miniature( url, name, unique )
 
-    def on_cancel( self, evt ):
-        """Event handler for 'done' button.  Calls
-        wxPFrame.OnCloseWindow so that all proper frame closing details
-        are taken care of.
-        """
-        wxPFrame.OnCloseWindow( self.frame, None )
-
-ADD_MINI = 10
-DEL_MINI = 20
-SEND_TO_MAP = 30
-SEND_GROUP_TO_MAP = 40
+        if btn.GetLabel() == 'Add No Lable':
+            sendName = False
+        for index in self.listbox.GetSelections():
+            self.handler.send_mini_to_map( self.handler.get_mini( index ), count, sendName )
 
 
-class minpedit( wxPanel ):
-    """Panel for editing game tree miniature nodes.  Node information 
+class minpedit(wx.Panel):
+    """Panel for editing game tree miniature nodes.  Node information
     is displayed in a grid, and buttons are provided for adding, deleting
     nodes, and for sending minis to the map ( singly and in batches ).
     """
     def __init__( self, frame, handler ):
         """Constructor.
         """
-        wxPanel.__init__( self, frame, -1 )
+        wx.Panel.__init__( self, frame, -1 )
         self.handler = handler
         self.frame = frame
 
-        self.sizer = wxBoxSizer( wxVERTICAL )
+        self.sizer = wx.BoxSizer( wx.VERTICAL )
         self.grid = minilib_grid( self, handler )
-        
-        bbox = wxBoxSizer( wxHORIZONTAL )
-        bbox.Add( wxButton( self, ADD_MINI, "New mini" ), 0, wxEXPAND )
-        bbox.Add( wxButton( self, DEL_MINI, "Del mini" ), 0, wxEXPAND )
-        bbox.Add(wxSize(10,10))
-        bbox.Add( wxButton( self, SEND_TO_MAP, "Add 1" ), 0, wxEXPAND )
-        bbox.Add( wxButton( self, SEND_GROUP_TO_MAP, "Add Batch" ), 0, 
-            wxEXPAND )
-        
-        self.sizer.Add( self.grid, 1, wxEXPAND)
+
+        bbox = wx.BoxSizer( wx.HORIZONTAL )
+        newMiniBtn = wx.Button( self, wx.ID_ANY, "New mini" )
+        delMiniBtn = wx.Button( self, wx.ID_ANY, "Del mini" )
+        addMiniBtn = wx.Button( self, wx.ID_ANY, "Add 1" )
+        addBatchBtn = wx.Button( self, wx.ID_ANY, "Add Batch" )
+        bbox.Add(newMiniBtn, 0, wx.EXPAND )
+        bbox.Add(delMiniBtn, 0, wx.EXPAND )
+        bbox.Add(wx.Size(10,10))
+        bbox.Add(addMiniBtn, 0, wx.EXPAND )
+        bbox.Add(addBatchBtn, 0, wx.EXPAND )
+
+        self.sizer.Add( self.grid, 1, wx.EXPAND)
         self.sizer.Add( bbox, 0)
         self.SetSizer(self.sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
+
+        self.Bind(wx.EVT_BUTTON, self.add_mini, newMiniBtn)
+        self.Bind(wx.EVT_BUTTON, self.del_mini, delMiniBtn)
+        self.Bind(wx.EVT_BUTTON, self.send_to_map, addMiniBtn)
+        self.Bind(wx.EVT_BUTTON, self.send_group_to_map, addBatchBtn)
 
-        EVT_SIZE( self, self.on_size )
-        EVT_BUTTON( self, ADD_MINI, self.add_mini )
-        EVT_BUTTON( self, DEL_MINI, self.del_mini )
-        EVT_BUTTON( self, SEND_TO_MAP, self.send_to_map )
-        EVT_BUTTON( self, SEND_GROUP_TO_MAP, self.send_group_to_map )
-    
     def add_mini( self, evt=None ):
         """Event handler for the 'New mini' button.  It calls
         minilib_grid.add_row
         """
         self.grid.add_row()
-        
+
     def del_mini( self, evt=None ):
         """Event handler for the 'Del mini' button.  It calls
         minilib_grid.del_row
         """
-        self.grid.del_row( )
-        
+        self.grid.del_row()
+
     def send_to_map( self, evt=None ):
-        """Event handler for the 'Add 1' button.  Sends the 
+        """Event handler for the 'Add 1' button.  Sends the
         miniature defined by the currently selected row to the map, once.
         """
         # map = self.handler.openrpg.get_component('map')
@@ -448,40 +426,33 @@ class minpedit( wxPanel ):
 
     def send_group_to_map( self, evt=None ):
         """Event handler for the 'Add batch' button.  Querys the user
-        for a mini count and sends the miniature defined by the currently 
+        for a mini count and sends the miniature defined by the currently
         selected row to the map, the specified number of times.
         """
         if self.grid.GetNumberRows() > 0:
-          dlg = wxTextEntryDialog( self.frame, 
-              'How many %s\'s do you want to add?' % 
-              ( self.grid.getSelectedLabel() ), 'Batch mini add', '2' )
-          if dlg.ShowModal() == wxID_OK:
-              try:
-                  value = eval( dlg.GetValue() )
-              except:
-                  value = 0
-              # for loop in range( 0, value ):
-              #     self.send_to_map()
-              print 'getting selected index for batch send'
-              index = self.grid.GetGridCursorRow()
-              print 'sending batch to map'
-              self.handler.send_mini_to_map( self.handler.get_mini( index ), value )
-        
-    def on_size( self, evt ):
-        """Event handler for panel resizing events.
-        """
-        s = self.GetClientSizeTuple()
-        self.sizer.SetDimension( 10, 10, s[0] - 20 , s[1] - 20 )
+            dlg = wx.TextEntryDialog( self.frame,
+                'How many %s\'s do you want to add?' %
+                ( self.grid.getSelectedLabel() ), 'Batch mini add', '2' )
+            if dlg.ShowModal() == wx.ID_OK:
+                try:
+                    value = eval( dlg.GetValue() )
+                except:
+                    value = 0
+                # for loop in range( 0, value ):
+                #     self.send_to_map()
+                print 'getting selected index for batch send'
+                index = self.grid.GetGridCursorRow()
+                print 'sending batch to map'
+                self.handler.send_mini_to_map( self.handler.get_mini( index ), value )
 
-class minilib_grid( wxGrid ):
+class minilib_grid(wx.grid.Grid):
     """A wxGrid subclass designed for editing game tree miniature library
     nodes.
     """
     def __init__( self, parent, handler ):
         """Constructor.
         """
-        wxGrid.__init__(self, parent, -1, style=wxSUNKEN_BORDER | 
-            wxWANTS_CHARS )
+        wx.grid.Grid.__init__(self, parent, -1, style=wx.SUNKEN_BORDER | wx.WANTS_CHARS )
         self.parent = parent
         self.handler = handler
         #self.keys = [ ATTRIBUTE_NAME, ATTRIBUTE_URL, ATTRIBUTE_UNIQUE ]
@@ -492,22 +463,22 @@ class minilib_grid( wxGrid ):
         # self.SetColSize( 1, 250 )
         # self.SetColLabelValue( 2, 'Unique' )
         for key in self.keys:
-          self.SetColLabelValue( self.keys.index( key ), key )
+            self.SetColLabelValue( self.keys.index( key ), key )
         self.update_all()
         self.selectedRow = 0
         self.AutoSizeColumns()
-        EVT_GRID_CELL_CHANGE( self, self.on_cell_change )
-        EVT_GRID_SELECT_CELL( self, self.select_cell )
+        self.Bind(wx.grid.EVT_GRID_CELL_CHANGE, self.on_cell_change)
+        self.Bind(wx.grid.EVT_GRID_SELECT_CELL, self.select_cell)
 
     def update_cols( self ):
         nl = self.handler.master_dom.getElementsByTagName( TAG_MINIATURE )
         for n in nl:
-          for k in n.getAttributeKeys():
-            if k not in self.keys:
-              self.keys.append( k )
+            for k in n.getAttributeKeys():
+                if k not in self.keys:
+                    self.keys.append( k )
 
     def select_cell( self, evt ):
-        """Event handler for grid cell selection changes.  It stores the 
+        """Event handler for grid cell selection changes.  It stores the
         last selected row in a variable for use by the add[*] and del_row
         operations.
         """
@@ -523,17 +494,17 @@ class minilib_grid( wxGrid ):
         """
         return self.handler.master_dom.getElementsByTagName( TAG_MINIATURE )
 
-    def add_row( self, count = 1 ): 
+    def add_row( self, count = 1 ):
         """creates a new miniature node, and then adds it to the current
         miniature library, and to the grid.
         """
         self.AppendRows( count )
         node = self.handler.new_mini( {
-          ATTRIBUTE_NAME :' ', 
+          ATTRIBUTE_NAME :' ',
           ATTRIBUTE_URL :'http://'} )# minidom.Element( TAG_MINIATURE )
         self.update_all()
         #self.handler.master_dom.appendChild( node )
-    
+
     def del_row( self ):
         """deletes the miniature associated with the currently selected
         row. BUG BUG BUG this method should drop a child from the DOM but
@@ -561,14 +532,14 @@ class minilib_grid( wxGrid ):
         list = self.getList()
         count = 0
         for n in list:
-          for k in n.getAttributeKeys():
-            if k not in self.keys:
-              self.keys.append( k )
+            for k in n.getAttributeKeys():
+                if k not in self.keys:
+                    self.keys.append( k )
         count = len( self.keys )
         if self.GetNumberCols() < count:
-          self.AppendCols( count - self.GetNumberCols() )
-          for k in self.keys:
-            self.SetColLabelValue( self.keys.index( k ), k )
+            self.AppendCols( count - self.GetNumberCols() )
+            for k in self.keys:
+                self.SetColLabelValue( self.keys.index( k ), k )
         count = len( list )
         rowcount = self.GetNumberRows()
         if ( count > rowcount ):
@@ -579,24 +550,24 @@ class minilib_grid( wxGrid ):
             self.DeleteRows( 0, total );
         for index in range( 0, count ):
             self.update_grid_row( index )
-    
+
     def getSelectedLabel( self ):
         """Returns the label for the selected row
         """
         return self.GetTable().GetValue( self.selectedRow, 0 )
-    
+
     def getSelectedURL( self ):
         """Returns the URL for the selected row
         """
         return self.GetTable().GetValue( self.selectedRow, 1 )
-    
+
     def getSelectedSerial( self ):
         """Returns the ATTRIBUTE_UNIQUE value for the selected row
         """
         return self.GetTable().GetValue( self.selectedRow, 2 )
-    
+
     def update_grid_row( self, row ):
-        """Updates the specified grid row with data from the DOM node 
+        """Updates the specified grid row with data from the DOM node
         specified by 'row'
         """
         list = self.getList()
@@ -605,7 +576,7 @@ class minilib_grid( wxGrid ):
         # self.GetTable().SetValue( row, 1, item.getAttribute(ATTRIBUTE_URL) )
         # self.GetTable().SetValue( row, 2, item.getAttribute(ATTRIBUTE_UNIQUE) )
         for key in self.keys:
-          self.GetTable().SetValue( row, self.keys.index( key ), item.getAttribute( key ) )
+            self.GetTable().SetValue( row, self.keys.index( key ), item.getAttribute( key ) )
 
     def update_data_row( self, row ):
         """Updates the DOM nodw 'row' with grid data from 'row'
@@ -613,7 +584,7 @@ class minilib_grid( wxGrid ):
         list = self.getList()
         item = list[ row ]
         for key in self.keys:
-          item.setAttribute( key, string.strip( self.GetTable().GetValue( row, self.keys.index( key ) ) ) )
+            item.setAttribute( key, string.strip( self.GetTable().GetValue( row, self.keys.index( key ) ) ) )
         # item.setAttribute( ATTRIBUTE_NAME, string.strip( self.GetTable().GetValue( row, 0 ) ) )
         # item.setAttribute( ATTRIBUTE_URL, string.strip( self.GetTable().GetValue( row, 1 ) ) )
         # item.setAttribute( ATTRIBUTE_UNIQUE, string.strip( self.GetTable().GetValue( row, 2 ) ) )
