@@ -21,12 +21,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: rpg_grid.py,v 1.7 2005/06/05 20:12:36 digitalxero Exp $
+#   $Id: rpg_grid.py,v 1.20 2006/11/15 12:11:24 digitalxero Exp $
 #
 # Description: The file contains code for the grid nodehanlers
 #
 
-__version__ = "$Id: rpg_grid.py,v 1.7 2005/06/05 20:12:36 digitalxero Exp $"
+__version__ = "$Id: rpg_grid.py,v 1.20 2006/11/15 12:11:24 digitalxero Exp $"
 
 from core import *
 from forms import *
@@ -80,7 +80,7 @@ class rpg_grid_handler(node_handler):
             if name == "":
                 name = "Row"
             new_tree_node = tree.AppendItem(self.mytree_node,name,icons['gear'],icons['gear'])
-            handler = grid_row_handler(n,new_tree_node,self.myopenrpg,self)
+            handler = grid_row_handler(n,new_tree_node,self.openrpg,self)
             tree.SetPyData(new_tree_node,handler)
 
 
@@ -98,7 +98,7 @@ class rpg_grid_handler(node_handler):
                 html_str += "<td >"
                 t_node = c._get_firstChild()
                 if t_node == None:
-                    html_str += "<br></td>"
+                    html_str += "<br /></td>"
                 else:
                     html_str += t_node._get_nodeValue() + "</td>"
             html_str += "</tr>"
@@ -115,7 +115,7 @@ class rpg_grid_handler(node_handler):
         return 1
 
     def is_autosized(self):
-        return int(self.grid.getAttribute("autosize"))
+        return self.grid.getAttribute("autosize")
 
     def set_autosize(self,autosize=1):
         self.grid.setAttribute("autosize",str(autosize))
@@ -125,8 +125,8 @@ class grid_row_handler(node_handler):
     """
     def __init__(self,xml_dom,tree_node,openrpg,parent):
         node_handler.__init__(self,xml_dom,tree_node,openrpg)
-        self.drag = false
-        self.frame = self.myopenrpg.get_component('frame')
+        self.drag = False
+        self.frame = self.openrpg.get_component('frame')
 
     def on_drop(self,evt):
         pass
@@ -141,14 +141,14 @@ class grid_row_handler(node_handler):
             html_str += "<td >"
             t_node = c._get_firstChild()
             if t_node == None:
-                html_str += "<br></td>"
+                html_str += "<br /></td>"
             else:
                 html_str += t_node._get_nodeValue() + "</td>"
             html_str += "</tr>"
         html_str += "</table>"
         return html_str
 
-class MyCellEditor(wxPyGridCellEditor):
+class MyCellEditor(wx.grid.PyGridCellEditor):
     """
     This is a sample GridCellEditor that shows you how to make your own custom
     grid editors.  All the methods that can be overridden are show here.  The
@@ -173,12 +173,8 @@ class MyCellEditor(wxPyGridCellEditor):
     -- Andrew
 
     """
-#    def __init__(self, log):
     def __init__(self):
-
-#        self.log = log
-#       self.log.write("MyCellEditor ctor\n")
-        wxPyGridCellEditor.__init__(self)
+        wx.grid.PyGridCellEditor.__init__(self)
 
 
     def Create(self, parent, id, evtHandler):
@@ -186,8 +182,7 @@ class MyCellEditor(wxPyGridCellEditor):
         Called to create the control, which must derive from wxControl.
         *Must Override*
         """
-#        self.log.write("MyCellEditor: Create\n")
-        self._tc = orpgTextCtrl(parent, id, "", style=wxTE_PROCESS_ENTER|wxTE_PROCESS_TAB)
+        self._tc = wx.TextCtrl(parent, id, "", style=wx.TE_PROCESS_ENTER | wx.TE_PROCESS_TAB)
         self._tc.SetInsertionPoint(0)
         self.SetControl(self._tc)
         if evtHandler:
@@ -200,7 +195,6 @@ class MyCellEditor(wxPyGridCellEditor):
         If you don't fill the cell (the rect) then be sure to override
         PaintBackground and do something meaningful there.
         """
-#        self.log.write("MyCellEditor: SetSize %s\n" % rect)
         self._tc.SetDimensions(rect.x+1, rect.y+1, rect.width+2, rect.height+2)
 
 
@@ -209,27 +203,15 @@ class MyCellEditor(wxPyGridCellEditor):
         Show or hide the edit control.  You can use the attr (if not None)
         to set colours or fonts for the control.
         """
-#        self.log.write("MyCellEditor: Show(self, %s, %s)\n" % (show, attr))
         self.base_Show(show, attr)
 
 
-    def PaintBackground(self, rect, attr):
-        """
-        Draws the part of the cell not occupied by the edit control.  The
-        base  class version just fills it with background colour from the
-        attribute.  In this class the edit control fills the whole cell so
-        don't do anything at all in order to reduce flicker.
-        """
-#        self.log.write("MyCellEditor: PaintBackground\n")
-
-
     def BeginEdit(self, row, col, grid):
         """
         Fetch the value from the table and prepare the edit control
         to begin editing.  Set the focus to the edit control.
         *Must Override*
         """
-#        self.log.write("MyCellEditor: BeginEdit (%d,%d)\n" % (row, col))
         self.startValue = grid.GetTable().GetValue(row, col)
         self._tc.SetValue(self.startValue)
         self._tc.SetInsertionPointEnd()
@@ -241,16 +223,15 @@ class MyCellEditor(wxPyGridCellEditor):
 
     def EndEdit(self, row, col, grid):
         """
-        Complete the editing of the current cell. Returns true if the value
+        Complete the editing of the current cell. Returns True if the value
         has changed.  If necessary, the control may be destroyed.
         *Must Override*
         """
-#        self.log.write("MyCellEditor: EndEdit (%d,%d)\n" % (row, col))
-        changed = false
+        changed = False
 
         val = self._tc.GetValue()
         if val != self.startValue:
-            changed = true
+            changed = True
             grid.GetTable().SetValue(row, col, val) # update the table
 
         self.startValue = ''
@@ -263,24 +244,22 @@ class MyCellEditor(wxPyGridCellEditor):
         Reset the value in the control back to its starting value.
         *Must Override*
         """
-#        self.log.write("MyCellEditor: Reset\n")
         self._tc.SetValue(self.startValue)
         self._tc.SetInsertionPointEnd()
 
 
     def IsAcceptedKey(self, evt):
         """
-        Return TRUE to allow the given key to start editing: the base class
+        Return True to allow the given key to start editing: the base class
         version only checks that the event has no modifiers.  F2 is special
         and will always start the editor.
         """
-#        self.log.write("MyCellEditor: IsAcceptedKey: %d\n" % (evt.GetKeyCode()))
 
         ## Oops, there's a bug here, we'll have to do it ourself..
         ##return self.base_IsAcceptedKey(evt)
 
         return (not (evt.ControlDown() or evt.AltDown()) and
-                evt.GetKeyCode() != WXK_SHIFT)
+                evt.GetKeyCode() != wx.WXK_SHIFT)
 
 
     def StartingKey(self, evt):
@@ -288,12 +267,11 @@ class MyCellEditor(wxPyGridCellEditor):
         If the editor is enabled by pressing keys on the grid, this will be
         called to let the editor do something about that first key if desired.
         """
-#        self.log.write("MyCellEditor: StartingKey %d\n" % evt.GetKeyCode())
         key = evt.GetKeyCode()
         ch = None
-        if key in [WXK_NUMPAD0, WXK_NUMPAD1, WXK_NUMPAD2, WXK_NUMPAD3, WXK_NUMPAD4,
-                   WXK_NUMPAD5, WXK_NUMPAD6, WXK_NUMPAD7, WXK_NUMPAD8, WXK_NUMPAD9]:
-            ch = ch = chr(ord('0') + key - WXK_NUMPAD0)
+        if key in [wx.WXK_NUMPAD0, wx.WXK_NUMPAD1, wx.WXK_NUMPAD2, wx.WXK_NUMPAD3, wx.WXK_NUMPAD4,
+                   wx.WXK_NUMPAD5, wx.WXK_NUMPAD6, wx.WXK_NUMPAD7, wx.WXK_NUMPAD8, wx.WXK_NUMPAD9]:
+            ch = ch = chr(ord('0') + key - wx.WXK_NUMPAD0)
 
         elif key < 256 and key >= 0 and chr(key) in string.printable:
             ch = chr(key)
@@ -303,23 +281,13 @@ class MyCellEditor(wxPyGridCellEditor):
         if ch is not None:
             # For this example, replace the text.  Normally we would append it.
             self._tc.AppendText(ch)
-#            self._tc.SetValue(ch)
         else:
             evt.Skip()
 
 
-    def StartingClick(self):
-        """
-        If the editor is enabled by clicking on the cell, this method will be
-        called to allow the editor to simulate the click on the control if
-        needed.
-        """
-#        self.log.write("MyCellEditor: StartingClick\n")
-
 
     def Destroy(self):
         """final cleanup"""
-#        self.log.write("MyCellEditor: Destroy\n")
         self.base_Destroy()
 
 
@@ -328,21 +296,19 @@ class MyCellEditor(wxPyGridCellEditor):
         Create a new object which is the copy of this one
         *Must Override*
         """
-#        self.log.write("MyCellEditor: Clone\n")
-#        return MyCellEditor(self.log)
         return MyCellEditor()
 
 
 
-class rpg_grid(wxGrid):
+class rpg_grid(wx.grid.Grid):
     """grid for attacks"""
     def __init__(self, parent, handler):
-        wxGrid.__init__(self, parent, -1, style=wxSUNKEN_BORDER| wxWANTS_CHARS)
+        wx.grid.Grid.__init__(self, parent, -1, style=wx.SUNKEN_BORDER | wx.WANTS_CHARS)
         self.parent = parent
         self.handler = handler
 
         #  Registers a "custom" cell editor (really the example from Robin Dunn with minor mods
-        self.RegisterDataType(wxGRID_VALUE_STRING,wxGridCellStringRenderer(),MyCellEditor())
+        self.RegisterDataType(wx.grid.GRID_VALUE_STRING, wx.grid.GridCellStringRenderer(),MyCellEditor())
 
         self.rows = handler.grid.getElementsByTagName('row')
         rows = len(self.rows)
@@ -350,32 +316,16 @@ class rpg_grid(wxGrid):
         self.CreateGrid(rows,cols)
         self.SetRowLabelSize(0)
         self.SetColLabelSize(0)
-
-        if handler.is_autosized():
-            EVT_SIZE(self, self.on_size)
-        else:
-            self.set_col_widths()
+        self.set_col_widths()
 
         for i in range(0,len(self.rows)):
             self.refresh_row(i)
 
-        EVT_GRID_CELL_CHANGE(self, self.on_cell_change)
-        EVT_GRID_COL_SIZE(self, self.on_col_size)
-        EVT_GRID_CELL_LEFT_DCLICK(self, self.on_leftdclick)
+        self.Bind(wx.grid.EVT_GRID_CELL_CHANGE, self.on_cell_change)
+        self.Bind(wx.grid.EVT_GRID_COL_SIZE, self.on_col_size)
+        self.Bind(wx.grid.EVT_GRID_CELL_LEFT_DCLICK, self.on_leftdclick)
 
 
-    def fit_cols(self):
-        (w,h) = self.GetClientSizeTuple()
-        cols = self.GetNumberCols()
-        col_w = w/(cols)
-        for i in range(0,cols):
-            self.SetColSize(i,col_w)
-        self.Refresh()
-
-    def on_size(self,evt):
-        self.fit_cols()
-        evt.Skip()
-
     def on_leftdclick(self,evt):
         if self.CanEnableCellControl():
             self.EnableCellEditControl()
@@ -465,80 +415,77 @@ class rpg_grid(wxGrid):
         self.fit_cols()
 
 
-G_TITLE = wxNewId()
-GRID_BOR = wxNewId()
-class rpg_grid_panel(wxPanel):
+G_TITLE = wx.NewId()
+GRID_BOR = wx.NewId()
+class rpg_grid_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxPanel.__init__(self, parent, -1)
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
         self.grid = rpg_grid(self,handler)
         label = handler.master_dom.getAttribute('name')
-        self.main_sizer = wxBoxSizer(wxVERTICAL)
-        self.main_sizer.Add(wxStaticText(self, -1, label+": "), 0, wxEXPAND)
-        #self.main_sizer.Add(wxSize(10,10))
-        self.main_sizer.Add(self.grid,1,wxEXPAND)
+        self.main_sizer = wx.BoxSizer(wx.VERTICAL)
+        self.main_sizer.Add(wx.StaticText(self, -1, label+": "), 0, wx.EXPAND)
+        self.main_sizer.Add(self.grid,1,wx.EXPAND)
         self.SetSizer(self.main_sizer)
-        EVT_SIZE(self, self.on_size)
-
-    def on_size(self,evt):
-        s = self.GetClientSizeTuple()
-        self.main_sizer.SetDimension(0,0,s[0],s[1])
+        self.SetAutoLayout(True)
+        self.Fit()
+        parent.SetSize(self.GetBestSize())
 
 
-G_AUTO_SIZE = wxNewId()
-G_ADD_ROW = wxNewId()
-G_ADD_COL = wxNewId()
-G_DEL_ROW = wxNewId()
-G_DEL_COL = wxNewId()
+G_AUTO_SIZE = wx.NewId()
+G_ADD_ROW = wx.NewId()
+G_ADD_COL = wx.NewId()
+G_DEL_ROW = wx.NewId()
+G_DEL_COL = wx.NewId()
 
-class rpg_grid_edit_panel(wxPanel):
+class rpg_grid_edit_panel(wx.Panel):
     def __init__(self, parent, handler):
-        wxPanel.__init__(self, parent, -1)
+        wx.Panel.__init__(self, parent, -1)
         self.handler = handler
         self.grid = rpg_grid(self,handler)
-        self.title = wxTextCtrl(self, G_TITLE, handler.master_dom.getAttribute('name'))
+        self.title = wx.TextCtrl(self, G_TITLE, handler.master_dom.getAttribute('name'))
 
-        radio_b = wxRadioBox(self, GRID_BOR, "Border (HTML)", choices=["no","yes"])
+        radio_b = wx.RadioBox(self, GRID_BOR, "Border (HTML)", choices=["no","yes"])
         border = handler.grid.getAttribute("border")
         radio_b.SetSelection(int(border))
 
-        self.auto_size = wxCheckBox(self, G_AUTO_SIZE, " Auto Size")
-        self.auto_size.SetValue(handler.is_autosized())
+        self.auto_size = wx.CheckBox(self, G_AUTO_SIZE, " Auto Size")
+        if handler.is_autosized() == '1':
+            self.auto_size.SetValue(True)
+        else:
+            self.auto_size.SetValue(False)
 
-        sizer = wxBoxSizer(wxHORIZONTAL)
-        sizer.Add(wxButton(self, G_ADD_ROW, "Add Row"), 1, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(wxButton(self, G_DEL_ROW, "Remove Row"), 1, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(wxButton(self, G_ADD_COL, "Add Column"), 1, wxEXPAND)
-        sizer.Add(wxSize(10,10))
-        sizer.Add(wxButton(self, G_DEL_COL, "Remove Column"), 1, wxEXPAND)
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer.Add(wx.Button(self, G_ADD_ROW, "Add Row"), 1, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(wx.Button(self, G_DEL_ROW, "Remove Row"), 1, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(wx.Button(self, G_ADD_COL, "Add Column"), 1, wx.EXPAND)
+        sizer.Add(wx.Size(10,10))
+        sizer.Add(wx.Button(self, G_DEL_COL, "Remove Column"), 1, wx.EXPAND)
 
-        self.main_sizer = wxBoxSizer(wxVERTICAL)
-        self.main_sizer.Add(wxStaticText(self, -1, "Title:"), 0, wxEXPAND)
-        self.main_sizer.Add(self.title, 0, wxEXPAND)
-        #self.main_sizer.Add(wxSize(10,10))
+        self.main_sizer = wx.StaticBoxSizer(wx.StaticBox(self,-1,"Grid"), wx.VERTICAL)
+        self.main_sizer.Add(wx.StaticText(self, -1, "Title:"), 0, wx.EXPAND)
+        self.main_sizer.Add(self.title, 0, wx.EXPAND)
         self.main_sizer.Add(radio_b, 0, 0)
-        #self.main_sizer.Add(wxSize(10,10))
         self.main_sizer.Add(self.auto_size, 0, 0)
-        #self.main_sizer.Add(wxSize(10,10))
-        self.main_sizer.Add(self.grid,1,wxEXPAND)
-        self.main_sizer.Add(sizer,0,wxEXPAND)
+        self.main_sizer.Add(self.grid,1,wx.EXPAND)
+        self.main_sizer.Add(sizer,0,wx.EXPAND)
 
-        self.outline = wxStaticBox(self,-1,"Grid")
         self.SetSizer(self.main_sizer)
+        self.SetAutoLayout(True)
+        self.Fit()
 
-        EVT_SIZE(self, self.on_size)
-        EVT_TEXT(self, G_TITLE, self.on_text)
-        EVT_BUTTON(self, G_ADD_ROW, self.grid.add_row)
-        EVT_BUTTON(self, G_DEL_ROW, self.grid.del_row)
-        EVT_BUTTON(self, G_ADD_COL, self.grid.add_col)
-        EVT_BUTTON(self, G_DEL_COL, self.grid.del_col)
-        EVT_RADIOBOX(self, GRID_BOR, self.on_radio_box)
-        EVT_CHECKBOX(self, G_AUTO_SIZE, self.on_auto_size)
+        self.Bind(wx.EVT_TEXT, self.on_text, id=G_TITLE)
+        self.Bind(wx.EVT_BUTTON, self.grid.add_row, id=G_ADD_ROW)
+        self.Bind(wx.EVT_BUTTON, self.grid.del_row, id=G_DEL_ROW)
+        self.Bind(wx.EVT_BUTTON, self.grid.add_col, id=G_ADD_COL)
+        self.Bind(wx.EVT_BUTTON, self.grid.del_col, id=G_DEL_COL)
+        self.Bind(wx.EVT_RADIOBOX, self.on_radio_box, id=GRID_BOR)
+        self.Bind(wx.EVT_CHECKBOX, self.on_auto_size, id=G_AUTO_SIZE)
 
     def on_auto_size(self,evt):
-        self.handler.set_autosize(evt.Checked())
+        self.handler.set_autosize(bool2int(evt.Checked()))
 
     def on_radio_box(self,evt):
         id = evt.GetId()
@@ -551,8 +498,3 @@ class rpg_grid_edit_panel(wxPanel):
         if txt != "":
             self.handler.master_dom.setAttribute('name',txt)
             self.handler.rename(txt)
-
-    def on_size(self,evt):
-        s = self.GetClientSizeTuple()
-        self.main_sizer.SetDimension(20,20,s[0]-40,s[1]-40)
-        self.outline.SetDimensions(5,5,s[0]-10,s[1]-10)
