@@ -21,11 +21,11 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: base.py,v 1.7 2004/02/19 02:07:23 tdb30_ Exp $
+#   $Id: base.py,v 1.18 2007/02/12 02:29:08 digitalxero Exp $
 #
-# Description: 
+# Description:
 #
-__version__ = "$Id: base.py,v 1.7 2004/02/19 02:07:23 tdb30_ Exp $"
+__version__ = "$Id: base.py,v 1.18 2007/02/12 02:29:08 digitalxero Exp $"
 
 #from mplay_client import *
 from images import *
@@ -35,24 +35,13 @@ from orpg.orpg_windows import *
 
 from orpg.orpg_xml import *
 from math import *
+from threading import Lock
 
 import time
 
-########################
-## timer
-########################
-
-class mytimer(wxTimer):
-    def __init__(self,func):
-        self.func = func
-        wxTimer.__init__(self)
-
-    def Notify(self):
-        self.func()
-        
-class cmpPoint(wxPoint):
+class cmpPoint(wx.Point):
     def __init__(self,*_args,**_kwargs):
-        wxPoint.__init__(self,*_args,**_kwargs)
+        wx.Point.__init__(self,*_args,**_kwargs)
 
     def __cmp__(self,other):
         try:
@@ -74,9 +63,9 @@ class cmpPoint(wxPoint):
 
 
 
-class cmpColour(wxColour):
+class cmpColour(wx.Colour):
     def __init__(self,*_args,**_kwargs):
-        wxColour.__init__(self,*_args,**_kwargs)
+        wx.Colour.__init__(self,*_args,**_kwargs)
 
     def __cmp__(self,other):
         try:
@@ -105,7 +94,6 @@ class protectable_attributes:
         self.__dict__[name] = value
 
     def __setattr__(self,name,value):
-
         if name in self._protected_attr:
             full_name = "_protect_" + name
             if hasattr(self,full_name):
@@ -159,18 +147,18 @@ class protectable_attributes:
 ## base class for layer objects
 ##-----------------------------
 
-class layer_base(protectable_attributes):
+class layer_base:
 
     def __init__(self):
-        protectable_attributes.__init__(self)
+        self.lock = Lock()
 
-    def draw(self,dc):
+    def layerDraw(self,dc,scale='',topleft='',size=''):
         pass
 
-    def toxml(self):
+    def layerToXML(self, action):
         pass
 
-    def takexml(self):
+    def layerTakeDOM(self, xml_dom):
         pass
 
     def hit_test(self,pos):
