@@ -27,78 +27,79 @@ from fog import *
 from base_handler import *
 from region import *
 
-CTRL_REVEAL = wxNewId()
-CTRL_HIDE = wxNewId()
-CTRL_REMOVE = wxNewId()
-CTRL_SHOWALL = wxNewId()
-CTRL_HIDEALL = wxNewId()
-CTRL_COLOR = wxNewId()
-CTRL_PEN = wxNewId()
+#CTRL_REVEAL = wx.NewId()
+#CTRL_HIDE = wx.NewId()
+#CTRL_REMOVE = wx.NewId()
+#CTRL_SHOWALL = wx.NewId()
+#CTRL_HIDEALL = wx.NewId()
+#CTRL_COLOR = wx.NewId()
+#CTRL_PEN = wx.NewId()
 
 class fog_handler(base_layer_handler):
     def __init__(self, parent, id, canvas):
         self.showmode = 1
-        self.drawing = false
-        self.pencolor=wxWHITE
+        self.drawing = False
+        self.pencolor=wx.WHITE
         base_layer_handler.__init__(self, parent, id, canvas)
 
     def build_ctrls(self):
         foglayer = self.canvas.layers['fog']
         base_layer_handler.build_ctrls(self)
         self.f_type_radio = {}
-        self.f_type_radio[CTRL_REVEAL] = wxRadioButton(self, CTRL_REVEAL, "Show", style=wxRB_GROUP)
-        self.f_type_radio[CTRL_HIDE] = wxRadioButton(self, CTRL_HIDE, "Hide")
+        self.fogshow = wx.RadioButton(self, wx.ID_ANY, "Show", style=wx.RB_GROUP)
+        self.foghide = wx.RadioButton(self, wx.ID_ANY, "Hide")
 
-
-        self.sizer.Prepend(wxSize(20,25),1)
-        self.sizer.Prepend(self.f_type_radio[CTRL_HIDE])
-        self.sizer.Prepend(self.f_type_radio[CTRL_REVEAL])
+        self.sizer.Add(self.foghide)
+        self.sizer.Add(self.fogshow)
+        self.sizer.Add(wx.Size(20,25),1)
 
 
     def build_menu(self,label = "fog"):
         base_layer_handler.build_menu(self,label)
         self.main_menu.AppendSeparator()
 
+        item = wx.MenuItem(self.main_menu, wx.ID_ANY, "&Hide All", "Hide All")
+        self.canvas.Bind(wx.EVT_MENU, self.on_hideall, item)
+        self.main_menu.AppendItem(item)
 
-#        self.main_menu.Append(CTRL_SHOWALL,"&Show All")
-        self.main_menu.Append(CTRL_HIDEALL,"&Hide All")
-        self.main_menu.Append(CTRL_COLOR,"&Fog Mask")
-        self.main_menu.Append(CTRL_REMOVE,"&Remove Fog Layer")
-        self.main_menu.Append(CTRL_PEN,"&Pen Color")
+        item = wx.MenuItem(self.main_menu, wx.ID_ANY, "&Fog Mask", "Fog Mask")
+        self.canvas.Bind(wx.EVT_MENU, self.on_color, item)
+        self.main_menu.AppendItem(item)
 
-#        EVT_MENU(self.canvas,CTRL_SHOWALL,self.on_showall)
-        EVT_MENU(self.canvas,CTRL_PEN,self.on_pen_color)
-        EVT_MENU(self.canvas,CTRL_COLOR,self.on_color)
-        EVT_MENU(self.canvas,CTRL_HIDEALL,self.on_hideall)
-        EVT_MENU(self.canvas,CTRL_REMOVE,self.on_remove)
+        item = wx.MenuItem(self.main_menu, wx.ID_ANY, "&Remove Fog Layer", "Remove Fog Layer")
+        self.canvas.Bind(wx.EVT_MENU, self.on_remove, item)
+        self.main_menu.AppendItem(item)
 
+        item = wx.MenuItem(self.main_menu, wx.ID_ANY, "&Pen Color", "Pen Color")
+        self.canvas.Bind(wx.EVT_MENU, self.on_pen_color, item)
+        self.main_menu.AppendItem(item)
 
 
 
 
     def on_remove(self,evt):
         session=self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+        if (session.my_role() != session.ROLE_GM):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
         self.canvas.layers['fog'].remove_fog()
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
 
     def on_showall(self,evt):
         session=self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+        if (session.my_role() != session.ROLE_GM):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
         foglayer = self.canvas.layers['fog']
         foglayer.showall()
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
 
     def on_pen_color(self,evt):
-        data = wxColourData()
-        data.SetChooseFull(true)
+        data = wx.ColourData()
+        data.SetChooseFull(True)
         data.SetColour(self.pencolor)
-        dlg = wxColourDialog(self.canvas, data)
-        if dlg.ShowModal() == wxID_OK:
+        dlg = wx.ColourDialog(self.canvas, data)
+        if dlg.ShowModal() == wx.ID_OK:
             data = dlg.GetColourData()
             color = data.GetColour()
             self.pencolor=color
@@ -106,28 +107,28 @@ class fog_handler(base_layer_handler):
 
     def on_hideall(self,evt):
         session=self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+        if (session.my_role() != session.ROLE_GM):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
         foglayer=self.canvas.layers['fog']
         foglayer.clear()
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
 
     def on_color(self,evt):
         session=self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+        if (session.my_role() != session.ROLE_GM):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
-        data = wxColourData()
-        data.SetChooseFull(true)
+        data = wx.ColourData()
+        data.SetChooseFull(True)
         data.SetColour(self.canvas.layers['fog'].color)
-        dlg = wxColourDialog(self.canvas, data)
-        if dlg.ShowModal() == wxID_OK:
+        dlg = wx.ColourDialog(self.canvas, data)
+        if dlg.ShowModal() == wx.ID_OK:
             data = dlg.GetColourData()
             self.canvas.layers['fog'].color=data.GetColour()
         dlg.Destroy()
         self.canvas.layers['fog'].fill_fog()
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
 
     def update_info(self):
         foglayer = self.canvas.layers['fog']
@@ -136,7 +137,7 @@ class fog_handler(base_layer_handler):
 
     def on_motion(self, evt):
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
@@ -148,44 +149,44 @@ class fog_handler(base_layer_handler):
                 self.line = []
                 self.line.append(IPoint().make(pos.x,pos.y))
             elif pos.x!=self.last.x or pos.y!=self.last.y:
-                pen=wxPen(self.pencolor)
+                pen= wx.Pen(self.pencolor)
                 pen.SetWidth(COURSE/2+1)
                 dc.SetPen(pen)
                 dc.DrawLine(self.last.x*COURSE,self.last.y*COURSE,pos.x*COURSE,pos.y*COURSE)
-                dc.SetPen(wxNullPen)
+                dc.SetPen(wx.NullPen)
                 self.line.append(IPoint().make(pos.x,pos.y))
             self.last = pos
-            self.drawing = true
+            self.drawing = True
         del dc
 
     def on_left_up(self,evt):
-        if self.drawing == true:
+        if self.drawing == True:
             session=self.canvas.frame.session
-            if (session.my_role() <> session.ROLE_GM):
-                self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+            if (session.my_role() != session.ROLE_GM):
+                self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             else:
                 # This code sets the mode to either new or del depending on the action to function with the updated createregen code.
-                if (self.f_type_radio[CTRL_REVEAL].GetValue() == 1):
+                if (self.fogshow.GetValue() == 1):
                     showmode = 'new'
                 else:
                     showmode = 'del'
                 scale = self.canvas.layers['grid'].mapscale
-                dc = wxClientDC( self.canvas )
+                dc = wx.ClientDC( self.canvas )
                 self.canvas.PrepareDC( dc )
                 dc.SetUserScale(scale,scale)
-                pen=wxPen(self.pencolor)
+                pen= wx.Pen(self.pencolor)
                 pen.SetWidth(COURSE*scale/2+1)
                 dc.SetPen(pen)
                 dc.DrawLine(self.last.x*COURSE,self.last.y*COURSE,self.line[0].X*COURSE,self.line[0].Y*COURSE)
-                dc.SetPen(wxNullPen)
-                wxBeginBusyCursor()
+                dc.SetPen(wx.NullPen)
+                wx.BeginBusyCursor()
                 # This prevents the divide by zero error by not even sending the line to be proccessed if it contains less then 3 points
                 if (len(self.line)>1):
                     self.canvas.layers['fog'].createregn(self.line,showmode)
                 else:
                     #print "Error Divide by zero, ignoring this section"
                     pass
-                wxEndBusyCursor()
+                wx.EndBusyCursor()
                 del dc
-            self.canvas.Refresh(false)
-            self.drawing = false
+            self.canvas.Refresh(False)
+            self.drawing = False
