@@ -21,11 +21,11 @@
 # Author: OpenRPG Team
 # Maintainer:
 # Version:
-#   $Id: grid.py,v 1.17 2005/06/05 20:12:38 digitalxero Exp $
+#   $Id: grid.py,v 1.24 2006/11/11 22:38:42 digitalxero Exp $
 #
 # Description:
 #
-__version__ = "$Id: grid.py,v 1.17 2005/06/05 20:12:38 digitalxero Exp $"
+__version__ = "$Id: grid.py,v 1.24 2006/11/11 22:38:42 digitalxero Exp $"
 
 from base import *
 from isometric import *
@@ -47,7 +47,6 @@ class grid_layer(layer_base):
 
     def __init__(self, canvas):
         layer_base.__init__(self)
-        self._protected_attr = ["unit_size","snap","color","mode","line"]
         self.canvas = canvas
         self.iso_ratio = RATIO_DEFAULT  #2:1 isometric ratio
         self.mapscale = 1
@@ -59,18 +58,16 @@ class grid_layer(layer_base):
         #size_ratio is the size ajustment for Hex and ISO to make them more accurate
         self.size_ratio = 1.5
 
-        self.snap = true
-        color = wxBLACK
-        (r,g,b) = color.Get()
-        self.color = cmpColour(r,g,b)
+        self.snap = True
+        self.color = wx.BLACK# = color.Get()
+        #self.color = cmpColour(r,g,b)
         self.r_h = RGBHex()
         self.mode = GRID_RECTANGLE
         self.line = LINE_NONE
         # Keep logic for different modes in different functions
         self.grid_hit_test = self.grid_hit_test_rect
         self.get_top_corner = self.get_top_corner_rect
-        self.draw = self.draw_rect
-        self._clean_all_attr()
+        self.layerDraw = self.draw_rect
 
     def get_unit_size(self):
         return self.unit_size
@@ -95,7 +92,7 @@ class grid_layer(layer_base):
         self.mode = GRID_RECTANGLE
         self.grid_hit_test = self.grid_hit_test_rect
         self.get_top_corner = self.get_top_corner_rect
-        self.draw = self.draw_rect
+        self.layerDraw = self.draw_rect
         self.unit_size_y = self.unit_size
 
     def set_hex_mode(self):
@@ -103,7 +100,7 @@ class grid_layer(layer_base):
         self.mode = GRID_HEXAGON
         self.grid_hit_test = self.grid_hit_test_hex
         self.get_top_corner = self.get_top_corner_hex
-        self.draw = self.draw_hex
+        self.layerDraw = self.draw_hex
         self.unit_size_y = self.unit_size
         self.unit_offset = sqrt(pow((self.unit_size/self.size_ratio ),2)-pow((self.unit_size/2),2))
         self.unit_widest = (self.unit_offset*2)+(self.unit_size/self.size_ratio )
@@ -113,7 +110,7 @@ class grid_layer(layer_base):
         self.mode = GRID_ISOMETRIC
         self.grid_hit_test = self.grid_hit_test_iso
         self.get_top_corner = self.get_top_corner_iso
-        self.draw = self.draw_iso
+        self.layerDraw = self.draw_iso
         self.unit_size_y = self.unit_size
 
     def set_line_none(self):
@@ -131,7 +128,7 @@ class grid_layer(layer_base):
     def grid_hit_test_rect(self,pos):
         "return grid pos (w,h) on rect map from pos"
         if self.unit_size and self.snap:
-            return (pos.x/self.unit_size,pos.y/self.unit_size)
+            return (pos.x/self.unit_size, pos.y/self.unit_size)
         else:
             return None
 
@@ -249,7 +246,7 @@ class grid_layer(layer_base):
         else:
             return None
 
-    def set_grid(self,unit_size,snap,color,mode,line,ratio = None):
+    def set_grid(self, unit_size, snap, color, mode, line, ratio=None):
         self.unit_size = unit_size
         if ratio != None:
             self.iso_ratio = ratio
@@ -287,10 +284,10 @@ class grid_layer(layer_base):
 
 
         if self.line == LINE_SOLID:
-            dc.SetPen(wxPen(self.color,1,wxSOLID))
+            dc.SetPen(wx.Pen(self.color,1,wx.SOLID))
 
         else:
-            dc.SetPen(wxPen(self.color,1,wxDOT))
+            dc.SetPen(wx.Pen(self.color,1,wx.DOT))
 
 
         sz = self.canvas.size
@@ -326,7 +323,7 @@ class grid_layer(layer_base):
         # Enable DC optimizations if available on a platform
         dc.EndDrawing()
 
-        dc.SetPen(wxNullPen)
+        dc.SetPen(wx.NullPen)
 
         # Disable pen/brush optimizations to prevent any odd effects elsewhere
 
@@ -343,10 +340,10 @@ class grid_layer(layer_base):
                 draw = 0
 
             elif self.line == LINE_SOLID:
-                dc.SetPen(wxPen(self.color,1,wxSOLID))
+                dc.SetPen(wx.Pen(self.color,1,wx.SOLID))
 
             else:
-                dc.SetPen(wxPen(self.color,1,wxDOT))
+                dc.SetPen(wx.Pen(self.color,1,wx.DOT))
 
             if draw:
                 sz = self.canvas.size
@@ -373,7 +370,7 @@ class grid_layer(layer_base):
                 # Enable DC optimizations if available on a platform
                 dc.EndDrawing()
 
-                dc.SetPen(wxNullPen)
+                dc.SetPen(wx.NullPen)
 
             # Disable pen/brush optimizations to prevent any odd effects elsewhere
 
@@ -389,10 +386,10 @@ class grid_layer(layer_base):
                 draw = 0
 
             elif self.line == LINE_SOLID:
-                dc.SetPen(wxPen(self.color,1,wxSOLID))
+                dc.SetPen(wx.Pen(self.color,1,wx.SOLID))
 
             else:
-                dc.SetPen(wxPen(self.color,1,wxDOT))
+                dc.SetPen(wx.Pen(self.color,1,wx.DOT))
 
             if draw:
                 sz = self.canvas.size
@@ -417,10 +414,10 @@ class grid_layer(layer_base):
                     x = startx
                     lineArray = []
                     while x < mx:
-                        lineArray.append(wxPoint(x,y))
-                        lineArray.append(wxPoint(x+us,y))
-                        lineArray.append(wxPoint(x+usxy,y+usy/2))
-                        lineArray.append(wxPoint(x+usxy+us,y+usy/2))
+                        lineArray.append(wx.Point(x,y))
+                        lineArray.append(wx.Point(x+us,y))
+                        lineArray.append(wx.Point(x+usxy,y+usy/2))
+                        lineArray.append(wx.Point(x+usxy+us,y+usy/2))
                         dc.DrawLine(x+usxy,y+usy/2,x+us,y+usy)
                         dc.DrawLine(x+usxy+us,y+usy/2,x+3*us,y+usy)
                         x += 3*us
@@ -431,95 +428,70 @@ class grid_layer(layer_base):
                 # Enable DC optimizations if available on a platform
                 dc.EndDrawing()
 
-                dc.SetPen(wxNullPen)
+                dc.SetPen(wx.NullPen)
 
             # Disable pen/brush optimizations to prevent any odd effects elsewhere
 
 
 
-    def toxml(self,action = "update"):
+    def layerToXML(self,action = "update"):
+        xml_str = "<grid"
 
-        xml_str = ""
+        if self.color != None:
+            (red,green,blue) = self.color.Get()
+            hexcolor = self.r_h.hexstring(red, green, blue)
+            xml_str += " color='" + hexcolor + "'"
 
-        if action == "new":
-            self._dirty_all_attr()
+        if self.unit_size != None:
+            xml_str += " size='" + str(self.unit_size) + "'"
 
-        changed = self._changed_attr()
+        if self.iso_ratio != None:
+            xml_str += " ratio='" + str(self.iso_ratio) + "'"
 
-        if changed:
-            xml_str = "<grid"
+        if self.snap != None:
+            if self.snap:
+                xml_str += " snap='1'"
+            else:
+                xml_str += " snap='0'"
 
-            for a in changed.keys():
-                if a == "color":
-                    if not (self.color is None):
-                        (red,green,blue) = self.color.Get()
-                        hexcolor = self.r_h.hexstring(red, green, blue)
-                        xml_str += " color='" + hexcolor + "'"
-                elif a == "unit_size":
-                    if not (self.unit_size is None):
-                        xml_str += " size='" + str(self.unit_size) + "'"
-                elif a == "iso_ratio":
-                    if not (self.iso_ratio is None):
-                        xml_str += " ratio='" + str(self.iso_ratio) + "'"
-                elif a == "snap":
-                    if not (self.snap is None):
-                        xml_str += " snap='" + str(self.snap) + "'"
-                elif a == "mode":
-                    if not (self.mode is None):
-                        xml_str+= "  mode='" + str(self.mode) + "'"
-                elif a == "line":
-                    if not (self.line is None):
-                        xml_str+= " line='" + str(self.line) + "'"
+        if self.mode != None:
+            xml_str+= "  mode='" + str(self.mode) + "'"
 
-            xml_str += "/>"
+        if self.line != None:
+            xml_str+= " line='" + str(self.line) + "'"
+
+        xml_str += "/>"
 
-        self._clean_all_attr()
         return xml_str
 
 
-    def takedom(self,xml_dom):
-        color = xml_dom.getAttribute("color")
-        if color <> "":
-            r,g,b = self.r_h.rgb_tuple(color)
+    def layerTakeDOM(self, xml_dom):
+        if xml_dom.hasAttribute("color"):
+            r,g,b = self.r_h.rgb_tuple(xml_dom.getAttribute("color"))
             self.set_color(cmpColour(r,g,b))
-            self._clean_attr("color")
-
-        size = xml_dom.getAttribute("size")
 
         #backwards compatible with non-isometric map formated clients
-        try:
+        ratio = RATIO_DEFAULT
+        if xml_dom.hasAttribute("ratio"):
             ratio = xml_dom.getAttribute("ratio")
-        except:
-            ratio = RATIO_DEFAULT
 
-        if size <> "":
-            self.unit_size = int(size)
+        if xml_dom.hasAttribute("mode"):
+            self.SetMode(int(xml_dom.getAttribute("mode")))
+
+        if xml_dom.hasAttribute("size"):
+            self.unit_size = int(xml_dom.getAttribute("size"))
             if self.mode == GRID_RECTANGLE:
                 self.unit_size_y = self.unit_size
             if self.mode == GRID_ISOMETRIC:
                 self.unit_size_y = self.unit_size
             elif self.mode == GRID_HEXAGON:
                 self.unit_size_y = self.unit_size*(3**0.5)
-            self._clean_attr("unit_size")
 
-        snap = xml_dom.getAttribute("snap")
-
-        if snap <> "":
-            if (snap == 'True') or (snap == "1"):
-                snap = 1
+        if xml_dom.hasAttribute("snap"):
+            if (xml_dom.getAttribute("snap") == 'True') or (xml_dom.getAttribute("snap") == "1"):
+                self.snap = True
             else:
-                snap = 0
-            self.snap = snap
-            self._clean_attr("snap")
-
-
-        mode = xml_dom.getAttribute("mode")
-        if mode <> "":
-            self.SetMode(int(mode))
-            self._clean_attr("mode")
-
-        line = xml_dom.getAttribute("line")
-        if line <> "":
-            self.SetLine(int(line))
-            self._clean_attr("line")
+                self.snap = False
 
+        if xml_dom.hasAttribute("line"):
+            self.SetLine(int(xml_dom.getAttribute("line")))
