@@ -20,20 +20,14 @@
 # Author: OpenRPG Team
 # Maintainer:
 # Version:
-#   $Id: map_handler.py,v 1.6 2004/05/11 03:31:27 markt1964 Exp $
+#   $Id: map_handler.py,v 1.13 2007/02/12 02:29:08 digitalxero Exp $
 #
 # Description: map layer handler
 #
-__version__ = "$Id: map_handler.py,v 1.6 2004/05/11 03:31:27 markt1964 Exp $"
+__version__ = "$Id: map_handler.py,v 1.13 2007/02/12 02:29:08 digitalxero Exp $"
 
 from base_handler import *
 
-CTRL_MAP_WIDTH = wxNewId()
-CTRL_MAP_HEIGHT = wxNewId()
-CTRL_MAP_NAME = wxNewId()
-CTRL_MAP_APPLY = wxNewId()
-CTRL_MAP_LOAD_DEFAULT = wxNewId()
-
 class map_handler(base_layer_handler):
     def __init__(self, parent, id, canvas):
         base_layer_handler.__init__(self, parent, id, canvas)
@@ -41,30 +35,26 @@ class map_handler(base_layer_handler):
     def build_ctrls(self):
         base_layer_handler.build_ctrls(self)
 
-        self.width = orpgTextCtrl(self, CTRL_MAP_WIDTH, size=(75,25))
-        self.height = orpgTextCtrl(self, CTRL_MAP_HEIGHT, size=(75,25))
-        #self.name = orpgTextCtrl(self, CTRL_MAP_NAME, size=(200,25))
+        self.width = wx.TextCtrl(self, wx.ID_ANY, size=(75,25))
+        self.height = wx.TextCtrl(self, wx.ID_ANY, size=(75,25))
 
-        self.apply_button = wxButton(self, CTRL_MAP_APPLY, "Apply!", style=wxBU_EXACTFIT)
-        self.load_default = wxButton(self, CTRL_MAP_LOAD_DEFAULT, "Default Map", style=wxBU_EXACTFIT)
+        self.apply_button = wx.Button(self, wx.ID_OK, "Apply!", style=wx.BU_EXACTFIT)
+        self.load_default = wx.Button(self, wx.ID_ANY, "Default Map", style=wx.BU_EXACTFIT)
 
-        self.sizer.Prepend(wxSize(20,25),1)
-        self.sizer.Prepend(self.load_default, 0, wxEXPAND)
-        self.sizer.Prepend(wxSize(20,25))
-        self.sizer.Prepend(self.apply_button, 0, wxEXPAND)
-        self.sizer.Prepend(wxSize(20,25))
-        #self.sizer.Prepend(self.name, 0, wxEXPAND)
-        #self.sizer.Prepend(wxStaticText(self, -1, "Name: "),0,wxALIGN_CENTER)
-        #self.sizer.Prepend(wxSize(10,25))
-        self.sizer.Prepend(self.height, 0, wxEXPAND)
-        self.sizer.Prepend(wxStaticText(self, -1, "Height: "),0,wxALIGN_CENTER)
-        self.sizer.Prepend(wxSize(10,25))
-        self.sizer.Prepend(self.width, 0, wxEXPAND)
-        self.sizer.Prepend(wxStaticText(self, -1, "Width: "),0,wxALIGN_CENTER)
-        self.sizer.Prepend(wxSize(10,25))
+        self.sizer.Prepend(wx.Size(20,25),1)
+        self.sizer.Prepend(self.load_default, 0, wx.EXPAND)
+        self.sizer.Prepend(wx.Size(20,25))
+        self.sizer.Prepend(self.apply_button, 0, wx.EXPAND)
+        self.sizer.Prepend(wx.Size(20,25))
+        self.sizer.Prepend(self.height, 0, wx.EXPAND)
+        self.sizer.Prepend(wx.StaticText(self, -1, "Height: "),0,wx.ALIGN_CENTER)
+        self.sizer.Prepend(wx.Size(10,25))
+        self.sizer.Prepend(self.width, 0, wx.EXPAND)
+        self.sizer.Prepend(wx.StaticText(self, -1, "Width: "),0,wx.ALIGN_CENTER)
+        self.sizer.Prepend(wx.Size(10,25))
 
-        EVT_BUTTON(self, CTRL_MAP_APPLY, self.on_apply)
-        EVT_BUTTON(self, CTRL_MAP_LOAD_DEFAULT, self.on_load_default)
+        self.Bind(wx.EVT_BUTTON, self.on_apply, self.apply_button)
+        self.Bind(wx.EVT_BUTTON, self.on_load_default, self.load_default)
         self.update_info()
 
     def update_info(self):
@@ -81,18 +71,14 @@ class map_handler(base_layer_handler):
     def on_apply(self, evt):
         session=self.canvas.frame.session
         if (session.my_role() <> session.ROLE_GM):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
         try:
             size = (int(self.width.GetValue()),int(self.height.GetValue()))
         except:
-            wxMessageBox("Invalide Map Size!","Map Properties")
+            wx.MessageBox("Invalide Map Size!","Map Properties")
             return
         self.canvas.set_size(size)
         self.update_info()
         self.canvas.send_map_data()
         self.canvas.Refresh()
-
-
-
-
