@@ -21,11 +21,11 @@
 # Author: OpenRPG
 # Maintainer:
 # Version:
-#   $Id: map_msg.py,v 1.8 2005/11/02 18:11:30 snowdog_ Exp $
+#   $Id: map_msg.py,v 1.15 2006/11/04 21:24:21 digitalxero Exp $
 #
-# Description: 
+# Description:
 #
-__version__ = "$Id: map_msg.py,v 1.8 2005/11/02 18:11:30 snowdog_ Exp $"
+__version__ = "$Id: map_msg.py,v 1.15 2006/11/04 21:24:21 digitalxero Exp $"
 
 #from base import *
 from base_msg import *
@@ -76,7 +76,7 @@ class map_msg(map_element_msg_base):
             if xml_dom.getAttributeKeys():
                 for k in xml_dom.getAttributeKeys():
                     self.init_prop(k,xml_dom.getAttribute(k))
-                    
+
 
             for c in xml_dom._get_childNodes():
 
@@ -102,7 +102,7 @@ class map_msg(map_element_msg_base):
                     self.children[name].init_from_dom(c)
 
                 except Exception, e:
-                    print "map_msg.init_from_dom() exception: " +  e
+                    print "map_msg.init_from_dom() exception: "+str(e)
                     continue
 
         else:
@@ -159,7 +159,7 @@ class map_msg(map_element_msg_base):
                     self.children[name].set_from_dom(c)
 
                 except Exception, e:
-                    print "map_msg.set_from_dom() exception: " + e
+                    print "map_msg.set_from_dom() exception: "+str(e)
                     continue
 
         else:
@@ -174,4 +174,3 @@ class map_msg(map_element_msg_base):
 
     def get_changed_xml(self,action="update",output_action=1):
         return map_element_msg_base.get_changed_xml(self,action,output_action)
-
