@@ -21,66 +21,72 @@
 # Author: OpenRPG Team
 # Maintainer:
 # Version:
-#   $Id: miniatures_handler.py,v 1.19 2005/03/06 01:50:32 digitalxero Exp $
+#   $Id: miniatures_handler.py,v 1.36 2007/02/12 02:29:08 digitalxero Exp $
 #
 # Description: Miniature layer handler
 #
-__version__ = "$Id: miniatures_handler.py,v 1.19 2005/03/06 01:50:32 digitalxero Exp $"
+__version__ = "$Id: miniatures_handler.py,v 1.36 2007/02/12 02:29:08 digitalxero Exp $"
 
 
 from base_handler import *
 #from miniatures import *
 from min_dialogs import *
+import thread
 import time
+import mimetypes
+import urllib
+import xml.dom.minidom as minidom
+import wx
 
 
-LABEL_TOOL = wxNewId()
-LAYER_TOOL = wxNewId()
-MIN_LIST_TOOL = wxNewId()
-MIN_TOOL = wxNewId()
-MIN_URL = wxNewId()
-SERIAL_TOOL = wxNewId()
+LABEL_TOOL = wx.NewId()
+LAYER_TOOL = wx.NewId()
+MIN_LIST_TOOL = wx.NewId()
+MIN_TOOL = wx.NewId()
+MIN_URL = wx.NewId()
+SERIAL_TOOL = wx.NewId()
 
-MIN_REMOVE = wxNewId()
-MIN_PROP_DLG = wxNewId()
-MIN_FACING_NONE = wxNewId()
-MIN_FACING_MATCH = wxNewId()
-MIN_FACING_EAST = wxNewId()
-MIN_FACING_WEST = wxNewId()
-MIN_FACING_NORTH = wxNewId()
-MIN_FACING_SOUTH = wxNewId()
-MIN_FACING_NORTHEAST = wxNewId()
-MIN_FACING_SOUTHEAST = wxNewId()
-MIN_FACING_SOUTHWEST = wxNewId()
-MIN_FACING_NORTHWEST = wxNewId()
-MIN_HEADING_NONE = wxNewId()
-MIN_HEADING_MATCH = wxNewId()
-MIN_HEADING_EAST = wxNewId()
-MIN_HEADING_WEST = wxNewId()
-MIN_HEADING_NORTH = wxNewId()
-MIN_HEADING_SOUTH = wxNewId()
-MIN_HEADING_NORTHEAST = wxNewId()
-MIN_HEADING_SOUTHEAST = wxNewId()
-MIN_HEADING_SOUTHWEST = wxNewId()
-MIN_HEADING_NORTHWEST = wxNewId()
-MIN_HEADING_SUBMENU = wxNewId()
-MIN_FACING_SUBMENU = wxNewId()
-MIN_ALIGN_SUBMENU = wxNewId()
-MIN_ALIGN_GRID_CENTER = wxNewId()
-MIN_ALIGN_GRID_TL = wxNewId()
-MIN_TITLE_HACK = wxNewId()
-MIN_TO_GAMETREE = wxNewId()
+MIN_REMOVE = wx.NewId()
+MIN_PROP_DLG = wx.NewId()
+MIN_FACING_NONE = wx.NewId()
+MIN_FACING_MATCH = wx.NewId()
+MIN_FACING_EAST = wx.NewId()
+MIN_FACING_WEST = wx.NewId()
+MIN_FACING_NORTH = wx.NewId()
+MIN_FACING_SOUTH = wx.NewId()
+MIN_FACING_NORTHEAST = wx.NewId()
+MIN_FACING_SOUTHEAST = wx.NewId()
+MIN_FACING_SOUTHWEST = wx.NewId()
+MIN_FACING_NORTHWEST = wx.NewId()
+MIN_HEADING_NONE = wx.NewId()
+MIN_HEADING_MATCH = wx.NewId()
+MIN_HEADING_EAST = wx.NewId()
+MIN_HEADING_WEST = wx.NewId()
+MIN_HEADING_NORTH = wx.NewId()
+MIN_HEADING_SOUTH = wx.NewId()
+MIN_HEADING_NORTHEAST = wx.NewId()
+MIN_HEADING_SOUTHEAST = wx.NewId()
+MIN_HEADING_SOUTHWEST = wx.NewId()
+MIN_HEADING_NORTHWEST = wx.NewId()
+MIN_HEADING_SUBMENU = wx.NewId()
+MIN_FACING_SUBMENU = wx.NewId()
+MIN_ALIGN_SUBMENU = wx.NewId()
+MIN_ALIGN_GRID_CENTER = wx.NewId()
+MIN_ALIGN_GRID_TL = wx.NewId()
+MIN_TITLE_HACK = wx.NewId()
+MIN_TO_GAMETREE = wx.NewId()
 
-MIN_BACK_ONE = wxNewId()
-MIN_FORWARD_ONE = wxNewId()
-MIN_TO_BACK = wxNewId()
-MIN_TO_FRONT = wxNewId()
-MIN_LOCK_BACK = wxNewId()
-MIN_LOCK_FRONT = wxNewId()
-MIN_FRONTBACK_UNLOCK = wxNewId()
-MIN_ZORDER_SUBMENU = wxNewId()
+MIN_BACK_ONE = wx.NewId()
+MIN_FORWARD_ONE = wx.NewId()
+MIN_TO_BACK = wx.NewId()
+MIN_TO_FRONT = wx.NewId()
+MIN_LOCK_BACK = wx.NewId()
+MIN_LOCK_FRONT = wx.NewId()
+MIN_FRONTBACK_UNLOCK = wx.NewId()
+MIN_ZORDER_SUBMENU = wx.NewId()
+MIN_SHOW_HIDE = wx.NewId()
 
-MAP_REFRESH_MINI_URLS = wxNewId()
+MAP_REFRESH_MINI_URLS = wx.NewId()
 
 
 class miniatures_handler(base_layer_handler):
@@ -98,26 +104,43 @@ class miniatures_handler(base_layer_handler):
 
         # add controls in reverse order! (unless you want them after the default tools)
 
-        auto_label = wxCheckBox(self, LABEL_TOOL, ' Auto Label ', (-1,-1),(-1,-1))
-        self.auto_label_cb = auto_label
-        auto_label.SetValue(self.auto_label)
-        self.min_url = wxComboBox(self,MIN_URL,"http://",style=wxCB_DROPDOWN|wxCB_SORT)
+        self.auto_label_cb = wx.CheckBox(self, wx.ID_ANY, ' Auto Label ', (-1,-1),(-1,-1))
+        self.auto_label_cb.SetValue(self.auto_label)
+        self.min_url = wx.ComboBox(self, wx.ID_ANY, "http://", style=wx.CB_DROPDOWN | wx.CB_SORT)
+        self.localBrowse = wx.Button(self, wx.ID_ANY, 'Browse')
+        minilist = createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'questionhead.gif', 'Edit miniature properties', wx.ID_ANY)
+        miniadd = wx.Button(self, wx.ID_OK, "Add Miniature", style=wx.BU_EXACTFIT)
+
+        self.sizer.Add(self.auto_label_cb,0,wx.ALIGN_CENTER)
+        self.sizer.Add(self.min_url, 1, wx.ALIGN_CENTER)
+        self.sizer.Add(miniadd, 0, wx.EXPAND)
+        self.sizer.Add(self.localBrowse, 0, wx.EXPAND)
+        self.sizer.Add(wx.Size(20,25))
+        self.sizer.Add(minilist, 0, wx.EXPAND )
 
 
-        self.sizer.Prepend( createMaskedButton( self, orpg.dirpath.dir_struct["icon"]+'questionhead.gif', 'Edit miniature properties', MIN_LIST_TOOL ), 0, wxEXPAND )
-        self.sizer.Prepend(wxSize(20,25))
-        self.sizer.Prepend(wxButton(self, MIN_TOOL, "Add Miniature", style=wxBU_EXACTFIT), 0, wxEXPAND)
-        self.sizer.Prepend(self.min_url, 1, wxALIGN_CENTER)
-        self.sizer.Prepend(auto_label,0,wxALIGN_CENTER)
-        self.sizer.Prepend(wxSize(10,25))
+        self.Bind(wx.EVT_BUTTON, self.on_min_list, minilist)
+        self.Bind(wx.EVT_BUTTON, self.on_miniature, miniadd)
+        self.Bind(wx.EVT_BUTTON, self.on_browse, self.localBrowse)
+        self.Bind(wx.EVT_CHECKBOX, self.on_label, self.auto_label_cb)
 
-        #self.sizer.Fit(self)
-        #self.SetAutoLayout(true)
-        #self.SetSizer(self.sizer)
+    def on_browse(self, evt):
+        dlg = wx.FileDialog(None, "Select a Miniture to load", wildcard="Image files (*.bmp, *.gif, *.jpg, *.png)|*.bmp;*.gif;*.jpg;*.png", style=wx.OPEN)
 
-        EVT_BUTTON(self, MIN_LIST_TOOL, self.on_min_list)
-        EVT_BUTTON(self, MIN_TOOL, self.on_miniature)
-        EVT_CHECKBOX(self, LABEL_TOOL, self.on_label)
+        if not dlg.ShowModal() == wx.ID_OK:
+            dlg.Destroy()
+            return
+
+        file = open(dlg.GetPath(), "rb")
+        imgdata = file.read()
+        file.close()
+
+        filename = dlg.GetFilename()
+        (imgtype,j) = mimetypes.guess_type(filename)
+
+        postdata = urllib.urlencode({'filename':filename, 'imgdata':imgdata, 'imgtype':imgtype})
+
+        thread.start_new_thread(self.canvas.layers['miniatures'].upload, (postdata, dlg.GetPath()))
 
 
     def build_menu(self,label = "Miniature"):
@@ -130,18 +153,18 @@ class miniatures_handler(base_layer_handler):
         self.main_menu.Check(SERIAL_TOOL, self.use_serial)
         self.main_menu.Append(MAP_REFRESH_MINI_URLS,"&Refresh miniatures")       #  Add the menu item
 
-        EVT_MENU(self.canvas,MAP_REFRESH_MINI_URLS,self.on_map_board_menu_item)          #  Set the handler
-        EVT_MENU(self.canvas, LABEL_TOOL, self.on_label)
-        EVT_MENU(self.canvas, SERIAL_TOOL, self.on_serial)
+        self.canvas.Bind(wx.EVT_MENU, self.on_map_board_menu_item, id=MAP_REFRESH_MINI_URLS)          #  Set the handler
+        self.canvas.Bind(wx.EVT_MENU, self.on_label, id=LABEL_TOOL)
+        self.canvas.Bind(wx.EVT_MENU, self.on_serial, id=SERIAL_TOOL)
 
         # build miniature meenu
 
-        self.min_menu = wxMenu()
+        self.min_menu = wx.Menu()
 
         # Rectangles and hexagons require slightly different menus because of
         # facing and heading possibilities.
-        heading_menu = wxMenu()
-        face_menu = wxMenu()
+        heading_menu = wx.Menu()
+        face_menu = wx.Menu()
         face_menu.Append(MIN_FACING_NONE,"&None")
         face_menu.Append(MIN_FACING_NORTH,"&North")
         face_menu.Append(MIN_FACING_NORTHEAST,"Northeast")
@@ -162,17 +185,19 @@ class miniatures_handler(base_layer_handler):
         heading_menu.Append(MIN_HEADING_NORTHWEST,"Northwest")
 
 
-        align_menu = wxMenu()
+        align_menu = wx.Menu()
         align_menu.Append(MIN_ALIGN_GRID_CENTER,"&Center")
         align_menu.Append(MIN_ALIGN_GRID_TL,"&Top-Left")
 
         #  This is a hack to simulate a menu title, due to problem in Linux
-        if wxPlatform == '__WXMSW__':
+        if wx.Platform == '__WXMSW__':
             self.min_menu.SetTitle(label)
         else:
             self.min_menu.Append(MIN_TITLE_HACK,label)
             self.min_menu.AppendSeparator()
 
+
+        self.min_menu.Append(MIN_SHOW_HIDE,"Show / Hide")
         self.min_menu.Append(MIN_REMOVE,"&Remove")
 
         self.min_menu.Append(MIN_TO_GAMETREE,"To &Gametree")
@@ -181,7 +206,7 @@ class miniatures_handler(base_layer_handler):
         self.min_menu.AppendMenu(MIN_FACING_SUBMENU,"Set &Facing",face_menu)
         self.min_menu.AppendMenu(MIN_ALIGN_SUBMENU,"Snap-to &Alignment",align_menu)
         self.min_menu.AppendSeparator()
-        zorder_menu = wxMenu()
+        zorder_menu = wx.Menu()
         zorder_menu.Append(MIN_BACK_ONE,"Back one")
         zorder_menu.Append(MIN_FORWARD_ONE,"Forward one")
         zorder_menu.Append(MIN_TO_BACK,"To back")
@@ -196,39 +221,40 @@ class miniatures_handler(base_layer_handler):
         self.min_menu.AppendSeparator()
         self.min_menu.Append(MIN_PROP_DLG,"&Properties")
 
-        EVT_MENU(self.canvas, MIN_REMOVE, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_TO_GAMETREE, self.on_min_menu_item)
-        #EVT_MENU(self.canvas, MIN_LOCK, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_PROP_DLG, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_NONE,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_EAST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_WEST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_NORTH,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_SOUTH,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_NORTHEAST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_SOUTHEAST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_SOUTHWEST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FACING_NORTHWEST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_NONE,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_EAST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_WEST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_NORTH,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_SOUTH,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_NORTHEAST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_SOUTHEAST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_SOUTHWEST,self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_HEADING_NORTHWEST,self.on_min_menu_item)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_SHOW_HIDE)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_REMOVE)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_TO_GAMETREE)
+        #self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_LOCK)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_PROP_DLG)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_NONE)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_EAST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_WEST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_NORTH)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_SOUTH)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_NORTHEAST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_SOUTHEAST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_SOUTHWEST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FACING_NORTHWEST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_NONE)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_EAST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_WEST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_NORTH)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_SOUTH)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_NORTHEAST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_SOUTHEAST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_SOUTHWEST)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_HEADING_NORTHWEST)
 
-        EVT_MENU(self.canvas, MIN_ALIGN_GRID_CENTER, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_ALIGN_GRID_TL, self.on_min_menu_item)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_ALIGN_GRID_CENTER)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_ALIGN_GRID_TL)
 
-        EVT_MENU(self.canvas, MIN_BACK_ONE, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FORWARD_ONE, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_TO_BACK, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_TO_FRONT, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_LOCK_BACK, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_LOCK_FRONT, self.on_min_menu_item)
-        EVT_MENU(self.canvas, MIN_FRONTBACK_UNLOCK, self.on_min_menu_item)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_BACK_ONE)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FORWARD_ONE)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_TO_BACK)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_TO_FRONT)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_LOCK_BACK)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_LOCK_FRONT)
+        self.canvas.Bind(wx.EVT_MENU, self.on_min_menu_item, id=MIN_FRONTBACK_UNLOCK)
 
 
 
@@ -237,7 +263,7 @@ class miniatures_handler(base_layer_handler):
 
 
     def do_min_select_menu(self,min_list,pos):
-        self.min_select_menu = wxMenu()
+        self.min_select_menu = wx.Menu()
         self.min_select_menu.SetTitle("Select Miniature")
         menu_list = []
         loop_count = 0
@@ -255,30 +281,30 @@ class miniatures_handler(base_layer_handler):
                     last_string = string_split[len(string_split)-1]
                     self.min_select_menu.Append(menu_list[loop_count],'Unlabeled - ' + last_string[:len(last_string)-4])
 ###
-                EVT_MENU(self.canvas, menu_list[loop_count], self.min_selected)
+                self.canvas.Bind(wx.EVT_MENU, self.min_selected, id=menu_list[loop_count])
                 loop_count += 1
             self.canvas.PopupMenu(self.min_select_menu,pos)
         except:
             pass
 
     def min_selected(self,evt):
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
         self.canvas.send_map_data()
         self.canvas.layers['miniatures'].id = evt.GetId()
 
     def on_left_down(self, evt):
         session = self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
+        if (session.my_role() <> session.ROLE_GM) and (session.my_role() <> session.ROLE_PLAYER) and (session.use_roles()):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
             return
         min = 0
-        dc = wxClientDC(self.canvas)
+        dc = wx.ClientDC(self.canvas)
         self.canvas.PrepareDC(dc)
         dc.SetUserScale(self.canvas.layers['grid'].mapscale,self.canvas.layers['grid'].mapscale)
         pos = evt.GetLogicalPosition(dc)
         #pos = evt.GetPosition()
         if self.canvas.layers['miniatures'].id < 0:
-            self.min_list =  self.canvas.layers['miniatures'].find_miniature(pos,true)
+            self.min_list =  self.canvas.layers['miniatures'].find_miniature(pos, True)
         min = None
         if not self.sel_min:
             try:
@@ -315,16 +341,16 @@ class miniatures_handler(base_layer_handler):
                 self.sel_min.pos = cmpPoint(int(x),int(y))                                           #  Set the pos attribute
             else:
                 self.sel_min.pos = cmpPoint(int(pos.x),int(pos.y))
-            self.sel_min.selected = false
+            self.sel_min.selected = False
             self.sel_min = None
-            self.canvas.Refresh(false)
+            self.canvas.Refresh(False)
             self.canvas.send_map_data()
         elif min:
             if self.sel_min:
-                self.sel_min.selected = false
+                self.sel_min.selected = False
             self.sel_min = min
-            self.sel_min.selected = true
-            self.sel_min.draw(dc)
+            self.sel_min.selected = True
+            self.sel_min.draw(dc, self)
             self.lastx=pos.x
             self.lasty=pos.y
         del dc
@@ -338,11 +364,11 @@ class miniatures_handler(base_layer_handler):
     def on_right_down(self, evt):
         session = self.canvas.frame.session
         if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
             return
         min = 0
         self.sel_rmin = None
-        dc = wxClientDC(self.canvas)
+        dc = wx.ClientDC(self.canvas)
         self.canvas.PrepareDC(dc)
         dc.SetUserScale(self.canvas.layers['grid'].mapscale,self.canvas.layers['grid'].mapscale)
         pos = evt.GetLogicalPosition(dc)
@@ -374,8 +400,8 @@ class miniatures_handler(base_layer_handler):
                 self.sel_rmin = None
             elif self.sel_rmin:
                 self.sel_rmin = None
-                self.sel_rmin.selected = false
-                self.Refresh(false)
+                self.sel_rmin.selected = False
+                self.Refresh(False)
 
         else:                                          # if not min_list, i.e. we right-clicked on the map board
 
@@ -391,7 +417,7 @@ class miniatures_handler(base_layer_handler):
             self.canvas.layers['miniatures'].del_miniature(self.sel_rmin)
             self.canvas.send_map_data()
         elif id == MIN_TO_GAMETREE:
-            min_xml = self.sel_rmin.toxml(action="new",preserve_changed=1)
+            min_xml = self.sel_rmin.toxml(action="new")
             node_begin = "<nodehandler module='map_miniature_nodehandler' class='map_miniature_handler' name='"
 
             if self.sel_rmin.label:
@@ -400,10 +426,16 @@ class miniatures_handler(base_layer_handler):
                 node_begin += "Unnamed Miniature'"
 
             node_begin += ">"
-            gametree = self.canvas.frame.myopenrpg.get_component('tree')
+            gametree = self.canvas.frame.openrpg.get_component('tree')
             node_xml = node_begin + min_xml + '</nodehandler>'
-            print "Sending this XML to insert_xml:" + node_xml
+            #print "Sending this XML to insert_xml:" + node_xml
             gametree.insert_xml(node_xml)
+        elif id == MIN_SHOW_HIDE:
+            if self.sel_rmin.hide:
+                self.sel_rmin.hide = 0
+            else:
+                self.sel_rmin.hide = 1
+            self.canvas.send_map_data()
         elif id == MIN_FACING_NONE:
             self.sel_rmin.face = FACE_NONE
             self.canvas.send_map_data()
@@ -466,7 +498,7 @@ class miniatures_handler(base_layer_handler):
             self.canvas.send_map_data()
         elif id == MIN_PROP_DLG:
             dlg = min_edit_dialog(self.canvas.frame.GetParent(),self.sel_rmin)
-            if dlg.ShowModal() == wxID_OK:
+            if dlg.ShowModal() == wx.ID_OK:
                 self.canvas.send_map_data()
 
         elif id == MIN_BACK_ONE:
@@ -562,7 +594,7 @@ class miniatures_handler(base_layer_handler):
 
 
         elif id == MIN_FRONTBACK_UNLOCK:
-            print "Unlocked/ unstickified..."
+            #print "Unlocked/ unstickified..."
             if self.sel_rmin.zorder == MIN_STICKY_BACK:
                 self.sel_rmin.zorder = MIN_STICKY_BACK + 1
 
@@ -570,58 +602,58 @@ class miniatures_handler(base_layer_handler):
                 self.sel_rmin.zorder = MIN_STICKY_FRONT - 1
 
         elif id == MIN_LOCK_BACK:
-            print "lock back"
+            #print "lock back"
             self.sel_rmin.zorder = MIN_STICKY_BACK
 
         elif id == MIN_LOCK_FRONT:
-            print "lock front"
+            #print "lock front"
             self.sel_rmin.zorder = MIN_STICKY_FRONT
 
         # Pretty much, we always want to refresh when we go through here
         # This helps us remove the redundant self.Refresh() on EVERY menu event
         # that we process above.
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
         self.canvas.send_map_data()
 
 
-    def on_miniature(self,evt):
+    def on_miniature(self, evt):
         session = self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
+        if (session.my_role() != session.ROLE_GM) and (session.my_role() != session.ROLE_PLAYER) and (session.use_roles()):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use the miniature Layer")
             return
         min_url = self.min_url.GetValue()
         # build url
         if min_url == "" or min_url == "http://":
             return
         if min_url[:7] != "http://" :
-            min_url = "http://"+min_url
+            min_url = "http://" + min_url
         # make label
-        if self.auto_label:
+        if self.auto_label and min_url[-4:-3] == '.':
             start = min_url.rfind("/") + 1
             min_label = min_url[start:len(min_url)-4]
             if self.use_serial:
-                #self.canvas.layers['miniatures'].serial_number = self.canvas.layers['miniatures'].serial_number + 1 # we're 1 indexed
                 min_label = '%s %d' % ( min_label, self.canvas.layers['miniatures'].next_serial() )
         else:
             min_label = ""
         if self.min_url.FindString(min_url) == -1:
             self.min_url.Append(min_url)
         try:
-            self.canvas.layers['miniatures'].add_miniature(self.canvas.frame.session.get_next_id(),min_url,label=min_label)
+            id = 'mini-' + self.canvas.frame.session.get_next_id()
+            self.canvas.layers['miniatures'].add_miniature(id, min_url, label=min_label)
         except:
             # When there is an exception here, we should be decrementing the serial_number for reuse!!
             unablemsg= "Unable to load/resolve URL: " + min_url + " on resource \"" + min_label + "\"!!!\n\n"
-            print unablemsg
-            dlg =wxMessageDialog(self,unablemsg, 'Url not found',wxICON_EXCLAMATION)
+            #print unablemsg
+            dlg = wx.MessageDialog(self,unablemsg, 'Url not found',wx.ICON_EXCLAMATION)
             dlg.ShowModal()
             dlg.Destroy()
             self.canvas.layers['miniatures'].rollback_serial()
 
         self.canvas.send_map_data()
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
 
         #except Exception, e:
-            #wxMessageBox(str(e),"Miniature Error")
+            #wx.MessageBox(str(e),"Miniature Error")
 
     def on_label(self,evt):
         self.auto_label = not self.auto_label
@@ -632,13 +664,13 @@ class miniatures_handler(base_layer_handler):
     def on_min_list(self,evt):
         session = self.canvas.frame.session
         if (session.my_role() <> session.ROLE_GM):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
         #d = min_list_panel(self.frame.GetParent(),self.canvas.layers,"Miniature list")
         d = min_list_panel(self.canvas.frame,self.canvas.layers,"Miniature list")
-        if d.ShowModal() == wxID_OK:
+        if d.ShowModal() == wx.ID_OK:
             d.Destroy()
-        self.canvas.Refresh(false)
+        self.canvas.Refresh(False)
 
     def on_serial(self, evt):
         self.use_serial = not self.use_serial
@@ -648,4 +680,4 @@ class miniatures_handler(base_layer_handler):
         if id == MAP_REFRESH_MINI_URLS:                          # Note: this doesn't change the mini, so no need to update the map
             for mini in self.canvas.layers['miniatures'].miniatures:       #  For all minis
                 mini.set_bmp(load_img(mini.path,"miniature",mini))                    #  Reload their bmp member
-            self.canvas.Refresh(false)
+            self.canvas.Refresh(False)
