@@ -21,11 +21,11 @@
 # Author: Mark Tarrabain
 # Maintainer:
 # Version:
-#   $Id: region.py,v 1.4 2002/06/10 01:12:37 markt1964 Exp $
+#   $Id: region.py,v 1.10 2006/11/04 21:24:21 digitalxero Exp $
 #
-__version__ = "$Id: region.py,v 1.4 2002/06/10 01:12:37 markt1964 Exp $"
-
+__version__ = "$Id: region.py,v 1.10 2006/11/04 21:24:21 digitalxero Exp $"
 
+import sys
 
 
 # This class manages the edge of a polygon
@@ -95,7 +95,7 @@ class IPoint:
         if self.Y<b.Y or (self.Y==b.Y and self.X<b.X):
             return 1
         return 0
-    
+
     def greater(self,b):
         if self.Y>b.Y or (self.Y==b.Y and self.X>b.X):
             return 1
@@ -107,7 +107,7 @@ class IRect:
         self.left=999999
         self.top=999999
         self.right=-999999
-        self.bottom=-999999    
+        self.bottom=-999999
 
     def __str__(self):
         return "[ left:"+str(self.left)+", top:"+str(self.top)+", right:"+str(self.right)+", bottom:"+str(self.bottom)+" ]"
@@ -128,7 +128,7 @@ class IRect:
 
     def GetX(self):
         return self.left
-    
+
     def GetY(self):
         return self.top
 
@@ -169,7 +169,7 @@ class IRect:
 
     def intersect(self,rect):
         return IRect().make(max(self.left,rect.left),max(self.top,rect.top),min(self.right,rect.right),min(self.bottom,rect.bottom))
-                          
+
     def union(self,rect):
         return IRect().make(min(self.left,rect.left),min(self.top,rect.top),max(self.right,rect.right),max(self.bottom,rect.bottom))
 
@@ -194,12 +194,12 @@ class ISpan:
         self.y=ypos
 
     def __str__(self):
-        return "("+str(self.left)+" to "+str(self.right)+" at "+str(self.y)+")"
+        return "(" + str(self.left) + " to " + str(self.right) + " at " + str(self.y) + ")"
 
 
 # clipping rectangle class -- this class is a single node in a linked list
 # of rectangles that describe a region
-        
+
 class ClipRect:
     def __init__(self):
         self.next=None
@@ -211,7 +211,7 @@ class ClipRect:
 class ClipRectList:
     def __init__(self):
         self.first=None
-        self.last=None    
+        self.last=None
         self.count=0
 
     def __str__(self):
@@ -220,9 +220,9 @@ class ClipRectList:
             x+=" "+str(y.bounds)+" "
         x+="]"
         return x
-        
 
-#remove all rectangles from list        
+
+#remove all rectangles from list
     def Clear(self):
         while(self.first):
             rect=self.first
@@ -231,7 +231,7 @@ class ClipRectList:
         self.last=None
         self.count=0
 
-#add a new clipping rectangle to list        
+#add a new clipping rectangle to list
     def AddRect(self,rect):
         rect.prev=None
         rect.next=self.first
@@ -317,12 +317,12 @@ def _vSortCmp(rect1,rect2):
         return 1
     return 0
 
-    
-        
-    
-    
-        
-    
+
+
+
+
+
+
 # this is the class for which this whole source file is designed!
 # a Region is maintained as an optimal set of non-intersecting rectangles
 # whose union is the 2D area of interest.  At the end of each of the public
@@ -344,7 +344,7 @@ class IRegion:
     def Clear(self):
         self.crects.Clear()
 
-    def IsEmpty(self):
+    def isEmpty(self):
         if self.crects.first:
             return 0
         return 1
@@ -355,7 +355,7 @@ class IRegion:
         while p:
             dest.__AddRect(p.bounds)
             p=p.next
-    
+
     def __AddRect(self,rect):
         cr=self.__AllocClipRect()
         cr.bounds=IRect().make(rect.left,rect.top,rect.right,rect.bottom)
@@ -382,7 +382,7 @@ class IRegion:
                           IRect().make(p.bounds.left,rect.bottom+1,p.bounds.right,p.bounds.bottom)]
                 elif (p.bounds.top<rect.top and p.bounds.bottom>rect.top):
                     cnew=[IRect().make(p.bounds.left,p.bounds.top,p.bounds.right,rect.top-1),
-                          IRect().make(p.bounds.left,rect.top,p.bounds.right,p.bounds.bottom)]                    
+                          IRect().make(p.bounds.left,rect.top,p.bounds.right,p.bounds.bottom)]
                 elif (p.bounds.top<rect.bottom and p.bounds.bottom>rect.bottom):
                     cnew=[IRect().make(p.bounds.left,p.bounds.top,p.bounds.right,rect.bottom),
                           IRect().make(p.bounds.left,rect.bottom+1,p.bounds.right,p.bounds.bottom)]
@@ -455,7 +455,7 @@ class IRegion:
                 # the center rectangle is the one to remove, rectangles A,B,C and D
                 # get created.  If the rectangle is not in the middle, then the
                 # corresponding rectangle that should have been on "that side" of
-                # the current rectangle will have IsValid==false, so it will be
+                # the current rectangle will have IsValid==False, so it will be
                 # rejected.
                 cnew=[IRect().make(pcclip.bounds.left,hide.top,hide.left-1,hide.bottom),
                       IRect().make(hide.right+1,hide.top,pcclip.bounds.right,hide.bottom),
@@ -467,10 +467,10 @@ class IRegion:
                         newclip=self.__AllocClipRect()
                         newclip.bounds=i
                         newlist.AddRect(newclip)
-                    
+
         self.crects.last=None
         self.crects.StealRects(newlist)
-        self.Optimize()        
+        self.Optimize()
 
     def ExcludeRect(self,rect):
         self.__ExcludeRect(rect)
@@ -501,7 +501,7 @@ class IRegion:
                         newclip=self.__AllocClipRect()
                         newclip.bounds=i
                         newlist.AddRect(newclip)
-            
+
         self.crects.last = None
         self.crects.StealRects(newlist)
 
@@ -526,7 +526,7 @@ class IRegion:
         self.crects.StealRects(clist)
         self.Optimize()
 
-        
+
     def GetBounds(self):
         bounds=IRect()
         pcclip = self.crects.first
@@ -539,7 +539,7 @@ class IRegion:
     def Optimize(self):
         clist=self.crects.GetList()
         removed=[]
-        keepgoing = 1 
+        keepgoing = 1
         while len(clist)>1 and keepgoing:
             keepgoing=0
             clist.sort(lambda a,b:_vSortCmp(a,b))
@@ -551,7 +551,7 @@ class IRegion:
                     clist[i].bounds.bottom==clist[i+1].bounds.bottom):
                     clist[i].bounds.right=clist[i+1].bounds.right
                     x=clist[i+1]
-                    del clist[i+1]                    
+                    del clist[i+1]
                     self.crects.RemoveRect(x)
                     self.__FreeClipRect(x)
                     keepgoing=1
@@ -570,9 +570,9 @@ class IRegion:
                     self.crects.RemoveRect(x)
                     self.__FreeClipRect(x)
                     keepgoing=1
-                    
+
     def FromPolygon(self,polypt,mode):
-        thelist=self.scan_convert(polypt)
+        thelist=self.scan_Convert(polypt)
         for i in thelist:
             r=IRect().make(i.left,i.y,i.right,i.y)
             if mode:
@@ -591,31 +591,22 @@ class IRegion:
         return result
 
 
-
-
-
-
-
-
-
-            
-        
 #Portable implementation to scan-convert a polygon
 #from algoritm described in Section 3.6.3 of Foley, et al
 #returns a (possibly redundant) list of spans that comprise the polygon
 #this routine does not manipulate the current region in any way, but
 #is enclosed in this class to isolate its name from the global namespace
-#invoke via IRegion().scan_convert(polypt)
-        
-    def scan_convert(self,polypt):
+#invoke via IRegion().scan_Convert(polypt)
+
+    def scan_Convert(self,polypt):
         result=[]
         ET = {}  # edge table
         i = 0
         size = len(polypt)
         polylines=[] # list of lines in polygon
         y = -1
-        for i in range(size):
-            n = (i+1)%size
+        for i in xrange(size):
+            n = (i+1) % size
             if polypt[i].Y < polypt[n].Y:
                 e = Edge(polypt[i],polypt[n])
                 e.dir = 1 #moving top to bottom
@@ -625,31 +616,31 @@ class IRegion:
                 e.dir = -1 #moving bottom to top
                 polylines.append(e)
             elif polypt[i].X != polypt[n].X:  # any horizontal lines just get added directly
-                sx=min(polypt[i].X,polypt[n].X)
-                ex=max(polypt[i].X,polypt[n].X)
+                sx = min(polypt[i].X,polypt[n].X)
+                ex = max(polypt[i].X,polypt[n].X)
                 result.append(ISpan(sx,ex,polypt[i].Y))
         size = len(polylines)
-        for i in range(size):
-            if i==0 and polylines[i].dir==-1:
-                n=size-1
-            elif (polylines[i].dir==-1):
-                n=i-1
+        for i in xrange(size):
+            if i == 0 and polylines[i].dir == -1:
+                n = size-1
+            elif (polylines[i].dir == -1):
+                n = i-1
             else:
-                n=(i+1)%size
+                n = (i+1) % size
             if (polylines[i].dir != polylines[n].dir): #find out if at bottom end
-                polylines[i].bottom=1
-            if i==0 or polylines[i].starty<y:
+                polylines[i].bottom = 1
+            if i == 0 or polylines[i].starty < y:
                 y = polylines[i].starty
             if not ET.has_key(polylines[i].starty):
-                ET[polylines[i].starty]=[]
+                ET[polylines[i].starty] = []
             ET[polylines[i].starty].append(polylines[i]) #add to edge table, indexed by smaller y coordinate
         AET = [] #active edge table
-        while len(AET)>0 or len(ET)>0:
+        while len(AET) > 0 or len(ET) > 0:
             if ET.has_key(y): #if current y value has entries in edge tabe
                 AET.extend(ET[y]) # add them to active edge table
                 del ET[y] #and delete the entries in the edge table
             i = len(AET)-1
-            vals = [] 
+            vals = []
             while i >= 0:
                 if (AET[i].endy == y): #if at the end of this edge's run
                     if (AET[i].bottom): #check and see if we need one more point
@@ -657,18 +648,14 @@ class IRegion:
                     del AET[i] # y=end of edge, so remove it
                 i -= 1
             i = 0
-            while i<len(AET): # for every edge in AET
-                vals.append(AET[i].cx) # add x intercept 
+            while i < len(AET): # for every edge in AET
+                vals.append(AET[i].cx) # add x intercept
                 AET[i].advance() #and advance the edge one down
                 i += 1
             vals.sort()
             i = 0
-            while i<len(vals)-1:  #split vals[] array into pairs and output them
+            while i < len(vals)-1:  #split vals[] array into pairs and output them
                 result.append(ISpan(vals[i],vals[i+1],y))
                 i += 2
             y += 1
         return result
-
-    
-        
-    
