@@ -21,59 +21,30 @@
 # Author: OpenRPG Team
 # Maintainer:
 # Version:
-#   $Id: whiteboard_handler.py,v 1.26 2005/08/03 01:32:47 tdb30_ Exp $
+#   $Id: whiteboard_handler.py,v 1.36 2007/02/09 00:37:17 digitalxero Exp $
 #
 # Description: Whiteboard layer handler
 #
-__version__ = "$Id: whiteboard_handler.py,v 1.26 2005/08/03 01:32:47 tdb30_ Exp $"
+__version__ = "$Id: whiteboard_handler.py,v 1.36 2007/02/09 00:37:17 digitalxero Exp $"
 
 
 
 from base_handler import *
 
-DELETE_ALL_LINES= wxNewId()
-LINE_REMOVE = wxNewId()
-LINE_TITLE_HACK = wxNewId()
-LINE_COLOR = wxNewId()
-LINE_WIDTH = wxNewId()
-SELECT_ITEM = wxNewId()
-
-# Text properties menu variables
-TEXT_REMOVE = wxNewId()
-TEXT_TITLE_HACK = wxNewId()
-TEXT_POINT_SIZE = wxNewId()
-TEXT_WEIGHT = wxNewId()
-TEXT_STYLE = wxNewId()
-TEXT_STRING = wxNewId()
-TEXT_COLOR = wxNewId()
-TEXT_STYLES = [wxNORMAL, wxITALIC]
-TEXT_WEIGHTS = [wxNORMAL, wxBOLD]
-TEXT_OKAY = wxNewId()
-TEXT_PROPERTIES = wxNewId()
-
-#drawing modes (added by Snowdog 05-09-2003)
-DRAW_MODE = wxNewId()
-DRAW_FREEFORM = 1
-DRAW_POLYLINE = 2
-DRAW_TEXT = 3
-POLYLINE_END_TOLERANCE = 5
-LIVE_REFRESH = wxNewId()
-LIVE_POLYLINE_DEFAULT = 1
-
 class whiteboard_handler(base_layer_handler):
     def __init__(self, parent, id, canvas):
-        self.drawing_mode = DRAW_FREEFORM
+        self.drawing_mode = 'Freeform'
         self.line_string = "0,0;"
-        self.drawing = false
-        self.upperleft = wxPoint(0,0)
-        self.lowerright = wxPoint(0,0)
+        self.drawing = False
+        self.upperleft = wx.Point(0,0)
+        self.lowerright = wx.Point(0,0)
         #polyline drawing vars
         self.polypoints = 0
         self.lastpoint = None
         self.selected = None
         #text drawing vars
-        self.style = str(wxNORMAL)
-        self.weight = str(wxNORMAL)
+        self.style = str(wx.NORMAL)
+        self.weight = str(wx.NORMAL)
         self.pointsize = str(12)
         self.text_selected_item = None
         #self.r_h = RGBHex()
@@ -83,114 +54,115 @@ class whiteboard_handler(base_layer_handler):
 
     def build_ctrls(self):
         base_layer_handler.build_ctrls(self)
-        self.color_button = wxButton(self, LINE_COLOR, "Pen Color", style=wxBU_EXACTFIT)
-        self.drawmode_ctrl = wxChoice(self, DRAW_MODE, choices = ["Freeform", "Polyline","Text"])
+        self.color_button = wx.Button(self, wx.ID_ANY, "Pen Color", style=wx.BU_EXACTFIT)
+        self.color_button.SetBackgroundColour(wx.BLACK)
+        self.color_button.SetForegroundColour(wx.WHITE)
+
+        self.drawmode_ctrl = wx.Choice(self, wx.ID_ANY, choices = ["Freeform", "Polyline","Text"])
         self.drawmode_ctrl.SetSelection(0) #always start showing "Freeform"
-        self.live_refresh = wxCheckBox(self, LIVE_REFRESH, " Live Refresh")
-        self.live_refresh.SetValue(LIVE_POLYLINE_DEFAULT)
-        self.color_button.SetBackgroundColour(wxBLACK)
-        self.color_button.SetForegroundColour(wxWHITE)
-        dwidthList=['1','2','3','4','5','6','7','8','9','10']
-        self.widthList=wxChoice(self,LINE_WIDTH,size=wxSize(40, 20),choices=dwidthList, name="choice")
+
+        self.live_refresh = wx.CheckBox(self, wx.ID_ANY, " Live Refresh")
+        self.live_refresh.SetValue(True)
+
+        self.widthList= wx.Choice(self, wx.ID_ANY, size= wx.Size(40, 20), choices=['1','2','3','4','5','6','7','8','9','10'])
         self.widthList.SetSelection(0) #always start showing "1"
 
-        self.sizer.Prepend(wxSize(20,25),1)
-        self.sizer.Prepend(self.color_button, 0, wxEXPAND)
-        self.sizer.Prepend(wxSize(20,25))
-        self.sizer.Prepend(self.live_refresh, 0, wxEXPAND)
-        self.sizer.Prepend(wxSize(10,25))
-        self.sizer.Prepend(self.drawmode_ctrl, 0, wxEXPAND)
-        self.sizer.Prepend(wxStaticText(self, -1, "Drawing Mode: "),0,wxALIGN_CENTER)
-        self.sizer.Prepend(wxSize(10,25))
-        self.sizer.Prepend(self.widthList, 0, wxEXPAND)
-        self.sizer.Prepend(wxStaticText(self, -1, "Line Width: "),0,wxALIGN_CENTER)
-        EVT_MOTION(self, self.on_motion)
-        EVT_CHOICE(self, DRAW_MODE, self.check_draw_mode)
-        EVT_BUTTON(self, LINE_COLOR, self.on_pen_color)
-        EVT_CHOICE(self, LINE_WIDTH, self.on_pen_width)
+        self.sizer.Add(wx.StaticText(self, wx.ID_ANY, "Line Width: "),0,wx.ALIGN_CENTER)
+        self.sizer.Add(self.widthList, 0, wx.EXPAND)
+        self.sizer.Add(wx.Size(10,25))
+        self.sizer.Add(wx.StaticText(self, wx.ID_ANY, "Drawing Mode: "),0,wx.ALIGN_CENTER)
+        self.sizer.Add(self.drawmode_ctrl, 0, wx.EXPAND)
+        self.sizer.Add(wx.Size(10,25))
+        self.sizer.Add(self.live_refresh, 0, wx.EXPAND)
+        self.sizer.Add(wx.Size(20,25))
+        self.sizer.Add(self.color_button, 0, wx.EXPAND)
+        self.sizer.Add(wx.Size(20,25))
+
+        self.Bind(wx.EVT_MOTION, self.on_motion)
+        self.Bind(wx.EVT_CHOICE, self.check_draw_mode, self.drawmode_ctrl)
+        self.Bind(wx.EVT_BUTTON, self.on_pen_color, self.color_button)
+        self.Bind(wx.EVT_CHOICE, self.on_pen_width, self.widthList)
 
     def build_text_properties_menu(self, label="Text Properties"):
-        self.text_properties_dialog = wxDialog(self, -1, "Text Properties",  name = "Text Properties")
-        self.text_props_sizer = wxBoxSizer(wxVERTICAL)
+        self.text_properties_dialog = wx.Dialog(self, -1, "Text Properties",  name = "Text Properties")
+        self.text_props_sizer = wx.BoxSizer(wx.VERTICAL)
 
-        okay_boxer = wxBoxSizer(wxHORIZONTAL)
+        okay_boxer = wx.BoxSizer(wx.HORIZONTAL)
 
-        okay_button = wxButton(self.text_properties_dialog, TEXT_OKAY, "APPLY")
-        cancel_button = wxButton(self.text_properties_dialog, wxID_CANCEL,"CANCEL")
-        okay_boxer.Add(okay_button, 1, wxALIGN_LEFT)
-        okay_boxer.Add(wxSize(10,10))
-        okay_boxer.Add(cancel_button, 1, wxALIGN_RIGHT)
+        okay_button = wx.Button(self.text_properties_dialog, wx.ID_OK, "APPLY")
+        cancel_button = wx.Button(self.text_properties_dialog, wx.ID_CANCEL,"CANCEL")
+        okay_boxer.Add(okay_button, 1, wx.ALIGN_LEFT)
+        okay_boxer.Add(wx.Size(10,10))
+        okay_boxer.Add(cancel_button, 1, wx.ALIGN_RIGHT)
 
-        self.txt_boxer = wxBoxSizer(wxHORIZONTAL)
-        self.txt_static = wxStaticText(self.text_properties_dialog, -1, "Text: ")
-        self.text_control = wxTextCtrl(self.text_properties_dialog, TEXT_STRING, "", name = "Text: ")
-        self.txt_boxer.Add(self.txt_static,0,wxEXPAND)
-        self.txt_boxer.Add(wxSize(10,10))
-        self.txt_boxer.Add(self.text_control,1,wxEXPAND)
+        self.txt_boxer = wx.BoxSizer(wx.HORIZONTAL)
+        self.txt_static = wx.StaticText(self.text_properties_dialog, -1, "Text: ")
+        self.text_control = wx.TextCtrl(self.text_properties_dialog, wx.ID_ANY, "", name = "Text: ")
+        self.txt_boxer.Add(self.txt_static,0,wx.EXPAND)
+        self.txt_boxer.Add(wx.Size(10,10))
+        self.txt_boxer.Add(self.text_control,1,wx.EXPAND)
 
-        self.point_boxer = wxBoxSizer(wxHORIZONTAL)
-#        self.point_static = wxStaticText(self.text_properties_dialog, -1, "Text Size: ")
-#        self.point_control = wxSpinCtrl(self.text_properties_dialog,TEXT_POINT_SIZE, value = "12",min = 1, initial = 12, name = "Font Size: ")
+        self.point_boxer = wx.BoxSizer(wx.HORIZONTAL)
+        self.point_static = wx.StaticText(self.text_properties_dialog, -1, "Text Size: ")
+        self.point_control = wx.SpinCtrl(self.text_properties_dialog, wx.ID_ANY, value = "12",min = 1, initial = 12, name = "Font Size: ")
 
-#        self.point_boxer.Add(self.point_static,1,wxEXPAND)
-#        self.point_boxer.Add(wxSize(10,10))
-#        self.point_boxer.Add(self.point_control,0,wxEXPAND)
+        self.point_boxer.Add(self.point_static,1,wx.EXPAND)
+        self.point_boxer.Add(wx.Size(10,10))
+        self.point_boxer.Add(self.point_control,0,wx.EXPAND)
 
-        self.text_color_control = wxButton(self.text_properties_dialog, TEXT_COLOR, "TEXT COLOR",style=wxBU_EXACTFIT)
+        self.text_color_control = wx.Button(self.text_properties_dialog, wx.ID_ANY, "TEXT COLOR",style=wx.BU_EXACTFIT)
 
-#        self.weight_control = wxRadioBox(self.text_properties_dialog, TEXT_WEIGHT, "Weight",choices = ["Normal","Bold"])
-#        self.style_control = wxRadioBox(self.text_properties_dialog, TEXT_STYLE, "Style",choices = ["Normal", "Italic"])
+        self.weight_control = wx.RadioBox(self.text_properties_dialog, wx.ID_ANY, "Weight", choices = ["Normal","Bold"])
+        self.style_control = wx.RadioBox(self.text_properties_dialog, wx.ID_ANY, "Style", choices = ["Normal", "Italic"])
 
-        self.text_props_sizer.Add(self.txt_boxer,0,wxEXPAND)
-        self.text_props_sizer.Add(self.point_boxer,0, wxEXPAND)
-#        self.text_props_sizer.Add(self.weight_control,0, wxEXPAND)
-#        self.text_props_sizer.Add(self.style_control,0, wxEXPAND)
-        self.text_props_sizer.Add(self.text_color_control, 0, wxEXPAND)
-        self.text_props_sizer.Add(wxSize(10,10))
-        self.text_props_sizer.Add(okay_boxer,0, wxEXPAND)
+        self.text_props_sizer.Add(self.txt_boxer,0,wx.EXPAND)
+        self.text_props_sizer.Add(self.point_boxer,0, wx.EXPAND)
+        self.text_props_sizer.Add(self.weight_control,0, wx.EXPAND)
+        self.text_props_sizer.Add(self.style_control,0, wx.EXPAND)
+        self.text_props_sizer.Add(self.text_color_control, 0, wx.EXPAND)
+        self.text_props_sizer.Add(wx.Size(10,10))
+        self.text_props_sizer.Add(okay_boxer,0, wx.EXPAND)
 
         self.text_props_sizer.Fit(self)
         self.text_properties_dialog.SetSizer(self.text_props_sizer)
         self.text_properties_dialog.Fit()
-        EVT_BUTTON(self.text_properties_dialog,TEXT_COLOR, self.on_text_color)
-        EVT_BUTTON(self.text_properties_dialog,TEXT_OKAY,self.on_text_properties)
-#        EVT_MENU(self.canvas,TEXT_POINT_SIZE,self.on_text_properties)
-#        EVT_MENU(self.canvas,TEXT_WEIGHT,self.on_text_properties)
-#        EVT_MENU(self.canvas,TEXT_STYLE,self.on_text_properties)
+        self.text_properties_dialog.Bind(wx.EVT_BUTTON, self.on_text_color, self.text_color_control)
+        self.text_properties_dialog.Bind(wx.EVT_BUTTON, self.on_text_properties, okay_button)
 
-#        self.text_properties_dialog.Destroy()
-        pass
+        #self.text_properties_dialog.Destroy()
 
-    def build_menu(self,label = "Whiteboard"):
+
+    def build_menu(self, label = "Whiteboard"):
         base_layer_handler.build_menu(self,label)
         self.main_menu.AppendSeparator()
-        self.main_menu.Append(LINE_COLOR,"&Change Pen Color")
-        self.main_menu.Append(DELETE_ALL_LINES,"Delete &All Lines")
 
-        EVT_MENU(self.canvas,LINE_COLOR,self.on_pen_color)
-        EVT_MENU(self.canvas,DELETE_ALL_LINES,self.delete_all_lines)
+        item = wx.MenuItem(self.main_menu, wx.ID_ANY, "&Change Pen Color", "Change Pen Color")
+        self.canvas.Bind(wx.EVT_MENU, self.on_pen_color, item)
+        self.main_menu.AppendItem(item)
 
-        self.line_menu = wxMenu()
-        if wxPlatform == '__WXMSW__':
-            self.line_menu.SetTitle(label)
-        else:
-            self.line_menu.Append(LINE_TITLE_HACK,label)
-            self.line_menu.AppendSeparator()
+        item = wx.MenuItem(self.main_menu, wx.ID_ANY, "Delete &All Lines", "Delete All Lines")
+        self.canvas.Bind(wx.EVT_MENU, self.delete_all_lines, item)
+        self.main_menu.AppendItem(item)
 
-        self.line_menu.Append(LINE_REMOVE,"&Remove")
-        EVT_MENU(self.canvas, LINE_REMOVE, self.on_line_menu_item)
 
-        self.text_menu = wxMenu()
-        if wxPlatform == '__WXMSW__':
-            self.text_menu.SetTitle(label)
-        else:
-            self.text_menu.Append(TEXT_TITLE_HACK,label)
-            self.text_menu.AppendSeparator()
+        self.line_menu = wx.Menu("Whiteboard Line")
+        self.line_menu.SetTitle("Whiteboard Line")
 
-        self.text_menu.Append(TEXT_PROPERTIES,"&Properties")
-        self.text_menu.Append(TEXT_REMOVE,"&Remove")
-        EVT_MENU(self.canvas, TEXT_PROPERTIES, self.text_menu_properties)
-        EVT_MENU(self.canvas, TEXT_REMOVE, self.on_text_menu_item)
+        item = wx.MenuItem(self.line_menu, wx.ID_ANY, "&Remove", "Remove")
+        self.canvas.Bind(wx.EVT_MENU, self.on_line_menu_item, item)
+        self.line_menu.AppendItem(item)
+
+
+        self.text_menu = wx.Menu("Whiteboard Text")
+        self.text_menu.SetTitle("Whiteboard Text")
+
+        item = wx.MenuItem(self.text_menu, wx.ID_ANY, "&Properties", "Properties")
+        self.canvas.Bind(wx.EVT_MENU, self.get_text_properties, item)
+        self.text_menu.AppendItem(item)
+
+        item = wx.MenuItem(self.text_menu, wx.ID_ANY, "&Remove", "Remove")
+        self.canvas.Bind(wx.EVT_MENU, self.on_text_menu_item, item)
+        self.text_menu.AppendItem(item)
 
 
     def do_line_menu(self,pos):
@@ -202,20 +174,26 @@ class whiteboard_handler(base_layer_handler):
 
     def on_text_properties(self,evt):
         text_string = self.text_control.GetValue()
-        style = wxNORMAL
-        weight = wxNORMAL
-        point = 12
+        if self.style_control.GetStringSelection() == 'Normal':
+            style = wx.NORMAL
+        else:
+            style = wx.ITALIC
+        if self.weight_control.GetStringSelection() == 'Normal':
+            weight = wx.NORMAL
+        else:
+            weight = wx.BOLD
+        point = str(self.point_control.GetValue())
         c = self.text_color_control.GetForegroundColour()
         color = self.canvas.layers['whiteboard'].r_h.hexstring(c.Red(), c.Green(), c.Blue())
-#        self.text_selected_item.set_text_props(text_string, style, point, weight,color)
+        self.text_selected_item.set_text_props(text_string, style, point, weight, color)
         self.text_to_xml()
-        self.text_properties_dialog.Show(FALSE)
-        self.text_selected_item.selected = false
+        self.text_properties_dialog.Show(False)
+        self.text_selected_item.selected = False
         self.text_selected_item = None
 
     def on_text_color(self,evt):
-        dlg = wxColourDialog(self)
-        if dlg.ShowModal() == wxID_OK:
+        dlg = wx.ColourDialog(self)
+        if dlg.ShowModal() == wx.ID_OK:
             c = dlg.GetColourData()
             self.text_color_control.SetForegroundColour(c.GetColour())
         dlg.Destroy()
@@ -226,57 +204,65 @@ class whiteboard_handler(base_layer_handler):
         xml_str += "</whiteboard></map>"
 
         self.canvas.frame.session.send(xml_str)
-        self.canvas.Refresh(false)
-
-    def get_text_properties(self, pos, item):
+        self.canvas.Refresh(False)
 
+    def get_text_properties(self, event=None):
         self.text_color_control.SetForegroundColour(self.text_selected_item.textcolor)
         self.text_control.SetValue(self.text_selected_item.text_string)
-#        self.point_control.SetValue(int(self.text_selected_item.pointsize))
+        self.point_control.SetValue(int(self.text_selected_item.pointsize))
+
+        if int(self.text_selected_item.weight) == wx.NORMAL:
+            self.weight_control.SetSelection(0)
+        else:
+            self.weight_control.SetSelection(1)
+
+        if int(self.text_selected_item.style) == wx.NORMAL:
+            self.style_control.SetSelection(0)
+        else:
+            self.style_control.SetSelection(1)
+
 
         self.text_properties_dialog.Center()
-        self.text_properties_dialog.Show(TRUE)
+        self.text_properties_dialog.Show(True)
 
-
-    def do_text_menu(self,pos):
-        self.canvas.PopupMenu(self.text_menu, pos)
+    def do_text_menu(self, pos, items=None):
+        if items == None:
+            self.canvas.PopupMenu(self.text_menu)
+        else:
+            menu = wx.Menu()
+            self.ItemList = items
+            self.tmpPos = pos
+            for i in xrange(len(items)):
+                menu.Append(i, items[i].text_string)
+                self.canvas.Bind(wx.EVT_MENU, self.onItemSelect, id=i)
+            self.canvas.PopupMenu(menu)
         return
 
-    def text_menu_properties(self, text_list):
-        self.selection_list = text_list
-        self.text_select_menu = None
-        self.text_select_menu = wxMenu()
-        self.text_select_menu.SetTitle("Which item?")
-        menu_list = []
-        loop_count = 0
-        try:
-            for m in text_list:
-                menu_list.append(loop_count)
-                self.text_select_menu.Append(menu_list[loop_count],m.text_string)
-                EVT_MENU(self.canvas, menu_list[loop_count] , self.item_selected)
-                loop_count += 1
-            item = self.canvas.PopupMenu(self.text_select_menu,pos)
-            return self.item_selection
-        except Exception, e:
-            print "Error found in do_text_menu!",e
-
+    def onItemSelect(self, evt):
+        id = evt.GetId()
+        self.text_selected_item = self.ItemList[id]
+        self.text_selected_item.selected = True
+        if self.tmpPos == 'right':
+            self.canvas.PopupMenu(self.text_menu)
+        self.ItemList = None
+        self.tmpPos = None
 
     def on_right_down(self,evt):
         line = 0
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC(self.canvas)
+        dc = wx.ClientDC(self.canvas)
         self.canvas.PrepareDC(dc)
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
-        if self.drawing_mode == DRAW_TEXT:
-            self.on_text_right_down(evt,dc)
-        elif (self.drawing_mode == DRAW_FREEFORM) or (self.drawing_mode == DRAW_POLYLINE):
+        if self.drawing_mode == 'Text':
+            self.on_text_right_down(evt, dc)
+        elif (self.drawing_mode == 'Freeform') or (self.drawing_mode == 'Polyline'):
             line_list = self.canvas.layers['whiteboard'].find_line(pos)
             if line_list:
                 self.sel_rline = self.canvas.layers['whiteboard'].get_line_by_id(line_list.id)
                 if self.sel_rline:
                     self.do_line_menu(evt.GetPosition())
-                    self.canvas.Refresh(false)
+                    self.canvas.Refresh(False)
             else:
                 base_layer_handler.on_right_down(self,evt)
         else:
@@ -284,10 +270,10 @@ class whiteboard_handler(base_layer_handler):
         del dc
 
     def on_pen_color(self,evt):
-        data = wxColourData()
-        data.SetChooseFull(true)
-        dlg = wxColourDialog(self.canvas, data)
-        if dlg.ShowModal() == wxID_OK:
+        data = wx.ColourData()
+        data.SetChooseFull(True)
+        dlg = wx.ColourDialog(self.canvas, data)
+        if dlg.ShowModal() == wx.ID_OK:
             data = dlg.GetColourData()
             color = data.GetColour()
             self.canvas.layers['whiteboard'].setcolor(color)
@@ -300,41 +286,36 @@ class whiteboard_handler(base_layer_handler):
 
     def delete_all_lines(self,evt):
         session = self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM) and (session.use_roles()):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
+        if (session.my_role() != session.ROLE_GM) and (session.use_roles()):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be a GM to use this feature")
             return
-        for m in range(len(self.canvas.layers['whiteboard'].lines)):
-            self.canvas.layers['whiteboard'].del_line(self.canvas.layers['whiteboard'].lines[0])
 
-    def on_line_menu_item(self,evt):
-        id = evt.GetId()
-        if id == LINE_REMOVE:
-            dc = self.create_dc()
-            self.un_highlight(dc)
-            self.canvas.layers['whiteboard'].del_line(self.sel_rline)
-            self.selected = None
-#            self.send_map_data()
+        self.canvas.layers['whiteboard'].del_all_lines()
+        dc = self.create_dc()
+        self.un_highlight(dc)
+        self.selected = None
+        del dc
 
-    def on_text_menu_item(self,evt):
-        id = evt.GetId()
-        if id == TEXT_REMOVE:
-            dc = self.create_dc()
-            self.un_highlight(dc)
-            self.canvas.layers['whiteboard'].del_text(self.selected)
-            self.selected = None
-#            self.send_map_data()
+    def on_line_menu_item(self, evt):
+        dc = self.create_dc()
+        self.un_highlight(dc)
+        self.canvas.layers['whiteboard'].del_line(self.sel_rline)
+        self.selected = None
+        del dc
+
+    def on_text_menu_item(self, evt):
+        dc = self.create_dc()
+        self.un_highlight(dc)
+        self.canvas.layers['whiteboard'].del_text(self.selected)
+        self.selected = None
+        del dc
 
     # Check Draw Mode
     # Queries the GUI to see what mode to draw in
     # 05-09-2003 Snowdog
 
     def check_draw_mode(self, evt=None):
-        if self.drawmode_ctrl.GetSelection() == 0:
-            self.drawing_mode = DRAW_FREEFORM
-        elif self.drawmode_ctrl.GetSelection() == 1:
-            self.drawing_mode = DRAW_POLYLINE
-        elif self.drawmode_ctrl.GetSelection() == 2:
-            self.drawing_mode = DRAW_TEXT
+        self.drawing_mode = self.drawmode_ctrl.GetStringSelection()
 
         #because mode can be changed while a polyline is being created
         #clear the current linestring and reset the polyline data
@@ -350,21 +331,17 @@ class whiteboard_handler(base_layer_handler):
     # drawing modes freeform vs polyline
     # 05-09-2003  Snowdog
     def on_left_down(self,evt):
-        if self.drawing == false: self.check_draw_mode()
-        if self.drawing_mode == DRAW_FREEFORM:
+        if not self.drawing:
+            self.check_draw_mode()
+
+        if self.drawing_mode == 'Freeform':
             #Freeform mode ignores the inital down click
             pass
-###
-###  Commenting this out to revert to old drawing method.  I will later
-###  Add an option to choose between the two methods (click and hold, or
-###  click draw click.
-###
-###            if not self.drawing:
-###                self.drawing = true
-###                self.line_string = ""
-        elif self.drawing_mode == DRAW_POLYLINE:
+
+        elif self.drawing_mode == 'Polyline':
             self.polyline_add_point( evt )
-        elif self.drawing_mode == DRAW_TEXT:
+
+        elif self.drawing_mode == 'Text':
             self.on_text_left_down(evt)
 
 
@@ -372,16 +349,12 @@ class whiteboard_handler(base_layer_handler):
     # Added handling for double clicks within the map
     # 05-09-2003  Snowdog
     def on_left_dclick(self, evt):
-        if self.drawing_mode == DRAW_FREEFORM:
+        if self.drawing_mode == 'Freeform':
             #Freeform mode ignores the double click
             pass
-#
-# Temprarily commenting this out.  Will be using it later.
-#
-#            self.on_freeform_left_up( evt )
-        elif self.drawing_mode == DRAW_POLYLINE:
+        elif self.drawing_mode == 'Polyline':
             self.polyline_last_point( evt )
-        elif self.drawing_mode == DRAW_TEXT:
+        elif self.drawing_mode == 'Text':
             pass
 
 
@@ -390,17 +363,13 @@ class whiteboard_handler(base_layer_handler):
     # drawing modes freeform vs polyline
     # 05-09-2003  Snowdog
     def on_left_up(self,evt):
-        if self.drawing_mode == DRAW_FREEFORM:
+        if self.drawing_mode == 'Freeform':
             self.on_freeform_left_up(evt)
-#
-#  Line to be added later
-#
-#           pass
-        elif self.drawing_mode == DRAW_POLYLINE:
+        elif self.drawing_mode == 'Polyline':
             #Polyline mode relies on the down click
             #not the mouse button release
             pass
-        elif self.drawing_mode == DRAW_TEXT:
+        elif self.drawing_mode == 'Text':
             pass
 
 
@@ -410,14 +379,14 @@ class whiteboard_handler(base_layer_handler):
     # 05-09-2003  Snowdog
     def on_motion(self,evt):
         session = self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM) \
-            and (session.my_role()<>session.ROLE_PLAYER) \
+        if (session.my_role() != session.ROLE_GM) \
+            and (session.my_role()!=session.ROLE_PLAYER) \
             and (session.use_roles()):
-                return
-        if self.drawing_mode == DRAW_FREEFORM:
+            return
+        if self.drawing_mode == 'Freeform':
             if evt.m_leftDown:
                 self.freeform_motion(evt)
-        elif self.drawing_mode == DRAW_POLYLINE:
+        elif self.drawing_mode == 'Polyline':
             if self.drawing:
                 self.polyline_preview( evt )
 
@@ -437,14 +406,14 @@ class whiteboard_handler(base_layer_handler):
 
     def create_dc(self):
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         return dc
 
     def highlight(self,hit,dc):
         if self.selected:
-            self.selected.highlight(false)
+            self.selected.highlight(False)
             self.selected.draw(self.wb,dc)
         self.selected = hit[0]
         self.selected.highlight()
@@ -452,7 +421,7 @@ class whiteboard_handler(base_layer_handler):
 
     def un_highlight(self,dc):
         if self.selected:
-            self.selected.highlight(false)
+            self.selected.highlight(False)
             self.selected.draw(self.wb,dc)
 
     # Polyline Add Point
@@ -461,7 +430,7 @@ class whiteboard_handler(base_layer_handler):
     def polyline_add_point(self, evt):
 
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
@@ -480,7 +449,7 @@ class whiteboard_handler(base_layer_handler):
         #if this point doens't end the line
         #add a new point into the line string
         if not self.polyline_end_check( pos ):
-            if self.drawing == true:
+            if self.drawing == True:
                 self.polypoints += 1 #add one to the point counter.
                 self.line_string += `pos.x` + "," + `pos.y` + ";"
                 self.canvas.layers['whiteboard'].draw_working_line(dc,self.line_string)
@@ -492,9 +461,9 @@ class whiteboard_handler(base_layer_handler):
                 self.upperleft.y = pos.y
                 self.lowerright.x = pos.x
                 self.lowerright.y = pos.y
-                self.drawing = true
+                self.drawing = True
         else: #end of line. Send and reset vars for next line
-            self.drawing = false
+            self.drawing = False
 
             if self.polypoints < 2:
                 #not enough points to form a line. Ignore line
@@ -503,9 +472,9 @@ class whiteboard_handler(base_layer_handler):
                 #have enough points to create valid line
                 #check to role to make sure user can draw at all....
                 session = self.canvas.frame.session
-                if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-                    self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
-                    self.canvas.Refresh(false)
+                if (session.my_role() != session.ROLE_GM) and (session.my_role()!=session.ROLE_PLAYER) and (session.use_roles()):
+                    self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
+                    self.canvas.Refresh(False)
                 else:
                     #user allowed to draw on whiteboard.. send polyline
                     line = self.canvas.layers['whiteboard'].add_line(self.line_string,self.upperleft,self.lowerright)
@@ -525,11 +494,11 @@ class whiteboard_handler(base_layer_handler):
     def polyline_last_point(self, evt):
 
         #if we haven't started a line already. Ignore the click
-        if self.drawing != true:
+        if self.drawing != True:
             return
 
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
@@ -551,7 +520,7 @@ class whiteboard_handler(base_layer_handler):
         self.canvas.layers['whiteboard'].draw_working_line(dc,self.line_string)
 
         #end of line. Send and reset vars for next line
-        self.drawing = false
+        self.drawing = False
 
         if self.polypoints < 2:
             #not enough points to form a line. Ignore line
@@ -560,9 +529,9 @@ class whiteboard_handler(base_layer_handler):
             #have enough points to create valid line
             #check to role to make sure user can draw at all....
             session = self.canvas.frame.session
-            if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-                self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
-                self.canvas.Refresh(false)
+            if (session.my_role() != session.ROLE_GM) and (session.my_role()!=session.ROLE_PLAYER) and (session.use_roles()):
+                self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
+                self.canvas.Refresh(False)
             else:
                 #user allowed to draw on whiteboard.. send polyline
                 line = self.canvas.layers['whiteboard'].add_line(self.line_string,self.upperleft,self.lowerright)
@@ -588,11 +557,11 @@ class whiteboard_handler(base_layer_handler):
         # if it is then the line has been completed and should be sent to the map just like
         # the original freeform version is. A line with fewer than 2 points should be ignored
         x_in = y_in = 0
-        tol = POLYLINE_END_TOLERANCE
+        tol = 5
 
         #first point check
         if type(self.lastpoint) == type(None):
-            self.lastpoint = wxPoint(pos.x,pos.y)
+            self.lastpoint = wx.Point(pos.x,pos.y)
             return 0 #not end of line
 
 
@@ -607,7 +576,7 @@ class whiteboard_handler(base_layer_handler):
             self.lastpoint = None
             return 1
 
-        #if we've reached here the point is NOT a terminal point. Reset the lastpoint and return false
+        #if we've reached here the point is NOT a terminal point. Reset the lastpoint and return False
         self.lastpoint.x = pos.x
         self.lastpoint.y = pos.y
         return 0
@@ -619,7 +588,7 @@ class whiteboard_handler(base_layer_handler):
     # from the last point to mouse position
     # 05-09-2003  Snowdog
     def polyline_preview(self, evt):
-        if self.drawing != true:
+        if self.drawing != True:
             #not enough points to form a line. Ignore line
             return
 
@@ -628,7 +597,7 @@ class whiteboard_handler(base_layer_handler):
             return
 
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
@@ -648,7 +617,7 @@ class whiteboard_handler(base_layer_handler):
         temp_string = self.line_string
         temp_string += `pos.x` + "," + `pos.y` + ";"
         self.canvas.layers['whiteboard'].draw_working_line(dc,temp_string)
-        self.canvas.Refresh(true)
+        self.canvas.Refresh(True)
 
 
 
@@ -659,7 +628,7 @@ class whiteboard_handler(base_layer_handler):
 #        if not self.drawing:
 #            return
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
@@ -674,7 +643,7 @@ class whiteboard_handler(base_layer_handler):
             self.lowerright.y = pos.y
 
         if evt.m_leftDown:
-            if self.drawing == true:
+            if self.drawing == True:
                 self.line_string += `pos.x` + "," + `pos.y` + ";"
                 self.canvas.layers['whiteboard'].draw_working_line(dc,self.line_string)
             else:
@@ -683,7 +652,7 @@ class whiteboard_handler(base_layer_handler):
                 self.upperleft.y = pos.y
                 self.lowerright.x = pos.x
                 self.lowerright.y = pos.y
-            self.drawing = true    
+            self.drawing = True
         del dc
 
 
@@ -691,12 +660,12 @@ class whiteboard_handler(base_layer_handler):
     # to allow alternate drawing method to be used
     # 05-09-2003  Snowdog
     def on_freeform_left_up(self,evt):
-        if self.drawing == true:
-            self.drawing = false
+        if self.drawing == True:
+            self.drawing = False
             session = self.canvas.frame.session
-            if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-                self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
-                self.canvas.Refresh(false)
+            if (session.my_role() != session.ROLE_GM) and (session.my_role()!=session.ROLE_PLAYER) and (session.use_roles()):
+                self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
+                self.canvas.Refresh(False)
                 return
         #self.id +=1
             line = self.canvas.layers['whiteboard'].add_line(self.line_string,self.upperleft,self.lowerright)
@@ -704,7 +673,7 @@ class whiteboard_handler(base_layer_handler):
             for m in range(30):
                 line.highlight()
                 line.draw(self.wb,dc)
-                line.highlight(false)
+                line.highlight(False)
                 line.draw(self.wb,dc)
             del dc
             self.upperleft.x = self.upperleft.y = 0
@@ -712,64 +681,50 @@ class whiteboard_handler(base_layer_handler):
 
     def on_text_left_down(self, evt):
         session = self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
-            self.canvas.Refresh(false)
+        if (session.my_role() != session.ROLE_GM) and (session.my_role()!=session.ROLE_PLAYER) and (session.use_roles()):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
+            self.canvas.Refresh(False)
             return
         scale = self.canvas.layers['grid'].mapscale
-        dc = wxClientDC( self.canvas )
+        dc = wx.ClientDC( self.canvas )
         self.canvas.PrepareDC( dc )
         dc.SetUserScale(scale,scale)
         pos = evt.GetLogicalPosition(dc)
 
         test_text = self.canvas.layers['whiteboard'].hit_test_text(pos,dc)
         if len(test_text) > 0:
-            if len(test_text)>1:
-                self.text_selected_item = self.do_text_menu(pos, test_text)
-                self.text_selected_item.selected=TRUE
+            if len(test_text) > 1:
+                self.do_text_menu('left', test_text)
             else:
                 self.text_selected_item = test_text[0]
-                self.text_selected_item.selected=TRUE
-            self.canvas.Refresh(true)
+                self.text_selected_item.selected = True
+            self.canvas.Refresh(True)
 
         else:
             if self.text_selected_item == None:
-                dlg = wxTextEntryDialog(self,"Text to add to whiteboard", caption="Enter text",defaultValue=" ")
-                if dlg.ShowModal() == wxID_OK:
+                dlg = wx.TextEntryDialog(self,"Text to add to whiteboard", caption="Enter text",defaultValue=" ")
+                if dlg.ShowModal() == wx.ID_OK:
                     text_string = dlg.GetValue()
                     self.canvas.layers['whiteboard'].add_text(text_string,pos, self.style, self.pointsize, self.weight, self.canvas.layers['whiteboard'].color)
             else:
                 self.text_selected_item.posx = pos.x
                 self.text_selected_item.posy = pos.y
                 self.text_to_xml()
-                self.text_selected_item.selected = false
+                self.text_selected_item.selected = False
                 self.text_selected_item = None
         del dc
 
-    def on_text_right_down(self,evt,dc):
+    def on_text_right_down(self, evt, dc):
         session = self.canvas.frame.session
-        if (session.my_role() <> session.ROLE_GM) and (session.my_role()<>session.ROLE_PLAYER) and (session.use_roles()):
-            self.top_frame.myopenrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
-            self.canvas.Refresh(false)
+        if (session.my_role() != session.ROLE_GM) and (session.my_role()!=session.ROLE_PLAYER) and (session.use_roles()):
+            self.top_frame.openrpg.get_component("chat").InfoPost("You must be either a player or GM to use this feature")
+            self.canvas.Refresh(False)
             return
         pos = evt.GetLogicalPosition(dc)
-        test_text = self.canvas.layers['whiteboard'].hit_test_text(pos,dc)
+        test_text = self.canvas.layers['whiteboard'].hit_test_text(pos, dc)
         if len(test_text) > 0:
-            if len(test_text)>1:
-                self.text_selected_item = self.do_text_menu(pos, test_text)
-                text_selected_item.selected=TRUE
+            if len(test_text) > 1:
+                self.do_text_menu('right', test_text)
             else:
-                self.do_text_menu(evt.GetPosition())
                 self.text_selected_item = test_text[0]
-#            self.get_text_properties(pos, self.text_selected_item)
-        else:
-            pass
-#            data = wxFontData()
-#            test = wxFontDialog(self,data)
-#            if test.ShowModal() == wxID_OK:
-#                fontdata = test.GetFontData()
-#                font = fontdata.GetChosenFont()
-#                self.Refresh()
-#                self.canvas.layers['whiteboard'].set_font(font)
-#        self.canvas.layers['whiteboard'].add_text(self.text_string, pos)
-
+                self.do_text_menu('right')
