@@ -92,6 +92,9 @@ class Node:
         else:
             return 0
 
+    def getChildren(self):
+        return self.childNodes
+
     def _get_firstChild(self):
         if self.hasChildNodes():
             return self.childNodes[0]
@@ -250,7 +253,7 @@ class AttributeList:
     def copy(self):
         clone = AttributeList(self._attrs.copy(),self._attrsNS.copy())
         return clone
-        
+
     def item(self, index):
         try:
             return self[self.keys()[index]]
@@ -264,7 +267,7 @@ class AttributeList:
     def itemsNS(self):
         return map(lambda node: ((node.URI, node.localName), node.value),
                    self._attrs.values())
-    
+
     def keys(self):
         return self._attrs.keys()
 
@@ -280,7 +283,7 @@ class AttributeList:
     def __cmp__(self, other):
         if self._attrs is getattr(other, "_attrs", None):
             return 0
-        else: 
+        else:
             return cmp(id(self), id(other))
 
     #FIXME: is it appropriate to return .value?
@@ -454,12 +457,12 @@ class Comment(Node):
     def writexml(self, writer, tabs=0):
         writer.write("<!--%s-->" % self.data)
 
-    def cloneNode(self, deep=0):                  
-        newNode = Comment(self.data)       
+    def cloneNode(self, deep=0):
+        newNode = Comment(self.data)
         if deep:
-            self.deep_clone(newNode)            
-        return newNode   
-   
+            self.deep_clone(newNode)
+        return newNode
+
 
 class ProcessingInstruction(Node):
     nodeType = Node.PROCESSING_INSTRUCTION_NODE
@@ -473,11 +476,11 @@ class ProcessingInstruction(Node):
     def writexml(self, writer, tabs=0):
         writer.write("<?%s %s?>" % (self.target, self.data))
 
-    def cloneNode(self, deep=0):                  
-        newNode = ProcessingInstruction(self.target, self.data)       
+    def cloneNode(self, deep=0):
+        newNode = ProcessingInstruction(self.target, self.data)
         if deep:
-            self.deep_clone(newNode)            
-        return newNode    
+            self.deep_clone(newNode)
+        return newNode
 
 class Text(Node):
     nodeType = Node.TEXT_NODE
@@ -497,19 +500,19 @@ class Text(Node):
 
     def writexml(self, writer, tabs=0):
         _write_data(writer, self.data)
-    
+
     def _get_nodeValue(self):
         return str(self.nodeValue)
-    
+
     def _set_nodeValue(self,data):
         self.data = self.nodeValue = data
-        
-    def cloneNode(self, deep=0):                  
-        newNode = Text(self.data)       
+
+    def cloneNode(self, deep=0):
+        newNode = Text(self.data)
         if deep:
-            self.deep_clone(newNode)            
-        return newNode    
-    
+            self.deep_clone(newNode)
+        return newNode
+
 
 def _nssplit(qualifiedName):
     fields = string.split(qualifiedName,':', 1)
