@@ -21,12 +21,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: gsclient.py,v 1.34 2005/10/24 01:07:27 tdb30_ Exp $
+#   $Id: gsclient.py,v 1.48 2006/11/08 07:46:35 digitalxero Exp $
 #
 # Description: The file contains code for the game server browser
 #
 
-__version__ = "$Id: gsclient.py,v 1.34 2005/10/24 01:07:27 tdb30_ Exp $"
+__version__ = "$Id: gsclient.py,v 1.48 2006/11/08 07:46:35 digitalxero Exp $"
 
 import orpg.dirpath
 from orpg.orpg_windows import *
@@ -40,19 +40,19 @@ gs_host = 1
 gs_join = 2
 # constants
 
-LIST_SERVER = wxNewId()
-LIST_ROOM = wxNewId()
-ADDRESS = wxNewId()
+LIST_SERVER = wx.NewId()
+LIST_ROOM = wx.NewId()
+ADDRESS = wx.NewId()
 
-GS_CONNECT = wxNewId()
-GS_DISCONNECT = wxNewId()
-GS_SERVER_REFRESH = wxNewId()
-GS_JOIN = wxNewId()
-GS_JOINLOBBY = wxNewId()
-GS_CREATE_ROOM = wxNewId()
-GS_PWD = wxNewId()
-GS_CLOSE = wxNewId()
-OR_CLOSE = wxNewId()
+GS_CONNECT = wx.NewId()
+GS_DISCONNECT = wx.NewId()
+GS_SERVER_REFRESH = wx.NewId()
+GS_JOIN = wx.NewId()
+GS_JOINLOBBY = wx.NewId()
+GS_CREATE_ROOM = wx.NewId()
+GS_PWD = wx.NewId()
+GS_CLOSE = wx.NewId()
+OR_CLOSE = wx.NewId()
 
 
 class server_instance:
@@ -91,15 +91,16 @@ def server_instance_compare(x,y):
     else: return -1
 
 
-class game_server_panel(wxPanel):
+class game_server_panel(wx.Panel):
     def __init__(self,parent,openrpg):
-        wxPanel.__init__(self, parent, -1)
+        wx.Panel.__init__(self, parent, -1)
         self.parent = parent
-        self.myopenrpg = openrpg
+        self.openrpg = openrpg
         self.password_manager = openrpg.get_component('password_manager') # passtool --SD 8/03
         self.frame = openrpg.get_component('frame')
         self.session = openrpg.get_component('session')
         self.settings = openrpg.get_component('settings')
+        self.xml = openrpg.get_component('xml')
         self.serverNameSet = 0
         self.last_motd = ""
         self.buttons = {}
@@ -108,7 +109,7 @@ class game_server_panel(wxPanel):
         self.build_ctrls()
         self.refresh_server_list()
         self.refresh_room_list()
-        EVT_SIZE(self, self.on_size)
+
 
 
 #---------------------------------------------------------
@@ -117,149 +118,141 @@ class game_server_panel(wxPanel):
     def build_ctrls(self):
         ## Section Sizers (with frame edges and text captions)
         self.box_sizers = {}
-        self.box_sizers["server"] = wxBoxedSizer(self,"Server")
-        self.box_sizers["window"] = wxBoxedSizer( self, "Exit" )
-        self.box_sizers["room"] = wxBoxedSizer(self,"Rooms")
-        self.box_sizers["c_room"] = wxBoxedSizer(self,"Create Room")
+        self.box_sizers["server"] = wx.StaticBox(self, -1, "Server")
+        self.box_sizers["window"] = wx.StaticBox(self, -1, "Exit" )
+        self.box_sizers["room"] = wx.StaticBox(self, -1, "Rooms")
+        self.box_sizers["c_room"] = wx.StaticBox(self, -1, "Create Room")
 
 
-        ## fixed size Boxed Sizers
-        self.box_sizers["c_room"].SetMySize( wxSize(200,125) )
-        self.box_sizers["window"].SetMySize( wxSize(200,60) )
-
 
         ## Layout Sizers
         self.sizers = {}
-        self.sizers["main"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["left"] = wxBoxSizer(wxVERTICAL)
-        self.sizers["right"] = wxBoxSizer(wxVERTICAL)
-        self.sizers["server"] = wxBoxSizer(wxVERTICAL)
-        self.sizers["svrlst"] = wxBoxSizer(wxVERTICAL)
-        self.sizers["option"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["close"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["c_room"] = wxBoxSizer(wxVERTICAL)
-        self.sizers["rooms"] = wxBoxSizer(wxVERTICAL)
-        self.sizers["join_buttons"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["cr_name"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["cr_pass"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["cr_admin"] = wxBoxSizer(wxHORIZONTAL)
-        self.sizers["cr_make"] = wxBoxSizer(wxHORIZONTAL)
-
-        ## List Objects
-        self.server_list = wxListCtrl(self.box_sizers["server"],LIST_SERVER, style=wxLC_REPORT|wxSUNKEN_BORDER )
-        self.server_list.InsertColumn(0,"Players",wxLIST_FORMAT_LEFT,0)
-        self.server_list.InsertColumn(1,"Name",wxLIST_FORMAT_LEFT,0)
-
-        self.room_list = wxListCtrl(self.box_sizers["room"],LIST_ROOM,style=wxLC_REPORT|wxSUNKEN_BORDER)
-        self.room_list.InsertColumn(0,"Game",wxLIST_FORMAT_LEFT,0)
-        self.room_list.InsertColumn(1,"Players",wxLIST_FORMAT_LEFT,0)
-        self.room_list.InsertColumn(2,"PW",wxLIST_FORMAT_LEFT,0)
+        self.sizers["main"] = wx.GridBagSizer(hgap=1, vgap=1)
+        self.sizers["server"] = wx.StaticBoxSizer(self.box_sizers["server"], wx.VERTICAL)
+        self.sizers["rooms"] = wx.StaticBoxSizer(self.box_sizers["room"], wx.VERTICAL)
+        self.sizers["close"] = wx.StaticBoxSizer(self.box_sizers["window"], wx.HORIZONTAL)
+        self.sizers["c_room"] = wx.StaticBoxSizer(self.box_sizers["c_room"], wx.VERTICAL)
 
 
-        ## Text Field Objects
-        self.texts["address"] = wxTextCtrl(self.box_sizers["server"], ADDRESS)
-        self.texts["room_name"]= wxTextCtrl(self.box_sizers["c_room"], -1)
-        self.texts["room_pwd"]= wxTextCtrl(self.box_sizers["c_room"], -1)
+        #Build Server Sizer
+        adder = wx.StaticText(self, -1, "Address:")
+        self.texts["address"] = wx.TextCtrl(self, ADDRESS)
+
+        servers = wx.StaticText(self, -1, "Servers:")
+        self.server_list = wx.ListCtrl(self, LIST_SERVER, style=wx.LC_REPORT | wx.SUNKEN_BORDER )
+        self.server_list.InsertColumn(0, "Players", wx.LIST_FORMAT_LEFT, 0)
+        self.server_list.InsertColumn(1, "Name", wx.LIST_FORMAT_LEFT, 0)
+
+        self.buttons[GS_CONNECT] = wx.Button(self, GS_CONNECT, "Connect")
+        self.buttons[GS_SERVER_REFRESH] = wx.Button(self, GS_SERVER_REFRESH, "Refresh")
+        self.buttons[GS_DISCONNECT] = wx.Button(self, GS_DISCONNECT, "Disconnect")
+
+        self.sizers["svrbtns"] = wx.BoxSizer(wx.HORIZONTAL)
+        self.sizers["svrbtns"].Add(self.buttons[GS_CONNECT], 0, wx.EXPAND)
+        self.sizers["svrbtns"].Add(self.buttons[GS_SERVER_REFRESH], 0, wx.EXPAND)
+        self.sizers["svrbtns"].Add(self.buttons[GS_DISCONNECT], 0, wx.EXPAND)
+
+        self.sizers["server"].Add(adder, 0, wx.EXPAND)
+        self.sizers["server"].Add(self.texts["address"], 0, wx.EXPAND)
+        self.sizers["server"].Add(servers, 0, wx.EXPAND)
+        self.sizers["server"].Add(self.server_list, 1, wx.EXPAND)
+        self.sizers["server"].Add(self.sizers["svrbtns"], 0, wx.EXPAND)
+
+
+        #Build Rooms Sizer
+        self.room_list = wx.ListCtrl(self, LIST_ROOM, style=wx.LC_REPORT | wx.SUNKEN_BORDER)
+        self.room_list.InsertColumn(0,"Game", wx.LIST_FORMAT_LEFT,0)
+        self.room_list.InsertColumn(1,"Players", wx.LIST_FORMAT_LEFT,0)
+        self.room_list.InsertColumn(2,"PW", wx.LIST_FORMAT_LEFT,0)
+
+        self.buttons[GS_JOIN] = wx.Button(self, GS_JOIN, "Join Room")
+        self.buttons[GS_JOINLOBBY] = wx.Button(self, GS_JOINLOBBY, "Lobby")
+
+        self.sizers["roombtns"] = wx.BoxSizer(wx.HORIZONTAL)
+        self.sizers["roombtns"].Add(self.buttons[GS_JOIN], 0, wx.EXPAND)
+        self.sizers["roombtns"].Add(self.buttons[GS_JOINLOBBY], 0, wx.EXPAND)
+
+        self.sizers["rooms"].Add(self.room_list, 1, wx.EXPAND)
+        self.sizers["rooms"].Add(self.sizers["roombtns"], 0, wx.EXPAND)
+
+        #Build Close Sizer
+        self.buttons[OR_CLOSE] = wx.Button(self, OR_CLOSE,"Exit OpenRPG")
+        self.buttons[GS_CLOSE] = wx.Button(self, GS_CLOSE,"Close Window")
+        self.sizers["close"].Add(self.buttons[OR_CLOSE], 1, wx.ALIGN_CENTER_VERTICAL)
+        self.sizers["close"].Add(self.buttons[GS_CLOSE], 1, wx.ALIGN_CENTER_VERTICAL)
+
+        #Build Create Room Sizer
+        rname = wx.StaticText(self,-1, "Room Name:")
+        self.texts["room_name"] = wx.TextCtrl(self, -1)
+
+        rpass = wx.StaticText(self,-1, "Password:")
+        self.buttons[GS_PWD] = wx.CheckBox(self, GS_PWD, "")
+        self.texts["room_pwd"] = wx.TextCtrl(self, -1)
         self.texts["room_pwd"].Enable(0)
-        self.texts["room_boot_pwd"] = wxTextCtrl(self.box_sizers["c_room"],-1)
-        self.texts["room_min_version"] = wxTextCtrl(self.box_sizers["c_room"],-1)
+        pwsizer = wx.BoxSizer(wx.HORIZONTAL)
+        pwsizer.Add(self.buttons[GS_PWD],0,0)
+        pwsizer.Add(self.texts["room_pwd"], 1, wx.EXPAND)
+
+        apass = wx.StaticText(self,-1, "Admin Password:")
+        self.texts["room_boot_pwd"] = wx.TextCtrl(self, -1)
+
+        minver = wx.StaticText(self,-1, "Minimum Version:")
+        self.texts["room_min_version"] = wx.TextCtrl(self, -1)
+
+        self.sizers["c_room_layout"] = wx.FlexGridSizer(rows=8, cols=2, hgap=1, vgap=1)
+        self.sizers["c_room_layout"].Add(rname, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL)
+        self.sizers["c_room_layout"].Add(self.texts["room_name"], 0, wx.EXPAND)
+        self.sizers["c_room_layout"].Add(rpass, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL)
+        self.sizers["c_room_layout"].Add(pwsizer, 0, wx.EXPAND)
+        self.sizers["c_room_layout"].Add(apass, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL)
+        self.sizers["c_room_layout"].Add(self.texts["room_boot_pwd"], 0, wx.EXPAND)
+        self.sizers["c_room_layout"].Add(minver, 0, wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL|wx.ALL)
+        self.sizers["c_room_layout"].Add(self.texts["room_min_version"], 0, wx.EXPAND)
+        self.sizers["c_room_layout"].AddGrowableCol(1)
+
+        self.buttons[GS_CREATE_ROOM] = wx.Button(self, GS_CREATE_ROOM, "Create Room")
+
+        self.sizers["c_room"].Add(self.sizers["c_room_layout"], 1, wx.EXPAND)
+        self.sizers["c_room"].Add(self.buttons[GS_CREATE_ROOM], 0, wx.EXPAND)
 
 
-        ## Buttons
-        self.buttons[GS_CONNECT] = wxButton(self.box_sizers["server"], GS_CONNECT, "Connect")
-        self.buttons[GS_SERVER_REFRESH] = wxButton(self.box_sizers["server"], GS_SERVER_REFRESH, "Refresh")
-        self.buttons[GS_DISCONNECT] = wxButton(self.box_sizers["server"], GS_DISCONNECT, "Disconnect")
-        self.buttons[GS_JOIN] = wxButton(self.box_sizers["room"], GS_JOIN, "Join Room")
-        self.buttons[GS_JOINLOBBY] = wxButton(self.box_sizers["room"], GS_JOINLOBBY, "Lobby")
-        self.buttons[GS_CREATE_ROOM] = wxButton(self.box_sizers["c_room"], GS_CREATE_ROOM, "Create Room")
-        self.buttons[GS_PWD] = wxCheckBox(self.box_sizers["c_room"], GS_PWD, "")
-        self.buttons[OR_CLOSE] = wxButton(self.box_sizers["window"], OR_CLOSE,"Exit OpenRPG")
-        self.buttons[GS_CLOSE] = wxButton(self.box_sizers["window"], GS_CLOSE,"Close Window")
-
-
-        ## Layout Assemmbly -- Adding Objects to correct sizers
-        self.sizers["option"].Add(self.buttons[GS_CONNECT] ,1,wxEXPAND )
-        self.sizers["option"].Add(self.buttons[GS_SERVER_REFRESH],1,wxEXPAND )
-        self.sizers["option"].Add(self.buttons[GS_DISCONNECT],1,wxEXPAND )
-
-        self.sizers["server"].Add(wxStaticText(self.box_sizers["server"], -1, "Address: "),0,wxLEFT)
-        self.sizers["server"].Add(self.texts["address"],0,wxEXPAND)
-        self.sizers["server"].Add(wxStaticText(self.box_sizers["server"], -1, "Server List: "),0,wxLEFT)
-        self.sizers["server"].Add(self.server_list,1,wxEXPAND)
-
-        self.sizers["cr_name"].Add(wxStaticText(self.box_sizers["c_room"], -1, "Name: "),0,wxLEFT | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_name"].Add(self.texts["room_name"],1,wxEXPAND | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_pass"].Add(wxStaticText(self.box_sizers["c_room"],-1,"Pass:   "),0,wxLEFT | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_pass"].Add(self.buttons[GS_PWD],0,wxLEFT | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_pass"].Add(self.texts["room_pwd"],1,wxEXPAND | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_admin"].Add(wxStaticText(self.box_sizers["c_room"],-1,"Admin Pass: "),0,wxLEFT | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_admin"].Add(self.texts["room_boot_pwd"],1,wxEXPAND | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_admin"].Add(wxStaticText(self.box_sizers["c_room"],-1,"  Min. Ver.: "),0,wxLEFT | wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_admin"].Add(self.texts["room_min_version"],1, wxALIGN_CENTER_VERTICAL)
-        self.sizers["cr_make"].Add(self.buttons[GS_CREATE_ROOM],1,wxEXPAND )
-
-        self.sizers["close"].Add( self.buttons[OR_CLOSE], 1, wxCENTER | wxEXPAND | wxALIGN_CENTER_VERTICAL )
-        self.sizers["close"].Add( self.buttons[GS_CLOSE], 1, wxCENTER | wxEXPAND | wxALIGN_CENTER_VERTICAL )
-
-        self.sizers["rooms"].Add(self.room_list,1,wxEXPAND)
-        self.sizers["join_buttons"].Add(self.buttons[GS_JOINLOBBY],0,wxEXPAND)
-        self.sizers["join_buttons"].Add(self.buttons[GS_JOIN],1,wxEXPAND)
-        self.sizers["rooms"].Add(self.sizers["join_buttons"],0,wxEXPAND)
-
-        ## bind intermediate sizers
-        self.sizers["svrlst"].Add(self.sizers["server"],1,wxEXPAND)
-        self.sizers["svrlst"].Add(self.sizers["option"],0,wxEXPAND| wxALIGN_CENTER_VERTICAL)
-
-        self.sizers["c_room"].Add(self.sizers["cr_name"],0,wxEXPAND)
-        self.sizers["c_room"].Add(self.sizers["cr_pass"],0,wxEXPAND)
-        self.sizers["c_room"].Add(self.sizers["cr_admin"],0,wxEXPAND)
-        self.sizers["c_room"].Add(self.sizers["cr_make"],0,wxEXPAND)
-
-
-
-
-        ## Add sizers to framed sizers (aka panels)
-        self.box_sizers["server"].set_sizer( self.sizers["svrlst"] )
-        self.box_sizers["c_room"].set_sizer( self.sizers["c_room"] )
-        self.box_sizers["window"].set_sizer( self.sizers["close"] )
-        self.box_sizers["room"].set_sizer(self.sizers["rooms"])
-
-
-        ## bind sizers
-        self.sizers["right"].Add(self.box_sizers["room"],1,wxEXPAND)
-        self.sizers["right"].Add(self.box_sizers["c_room"],0,wxEXPAND | wxALIGN_CENTER_VERTICAL)
-
-        self.sizers["left"].Add(self.box_sizers["server"],1,wxEXPAND)
-        self.sizers["left"].Add(self.box_sizers["window"],0,wxEXPAND | wxALIGN_CENTER_VERTICAL)
-
-        self.sizers["main"].Add(self.sizers["left"],1,wxEXPAND)
-        self.sizers["main"].Add(self.sizers["right"],1,wxEXPAND)
+        #Build Main Sizer
+        self.sizers["main"].Add(self.sizers["server"], (0,0), span=(2,1), flag=wx.EXPAND)
+        self.sizers["main"].Add(self.sizers["rooms"], (0,1), flag=wx.EXPAND)
+        self.sizers["main"].Add(self.sizers["close"], (2,0), flag=wx.EXPAND)
+        self.sizers["main"].Add(self.sizers["c_room"], (1,1), span=(2,1), flag=wx.EXPAND)
+        self.sizers["main"].AddGrowableCol(0)
+        self.sizers["main"].AddGrowableCol(1)
+        self.sizers["main"].AddGrowableRow(0)
 
         self.SetSizer(self.sizers["main"])
+        self.SetAutoLayout(True)
+        self.Fit()
 
 
         ## Event Handlers
-        EVT_BUTTON(self, GS_CONNECT, self.on_button)
-        EVT_BUTTON(self, GS_DISCONNECT, self.on_button)
-        EVT_BUTTON(self, GS_CREATE_ROOM, self.on_button)
-        EVT_BUTTON(self, GS_JOIN, self.on_button)
-        EVT_BUTTON(self, GS_JOINLOBBY, self.on_button)
-        EVT_BUTTON(self, GS_SERVER_REFRESH, self.on_button)
-        EVT_BUTTON(self, GS_CLOSE, self.on_button)
-        EVT_BUTTON(self, OR_CLOSE, self.on_button)
-        EVT_CHECKBOX(self, GS_PWD, self.on_button)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_CONNECT)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_DISCONNECT)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_CREATE_ROOM)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_JOIN)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_JOINLOBBY)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_SERVER_REFRESH)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=GS_CLOSE)
+        self.Bind(wx.EVT_BUTTON, self.on_button, id=OR_CLOSE)
+        self.Bind(wx.EVT_CHECKBOX, self.on_button, id=GS_PWD)
 
 
         # Added double click handlers 5/05 -- Snowdog
-        EVT_LIST_ITEM_ACTIVATED(self, LIST_SERVER, self.on_server_dbclick)
-        EVT_LIST_ITEM_ACTIVATED(self, LIST_ROOM, self.on_room_dbclick)
+        self.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self.on_server_dbclick, id=LIST_SERVER)
+        self.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self.on_room_dbclick, id=LIST_ROOM)
 
-        EVT_LIST_ITEM_SELECTED(self,LIST_ROOM,self.on_select)
-        EVT_LIST_ITEM_SELECTED(self,LIST_SERVER,self.on_select)
-        EVT_SET_FOCUS(self.texts['address'],self.on_text)
+        self.Bind(wx.EVT_LIST_ITEM_SELECTED, self.on_select, id=LIST_ROOM)
+        self.Bind(wx.EVT_LIST_ITEM_SELECTED, self.on_select, id=LIST_SERVER)
+        self.texts['address'].Bind(wx.EVT_SET_FOCUS, self.on_text)
         self.set_connected(self.session.is_connected())
         self.cur_room_index = -1
         self.cur_server_index = -1
+        self.rmList = {}
 
 #---------------------------------------------------------
 # [END] Snowdog: Updated Game Server Window 12/02
@@ -272,9 +265,12 @@ class game_server_panel(wxPanel):
     # support for double click selection of server.
     # 5/16/05 -- Snowdog
     #-----------------------------------------------------
-    def on_server_dbclick(self, evt):
+    def on_server_dbclick(self, evt=None):
         #make sure address is updated just in case list select wasn't done
-        self.on_select(evt)
+        try:
+            self.on_select(evt)
+        except:
+            pass
         address = self.texts["address"].GetValue()
         if self.session.is_connected():
             if self.session.host_server == address :
@@ -291,9 +287,21 @@ class game_server_panel(wxPanel):
     # support for double click selection of server.
     # 5/16/05 -- Snowdog
     #-----------------------------------------------------
-    def on_room_dbclick(self, evt):
+
+    def on_room_dbclick(self, evt=None):
         #make sure address is updated just in case list select wasn't done
-        self.on_select(evt)
+        try:
+            self.on_select(evt)
+        except:
+            pass
+
+        group_id = str(self.room_list.GetItemData(self.cur_room_index))
+
+        if self.NoGroups:
+            self.NoGroups = False
+            self.session.group_id = group_id
+            self.on_server_dbclick()
+            return
 
         if self.cur_room_index >= 0:
             if self.cur_room_index != 0:
@@ -301,14 +309,14 @@ class game_server_panel(wxPanel):
             else:
                 self.set_lobbybutton(0);
 
-            group_id = str(self.room_list.GetItemData(self.cur_room_index))
             group = self.session.get_group_info(group_id)
+
             pwd = ""
             if (group[2] == "True") or (group[2] == "1"):
                 pwd = self.password_manager.GetPassword("room", group_id)
             else:
                 pwd = ""
-            self.session.send_join_group(group_id,pwd)
+            self.session.send_join_group(group_id, pwd)
 
 
 
@@ -316,24 +324,23 @@ class game_server_panel(wxPanel):
         id = evt.GetId()
         if id == LIST_ROOM:
             self.cur_room_index = evt.m_itemIndex
+
         elif id==LIST_SERVER:
-            #self.cur_server_index = self.server_list.GetSelection()
             self.cur_server_index = evt.m_itemIndex
 
             self.name = self.svrList[self.cur_server_index].name
             address = self.svrList[self.cur_server_index].addy
             port = self.svrList[self.cur_server_index].port
-            #self.name = self.servers[self.cur_server_index].getAttribute('name')
-            #address = self.servers[self.cur_server_index].getAttribute('address')
-            #port = self.servers[self.cur_server_index].getAttribute('port')
             self.texts["address"].SetValue(address+":"+str(port))
+            self.refresh_room_list()
 
     def on_text(self,evt):
         id = evt.GetId()
+
         if (id == ADDRESS) and (self.cur_server_index >= 0):
-            print "ADDRESS id = ", id, "index = ", self.cur_server_index
-            #self.server_list.SetSelection(self.cur_server_index,false)
+            #print "ADDRESS id = ", id, "index = ", self.cur_server_index
             self.cur_server_index = -1
+
         evt.Skip()
 
     def add_room(self,data):
@@ -346,8 +353,8 @@ class game_server_panel(wxPanel):
         self.room_list.SetItemData(i,int(data[0]))
         self.refresh_room_list()
 
-    def del_room(self,data):
-        i = self.room_list.FindItemData(-1,int(data[0]))
+    def del_room(self, data):
+        i = self.room_list.FindItemData(-1, int(data[0]))
         self.room_list.DeleteItem(i)
         self.refresh_room_list()
 
@@ -421,48 +428,58 @@ class game_server_panel(wxPanel):
         elif id == GS_PWD:
             self.texts["room_pwd"].Enable(evt.Checked())
         elif id == OR_CLOSE:
-            dlg = wxMessageDialog(self,"Quit OpenRPG?","OpenRPG",wxYES_NO)
-            if dlg.ShowModal() == wxID_YES:
+            dlg = wx.MessageDialog(self,"Quit OpenRPG?","OpenRPG",wx.YES_NO)
+            if dlg.ShowModal() == wx.ID_YES:
                 dlg.Destroy()
                 self.frame.kill_mplay_session()
                 self.frame.closed_confirmed()
         elif id == GS_CLOSE:
-            # Potential BUG here.  type function didn't return useful
-            # information, so we make the call assuming it's in a
-            # wxPFrame, and catch the exception if it's not.
-            # lame, but true.
-            # a better way might be to look at the parent's dict or
-            # __name__ or something
-
-            # print self.parent.__name__ # this didn't work
-            # print self.parent.__dict__  # this *might* be coerced into working
-            # print self.parent.locals() # this didn't work
-
-            # print 'browse panel closing'
-            # print 'parent type is',type( self.parent )
-            # print 'wxPFrame type is', type( wxPFrame )
-            # if ( type( self.parent ) == type( wxPFrame ) ):
-            #     self.parent.OnCloseWindow( self, None )
-            # else:
-            try:
-                self.parent.OnCloseWindow( self, None )
-            except:
-                self.parent.Close()
-            # self.parent.Close()
+            self.parent.OnMB_GameServerBrowseServers()
 
     def refresh_room_list(self):
         self.room_list.DeleteAllItems()
-        groups = self.session.get_groups()
-        for g in groups:
-             i = self.room_list.GetItemCount()
-             if (g[2]=="True") or (g[2]=="1") : pwd="yes"
-             else: pwd="no"
-             self.room_list.InsertStringItem(i,g[1])
-             self.room_list.SetStringItem(i,1,g[3])
-             self.room_list.SetStringItem(i,2,pwd)
-             self.room_list.SetItemData(i,int(g[0]))
-        self.colorize_group_list(groups)
+        address = self.texts["address"].GetValue()
+
+        try:
+            cadder = self.session.host_server
+        except:
+            cadder = ''
+
+        if self.rmList.has_key(address) and len(self.rmList[address]) > 0 and cadder != address:
+            for room in self.rmList[address]:
+                pwd = room.getAttribute("pwd")
+                id = room.getAttribute("id")
+                name = room.getAttribute("name")
+                nump = room.getAttribute("num_users")
+
+                i = self.room_list.GetItemCount()
+                if (pwd == "True") or (pwd == "1"):
+                    pwd = "yes"
+                else:
+                    pwd = "no"
+                self.room_list.InsertStringItem(i,name)
+                self.room_list.SetStringItem(i,1,nump)
+                self.room_list.SetStringItem(i,2,pwd)
+                self.room_list.SetItemData(i,int(id))
+                self.NoGroups = True
+        else:
+            self.NoGroups = False
+            groups = self.session.get_groups()
+            for g in groups:
+                i = self.room_list.GetItemCount()
+                if (g[2]=="True") or (g[2]=="1") : pwd="yes"
+                else: pwd="no"
+                self.room_list.InsertStringItem(i,g[1])
+                self.room_list.SetStringItem(i,1,g[3])
+                self.room_list.SetStringItem(i,2,pwd)
+                self.room_list.SetItemData(i,int(g[0]))
+
+
+            self.colorize_group_list(groups)
         self.room_list.SortItems(cmp)
+        self.room_list.SetColumnWidth(0, wx.LIST_AUTOSIZE)
+        self.room_list.SetColumnWidth(1, wx.LIST_AUTOSIZE)
+        self.room_list.SetColumnWidth(2, wx.LIST_AUTOSIZE)
 
     def refresh_server_list(self):
         #dlg = do_progress_dlg(self,"Game Browser","Retrieving  Server List...",5)
@@ -491,6 +508,8 @@ class game_server_panel(wxPanel):
                 for n in node_list:
                     if n.hasAttribute('id') and n.hasAttribute('name') and n.hasAttribute('num_users') and n.hasAttribute('address') and n.hasAttribute('port'):
                         self.svrList.append( server_instance(n.getAttribute('id'),n.getAttribute('name'), n.getAttribute('num_users'), n.getAttribute('address'),n.getAttribute('port')))
+                        self.rmList[n.getAttribute('address') + ':'+n.getAttribute('port')] = n.getElementsByTagName('room')
+
 
                 self.svrList.sort(server_instance_compare)
 
@@ -503,15 +522,15 @@ class game_server_panel(wxPanel):
                     self.server_list.SetStringItem(i,1,name)
 
                     r,g,b = hex.rgb_tuple(color1)
-                    svrcolor = wxColour(red=r,green=g,blue=b)
+                    svrcolor = wx.Colour(red=r,green=g,blue=b)
 
                     if players == "0":
                         r,g,b = hex.rgb_tuple(color3)
-                        svrcolor = wxColour(red=r,green=g,blue=b)
+                        svrcolor = wx.Colour(red=r,green=g,blue=b)
 
                     if n.name.startswith("OpenRPG DEV"):
                         r,g,b = hex.rgb_tuple(color2)
-                        svrcolor = wxColour(red=r,green=g,blue=b)
+                        svrcolor = wx.Colour(red=r,green=g,blue=b)
 
                     item = self.server_list.GetItem(i)
                     item.SetTextColour(svrcolor)
@@ -526,6 +545,8 @@ class game_server_panel(wxPanel):
 
             # No server is currently selected!!!  Versus the broken and random 0!
             self.cur_server_index = -1
+            self.server_list.SetColumnWidth(0, wx.LIST_AUTOSIZE)
+            self.server_list.SetColumnWidth(1, wx.LIST_AUTOSIZE)
 
             if self.serverNameSet == 0:
                 # Pointless to constantly set the address field to random
@@ -535,28 +556,9 @@ class game_server_panel(wxPanel):
                 # entered data or even the previously selected server data!
                 # Localhost should probably be used but some systems are ultra/lame
                 # broken about localhost use.
-                self.texts["address"].SetValue( "127.0.0.1:6774" )
+                self.texts["address"].SetValue("127.0.0.1:6774")
                 self.serverNameSet = 1
 
-
-##            dlg.Update(3,"Checking for new MOTD ...")
-
-##            #xml_dom2 =  parseXml("<motd href='http://bennettsathome.com/testmotd.html'>")
-##            #node_list = xml_dom2.getElementsByTagName('motd')
-##            node_list = xml_dom.getElementsByTagName('motd')
-##            if node_list:
-##                #motd = node_list[0]._get_firstChild().toxml()
-##                data = urllib.urlretrieve(node_list[0].getAttribute('href'))
-##                file = open(data[0])
-##                motd = file.read()
-##                if motd != self.last_motd:
-##                    self.last_motd = motd
-##                    #motd_frame = wxHTMLFrame(self,"Important Message from OpenRPG",style = wxSTAY_ON_TOP | wxDEFAULT_FRAME_STYLE)
-##                    #motd_frame.set_page(motd)
-##                    #motd_frame.Show()
-##                    self.frame.chat.Post(motd)
-##                    wxMessageBox("There is an important bulletin diplayed in the Chat window","Bulletin")
-
             else:
                 pass
 
@@ -587,9 +589,9 @@ class game_server_panel(wxPanel):
             if(meta_server_lib.post_failed_connection(id,meta=meta,address=address,port=port)):
                 self.refresh_server_list()
 
-    def do_connect(self,address):
-        chat = self.myopenrpg.get_component('chat')
-        chat.InfoPost("Locating server at "+address+"...")
+    def do_connect(self, address):
+        chat = self.openrpg.get_component('chat')
+        chat.InfoPost("Locating server at " + address + "...")
         if self.session.connect(address):
             self.frame.start_timer()
         else:
@@ -612,13 +614,13 @@ class game_server_panel(wxPanel):
             pwd = ""
             if (group[2] == "True") or (group[2] == "1"):
                 pwd = self.password_manager.GetPassword("room", group_id)
-                #dlg = wxTextEntryDialog(self,"Password?","Join Private Room")
-                #if dlg.ShowModal() == wxID_OK:
+                #dlg = wx.TextEntryDialog(self,"Password?","Join Private Room")
+                #if dlg.ShowModal() == wx.ID_OK:
                 #    pwd = dlg.GetValue()
                 #dlg.Destroy()
             else:
                 pwd = ""
-            if pwd != None:#pwd==None means the user clicked "Cancel"
+            if pwd != None: #pwd==None means the user clicked "Cancel"
                 self.session.send_join_group(group_id,pwd)
 
 
@@ -648,7 +650,7 @@ class game_server_panel(wxPanel):
             if loc > -1:
                 b = name[:loc]
                 e = name[loc+1:]
-                name = b + "&#39;&#39;" + e
+                name = b + "&quote;" + e
                 oldloc = loc+1
         loc = name.find("'")
         oldloc=0
@@ -666,7 +668,7 @@ class game_server_panel(wxPanel):
         else:
             pwd = ""
         if name == "":
-            wxMessageBox("Invalid Name","Error");
+            wx.MessageBox("Invalid Name","Error");
         else:
             msg = "%s is creating room \'%s.\'" % (self.session.name, name)
             self.session.send( msg )
@@ -679,23 +681,12 @@ class game_server_panel(wxPanel):
 #---------------------------------------------------------
 
     def on_size(self,evt):
-        (w,h) = self.GetClientSizeTuple()
-        w = w/2
-        w2 = w*2
-
-        self.sizers["main"].SetDimension(0,0,w2,h)
-
         # set column widths for room list
-        (lw, lh) = self.room_list.GetClientSizeTuple()
-        self.room_list.SetColumnWidth(0, lw-80)
-        self.room_list.SetColumnWidth(1, 50)
-        self.room_list.SetColumnWidth(2, 30)
+
 
         # set column widths for server list
-        (lw, lh) = self.server_list.GetClientSizeTuple()
-        lw = lw/4
-        self.server_list.SetColumnWidth(0, lw)
-        self.server_list.SetColumnWidth(1, lw*3)
+        pass
+
 
 
 #---------------------------------------------------------
@@ -718,22 +709,22 @@ class game_server_panel(wxPanel):
                 if item_list_location != -1:
                     item = self.room_list.GetItem(item_list_location)
                     r,g,b = hex.rgb_tuple(color1)
-                    color = wxColour(red=r,green=g,blue=b)
+                    color = wx.Colour(red=r,green=g,blue=b)
 
                     #passworded rooms with players get marked in dark red
                     if gr[2]=="1" or gr[2]=="True":
                         r,g,b = hex.rgb_tuple(color2)
-                        color = wxColour(red=r,green=g,blue=b)
+                        color = wx.Colour(red=r,green=g,blue=b)
 
                     #all empty rooms marked in light grey
                     if gr[3] == "0":
                         r,g,b = hex.rgb_tuple(color3)
-                        color = wxColour(red=r,green=g,blue=b)
+                        color = wx.Colour(red=r,green=g,blue=b)
 
                     #Lobby always marked in blue
                     if gr[0] == "0":
                         r,g,b = hex.rgb_tuple(color4)
-                        color = wxColour(red=r,green=g,blue=b)
+                        color = wx.Colour(red=r,green=g,blue=b)
 
                     item.SetTextColour(color)
                     self.room_list.SetItem(item)
