@@ -22,7 +22,7 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: meta_server_lib.py,v 1.31 2005/06/05 20:12:38 digitalxero Exp $
+#   $Id: meta_server_lib.py,v 1.39 2006/11/04 21:24:22 digitalxero Exp $
 #
 # Description: A collection of functions to communicate with the meta server.
 #
@@ -31,12 +31,12 @@
 #added debug flag for meta messages to cut console server spam --Snowdog
 META_DEBUG = 0
 
-__version__ = "$Id: meta_server_lib.py,v 1.31 2005/06/05 20:12:38 digitalxero Exp $"
+__version__ = "$Id: meta_server_lib.py,v 1.39 2006/11/04 21:24:22 digitalxero Exp $"
 
 from orpg.orpg_version import PROTOCOL_VERSION
 from orpg.orpg_xml import *
 import orpg.dirpath
-import orpg.tools.config_files
+import orpg.tools.validate
 import urllib
 import orpg.minidom
 from threading import *
@@ -57,26 +57,29 @@ def get_server_dom(data=None,path=None):
 
 
     # POST the data
-#    print
-#    print "Sending the following POST info to Meta at " + path + ":"
-#    print "=========================================="
-#    print data
-#    print
-    file = urllib.urlopen(path,data)
+    if META_DEBUG:
+        print
+        print "Sending the following POST info to Meta at " + path + ":"
+        print "=========================================="
+        print data
+        print
+    file = urllib.urlopen(path, data)
     data = file.read()
+    file.close()
 
     # Remove any leading or trailing data.  This can happen on some satellite connections
 
     p = re.compile('(<servers>.*?</servers>)',re.DOTALL|re.IGNORECASE)
-    mo=p.search(data)
+    mo = p.search(data)
     if mo:
-        data=mo.group(0)
+        data = mo.group(0)
 
-#    print
-#    print "Got this string from the Meta at " + path + ":"
-#    print "==============================================="
-#    print data
-#    print
+    if META_DEBUG:
+        print
+        print "Got this string from the Meta at " + path + ":"
+        print "==============================================="
+        print data
+        print
     # build dom
     xml_dom = parseXml(data)
     xml_dom = xml_dom._get_documentElement()
@@ -263,6 +266,10 @@ def updateMetaCache(xml_dom):
     try:
         if META_DEBUG: print "Updating Meta Server Cache"
         metaservers = xml_dom.getElementsByTagName( 'metaservers' )   # pull out the metaservers bit
+        if len(metaservers) == 0:
+            cmetalist = getRawMetaList()
+            xml_dom = get_server_dom(cmetalist[0])
+            metaservers = xml_dom.getElementsByTagName( 'metaservers' )
         authoritative = metaservers[0].getAttribute('auth')
         if META_DEBUG: print "  Authoritive Meta: "+str(authoritative)
         metas = metaservers[0].getElementsByTagName("meta")                # get the list of metas
@@ -281,7 +288,7 @@ def updateMetaCache(xml_dom):
 
     except Exception, e:
         if META_DEBUG: traceback.print_exc()
-        print "Meta Server Lib: UpdateMetaChache(): " + str(e)
+        print "Meta Server Lib: UpdateMetaCache(): " + str(e)
 
 
 def getRawMetaList():
@@ -289,7 +296,7 @@ def getRawMetaList():
         try:
             metacache_lock.acquire()
             #  Read in the metas
-            orpg.tools.config_files.validate_config_file("metaservers.cache","metaservers.cache")
+            orpg.tools.validate.Validate().config_file("metaservers.cache","metaservers.cache")
             ini = open(orpg.dirpath.dir_struct["user"]+"metaservers.cache","r")
             metas = ini.readlines()
             ini.close()
@@ -308,7 +315,7 @@ def getMetaServers(versions = None, pick_random=0):
     # get meta server URLs as a list
 
     #  versions is a list of acceptable version numbers.
-    #    A false truth value will use getMetaServerBaseURL()
+    #    A False truth value will use getMetaServerBaseURL()
 
     # set a default if we have weird reading problems
     # default_url = "http://www.openrpg.com/openrpg_servers.php"
@@ -384,8 +391,8 @@ def getMetaServerBaseURL():
     url = "http://www.openrpg.com/openrpg_servers.php"
 
     try:
-        orpg.tools.config_files.validate_config_file("ini.xml","default_ini.xml")
-        ini = open(orpg.dirpath.dir_struct["user"]+"ini.xml","r")
+        orpg.tools.validate.Validate().config_file("settings.xml","default_settings.xml")
+        ini = open(orpg.dirpath.dir_struct["user"]+"settings.xml","r")
         txt = ini.read()
         tree = parseXml(txt)._get_documentElement()
         ini.close()
@@ -483,6 +490,8 @@ class registerThread(Thread):
         else:
             self.path = MetaPath
 
+    def getIdAndCookie(self):
+        return self.id, self.cookie
 
     def TestDeleteStatus(self):
 
@@ -521,8 +530,8 @@ class registerThread(Thread):
             try:
                 self.rlock.acquire()            #  Serialize access to this state information
 
-                if self.interval >= 1:          #  If the number of minutes is one or greater
-                    self.interval -= .5         #  wake up with 30 seconds left to re-register
+                if self.interval >= 3:          #  If the number of minutes is one or greater
+                    self.interval -= 1          #  wake up with 30 seconds left to re-register
                 else:
                     self.interval = .1           #  Otherwise, we probably experienced some kind
                                                 #  of error from the Meta in register().  Sleep
@@ -540,7 +549,7 @@ class registerThread(Thread):
 
         #  If we get past the while loop, it's because we've been asked to die,
         #  so just let run() end.  Once this occurs, the thread is dead and
-        #  calls to Thread.isAlive() return false.
+        #  calls to Thread.isAlive() return False.
 
 
     def unregister(self):
@@ -644,14 +653,13 @@ class registerThread(Thread):
                                         "act":"register"} )
 
             try:
-
                 xml_dom = get_server_dom( data=data,path=self.path )  #  this POSTS the request and returns the result
 
             except:
                 if META_DEBUG: print "Problem talking to server.  Setting interval for retry ..."
                 self.interval = 0
                 if self.register_callback:                 #  if a callback is registered, call it
-                    self.register_callback(None,self.path)
+                    self.register_callback(None, self.path)
                 #  If we are in the registerThread thread, then setting interval to 0
                 #  will end up causing a retry in about 6 seconds (see self.run())
 
@@ -670,12 +678,12 @@ class registerThread(Thread):
             if xml_dom:
 
                 if self.register_callback:                      #  if a callback is registered, call it
-                    self.register_callback(xml_dom,self.path)
+                    self.register_callback(xml_dom, self.path)
 
 
                 #  If there's an error, echo it to the console
                 if xml_dom.hasAttribute("errmsg"):
-                    if META_DEBUG: print "Error message returned from Meta:  " + xml_dom.getAttribute("errmsg")
+                    print "Error message returned from Meta:  " + xml_dom.getAttribute("errmsg")
 
                 #  No special handling is required.  If the registration worked, id, cookie, and interval
                 #  can be stored and used for the next time.
@@ -700,6 +708,8 @@ class registerThread(Thread):
                     self.interval = int(xml_dom.getAttribute("interval"))
                     self.id = xml_dom.getAttribute("id")
                     self.cookie = xml_dom.getAttribute("cookie")
+                    if not xml_dom.hasAttribute("errmsg"):
+                        updateMetaCache(xml_dom)
 
                 except:
                     if META_DEBUG: print
@@ -714,7 +724,7 @@ class registerThread(Thread):
                     pass
 
             else:  #  else if no DOM is returned from get_server_dom()
-                if META_DEBUG: print "Error - no DOM constructed from Meta message!"
+                print "Error - no DOM constructed from Meta message!"
 
             return 0  # Let caller know it was okay to call us
 
@@ -723,5 +733,3 @@ class registerThread(Thread):
 
     #  End of class registerThread
     ################################################################################
-
-
