@@ -21,13 +21,13 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: mplay_client.py,v 1.49 2005/10/24 02:06:04 tdb30_ Exp $
+#   $Id: mplay_client.py,v 1.70 2007/02/15 15:26:47 digitalxero Exp $
 #
 # Description: This file contains the code for the client stubs of the multiplayer
 # features in the orpg project.
 #
 
-__version__ = "$Id: mplay_client.py,v 1.49 2005/10/24 02:06:04 tdb30_ Exp $"
+__version__ = "$Id: mplay_client.py,v 1.70 2007/02/15 15:26:47 digitalxero Exp $"
 
 import orpg.minidom
 import socket
@@ -45,6 +45,18 @@ import errno
 import os
 import time
 
+try:
+    import bz2
+    cmpBZ2 = True
+except:
+    cmpBZ2 = False
+
+try:
+    import zlib
+    cmpZLIB = True
+except:
+    cmpZLIB = False
+
 
 # This should be configurable
 OPENRPG_PORT = 6774
@@ -124,14 +136,16 @@ class client_base:
         self.protocol_version = PROTOCOL_VERSION
         self.client_string = CLIENT_STRING
         self.status = MPLAY_DISCONNECTED
+        self.useCompression = False
+        self.compressionType = 'Undefined'
         self.log_console = None
         self.sock = None
         self.text_status = "Idle"
         self.statLock = Lock()
         self.useroles = 0
-        self.ROLE_GM="GM"
-        self.ROLE_PLAYER="PLAYER"
-        self.ROLE_LURKER="LURKER"
+        self.ROLE_GM = "GM"
+        self.ROLE_PLAYER = "PLAYER"
+        self.ROLE_LURKER = "LURKER"
         self.lastmessagetime = time.time()
         self.connecttime = time.time()
 
@@ -176,10 +190,11 @@ class client_base:
         while( self.get_status() == MPLAY_CONNECTED ):
             readMsg = self.recvMsg( self.sock )
 
-            # Make sure we didn't get disconnected
-            bytes = len( readMsg )
-            if bytes == 0:
-                break
+            try:
+                if self.useCompression and self.compressionType != None:
+                    readMsg = self.compressionType.decompress(readMsg)
+            except:
+                pass
 
             # Check the length of the message
             bytes = len( readMsg )
@@ -206,26 +221,38 @@ class client_base:
         """Very simple function that will properly encode and send a message to te
         remote on the specified socket."""
 
-        # Calculate our message length
-        length = len( msg )
+        if self.useCompression and self.compressionType != None:
+            mpacket = self.compressionType.compress(msg)
+            lpacket = pack('i', socket.htonl(len(mpacket)))
+            sock.send(lpacket)
 
-        # Encode the message length into network byte order
-        lp = pack( 'i', socket.htonl( length ) )
+            offset = 0
+            while offset < len(mpacket):
+                slice = buffer(mpacket, offset, len(mpacket)-offset)
+                sent = sock.send(slice)
+                offset += sent
+            sentm = offset
+        else:
+            # Calculate our message length
+            length = len( msg )
 
-        try:
-            # Send the encoded length
-            sentl = sock.send( lp )
+            # Encode the message length into network byte order
+            lp = pack( 'i', socket.htonl( length ) )
 
-            # Now, send the message the the length was describing
-            sentm = sock.send( msg )
-            if self.isServer():
-                self.log_msg(("data_sent", sentl+sentm))
+            try:
+                # Send the encoded length
+                sentl = sock.send( lp )
 
-        except socket.error, e:
-            self.log_msg( e )
+                # Now, send the message the the length was describing
+                sentm = sock.send( msg )
+                if self.isServer():
+                    self.log_msg(("data_sent", sentl+sentm))
 
-        except Exception, e:
-            self.log_msg( e )
+            except socket.error, e:
+                self.log_msg( e )
+
+            except Exception, e:
+                self.log_msg( e )
 
         return sentm
 
@@ -348,14 +375,21 @@ class client_base:
 # The IP field should really be deprecated as too many systems are NAT'd and/or behind firewalls for a
 # client provided IP address to have much value.  As such, we now label it as deprecated.
     def toxml(self,action):
-        xml_data = "<player name=\""+myescape(self.name) + "\""
-        xml_data += " action=\""+action+"\" id=\""+self.id + "\""
-        xml_data += " group_id=\""+self.group_id+"\" ip=\""+self.ip + "\""
-        xml_data += " status=\""+self.text_status + "\""
-        xml_data += " version=\""+self.version + "\""
-        xml_data += " protocol_version=\""+self.protocol_version + "\""
-        xml_data += " client_string=\""+self.client_string + "\""
-        xml_data += "/>"
+        xml_data = '<player name="' + myescape(self.name) + '"'
+        xml_data += ' action="' + action + '" id="' + self.id + '"'
+        xml_data += ' group_id="' + self.group_id + '" ip="' + self.ip + '"'
+        xml_data += ' status="' + self.text_status + '"'
+        xml_data += ' version="' + self.version + '"'
+        xml_data += ' protocol_version="' + self.protocol_version + '"'
+        xml_data += ' client_string="' + self.client_string + '"'
+        xml_data += ' useCompression="' + str(self.useCompression) + '"'
+        if cmpBZ2 and (self.compressionType == 'Undefined' or self.compressionType == bz2):
+            xml_data += ' cmpType="bz2"'
+        elif cmpZLIB and (self.compressionType == 'Undefined' or self.compressionType == zlib):
+            xml_data += ' cmpType="zlib"'
+        else:
+            xml_data += ' cmpType="None"'
+        xml_data += ' />'
         return xml_data
 
 
@@ -469,6 +503,7 @@ class mplay_client(client_base):
         # Should really find a better solution. -- SD 8/03
         self.orpgFrame_callback = callbacks['orpgFrame']
 
+        self.settings = self.orpgFrame_callback.settings
 
         #self.version = VERSION
         #self.protocol_version = PROTOCOL_VERSION
@@ -479,31 +514,37 @@ class mplay_client(client_base):
         self.groups = {}
         self.unique_cookie = 0
 
+        self.msg_handlers = {}
+        self.core_msg_handlers = []
+        self.load_core_msg_handlers()
+
 
     # implement from our base class
-    def isServer( self ):
+    def isServer(self):
         return 0
 
+    def get_chat(self):
+        return self.orpgFrame_callback.chat
 
     def set_name(self,name):
         self.name =  name
         self.update()
 
-    def set_text_status(self,status):
+    def set_text_status(self, status):
         if self.text_status != status:
-          self.text_status = status
-          self.update()
+            self.text_status = status
+            self.update()
 
-    def set_status_url(self,url="None"):
+    def set_status_url(self, url="None"):
         self.on_status_event(mplay_event(STATUS_SET_URL,url))
 
-    def update(self):
+    def update(self, evt=None):
         if self.status == MPLAY_CONNECTED:
             self.outbox.put(self.toxml('update'))
             self.inbox.put(self.toxml('update'))
 
 
-    def get_group_info(self,id=0):
+    def get_group_info(self, id=0):
         self.statLock.acquire()
         id = self.groups[id]
         self.statLock.release()
@@ -567,8 +608,6 @@ class mplay_client(client_base):
 
         self.statLock.release()
 
-
-
     def clear_groups(self):
         self.statLock.acquire()
 
@@ -622,6 +661,15 @@ class mplay_client(client_base):
                 name = b + "&amp;" + e
                 oldloc = loc+1
 
+        loc = name.find('"')
+        oldloc=0
+        while loc > -1:
+            loc = name.find('"',oldloc)
+            if loc > -1:
+                b = name[:loc]
+                e = name[loc+1:]
+                name = b + "&quot;" + e
+                oldloc = loc+1
         loc = name.find("'")
         oldloc=0
         while loc > -1:
@@ -632,16 +680,6 @@ class mplay_client(client_base):
                 name = b + "&#39;" + e
                 oldloc = loc+1
 
-        loc = name.find('"')
-        oldloc=0
-        while loc > -1:
-            loc = name.find('"',oldloc)
-            if loc > -1:
-                b = name[:loc]
-                e = name[loc+1:]
-                name = b + "&#39;&#39;" + e
-                oldloc = loc+1
-
 
         self.outbox.put("<alter key=\"name\" val=\"" + name + "\" bpw=\"" + pwd + "\" plr=\"" + self.id +"\" gid=\"" + self.group_id + "\" />")
         self.update()
@@ -665,6 +703,11 @@ class mplay_client(client_base):
             self.outbox.put("<msg to='"+player+"' from='"+self.id+"' group_id='"+self.group_id+"' />"+msg)
         self.check_my_status()
 
+    def send_sound(self, snd_xml):
+        if self.status == MPLAY_CONNECTED:
+            self.outbox.put(snd_xml)
+        self.check_my_status()
+
     def send_create_group(self,name,pwd,boot_pwd,minversion):
         self.outbox.put("<create_group from=\""+self.id+"\" pwd=\""+pwd+"\" name=\""+
                         name+"\" boot_pwd=\""+boot_pwd+"\" min_version=\"" + minversion +"\" />")
@@ -675,11 +718,11 @@ class mplay_client(client_base):
         self.outbox.put("<join_group from=\""+self.id+"\" pwd=\""+pwd+"\" group_id=\""+str(group_id)+"\" />")
 
 
-    def poll(self):
+    def poll(self, evt=None):
         try:
             msg = self.inbox.get_nowait()
         except:
-            if self.get_status() <> MPLAY_CONNECTED:
+            if self.get_status() != MPLAY_CONNECTED:
                 self.check_my_status()
         else:
             try:
@@ -688,10 +731,29 @@ class mplay_client(client_base):
                 print "The following  message: " + str(msg)
                 print "created the following exception: "
                 traceback.print_exc()
-                print self.players
 
-            self.poll()
+    def add_msg_handler(self, tag, function, core=False):
+        if not self.msg_handlers.has_key(tag):
+            self.msg_handlers[tag] = function
+            if core:
+                self.core_msg_handlers.append(tag)
+        else:
+            print 'XML Messages ' + tag + ' already has a handler'
 
+    def remove_msg_handler(self, tag):
+        if self.msg_handlers.has_key(tag) and not tag in self.core_msg_handlers:
+            del self.msg_handlers[tag]
+        else:
+            print 'XML Messages ' + tag + ' already deleted'
+
+    def load_core_msg_handlers(self):
+        self.add_msg_handler('msg', self.on_msg, True)
+        self.add_msg_handler('ping', self.on_ping, True)
+        self.add_msg_handler('group', self.on_group, True)
+        self.add_msg_handler('role', self.on_role, True)
+        self.add_msg_handler('player', self.on_player, True)
+        self.add_msg_handler('password', self.on_password, True)
+        self.add_msg_handler('sound', self.on_sound, True)
 
     def pretranslate(self,data):
         # Pre-qualify our data.  If we don't have atleast 5-bytes, then there is
@@ -704,115 +766,162 @@ class mplay_client(client_base):
         msg = data[end+1:]
         xml_dom = parseXml(head)
         xml_dom = xml_dom._get_documentElement()
+
         tag_name = xml_dom._get_tagName()
         id = xml_dom.getAttribute("from")
+        if id == '':
+            id = xml_dom.getAttribute("id")
 
-        if tag_name=="msg":
-            if id == "0":
-                self.on_receive(msg,None)      #  None get's interpreted in on_receive as the sys admin.
-                                               #  Doing it this way makes it harder to impersonate the admin
-            else:
-                if self.is_valid_id(id):
-                    self.on_receive(msg,self.players[id])
+        if self.msg_handlers.has_key(tag_name):
+            self.msg_handlers[tag_name](id, data, xml_dom)
+        else:
+            #Unknown messages recived ignoring
+            #using pass insted or printing an error message
+            #because plugins should now be able to send and proccess messages
+            #if someone is using a plugin to send messages and this user does not
+            #have the plugin they would be getting errors
+            pass
 
+        if xml_dom:
+            xml_dom.unlink()
+
+
+    def on_sound(self, id, data, xml_dom):
+        (ignore_id,ignore_name) = self.get_ignore_list()
+        for m in ignore_id:
+            if m == id:
+                # yes we are
+                print "ignoring sound from player:"
+                return
+        chat = self.get_chat()
+        snd = xml_dom.getAttribute("url")
+        loop_sound = xml_dom.getAttribute("loop")
+        chat.sound_player.play(snd, "remote", loop_sound)
+
+    def on_msg(self, id, data, xml_dom):
+        end = data.find(">")
+        head = data[:end+1]
+        msg = data[end+1:]
+        if id == "0":
+            self.on_receive(msg,None)      #  None get's interpreted in on_receive as the sys admin.
+                                           #  Doing it this way makes it harder to impersonate the admin
+        else:
+            if self.is_valid_id(id):
+                self.on_receive(msg,self.players[id])
+
+        if xml_dom:
+            xml_dom.unlink()
+
+    def on_ping(self, id, msg, xml_dom):
         #a REAL ping time implementation by Snowdog 8/03
         # recieves special server <ping time="###" /> command
         # where ### is a returning time from the clients ping command
-        elif tag_name == "ping":
-                        #i
-            #get current time, pull old time from object and compare them
-            # the difference is the latency between server and client * 2
-            ct = time.clock()
-            ot = xml_dom.getAttribute("time")
-            latency = float(float(ct) - float(ot))
-            latency = int( latency * 10000.0 )
-            latency = float( latency) / 10.0
-            ping_msg = "Ping Results: "+str(latency)+" ms (parsed message, round trip)"
-            self.on_receive(ping_msg,None)
+        #get current time, pull old time from object and compare them
+        # the difference is the latency between server and client * 2
+        ct = time.clock()
+        ot = xml_dom.getAttribute("time")
+        latency = float(float(ct) - float(ot))
+        latency = int( latency * 10000.0 )
+        latency = float( latency) / 10.0
+        ping_msg = "Ping Results: " + str(latency) + " ms (parsed message, round trip)"
+        self.on_receive(ping_msg,None)
+        if xml_dom:
+            xml_dom.unlink()
+
+    def on_group(self, id, msg, xml_dom):
+        name = xml_dom.getAttribute("name")
+        players = xml_dom.getAttribute("players")
+        act = xml_dom.getAttribute("action")
+        pwd = xml_dom.getAttribute("pwd")
+        group_data = (id, name, pwd, players)
+
+        if act == 'new':
+            self.groups[id] = group_data
+            self.on_group_event(mplay_event(GROUP_NEW, group_data))
+
+        elif act == 'del':
+            del self.groups[id]
+            self.on_group_event(mplay_event(GROUP_DEL, group_data))
+
+        elif act == 'update':
+            self.groups[id] = group_data
+            self.on_group_event(mplay_event(GROUP_UPDATE, group_data))
+
+        if xml_dom:
+            xml_dom.unlink()
 
 
-        elif tag_name == "group":
-            #print head
-            id = xml_dom.getAttribute("id")
-            name = xml_dom.getAttribute("name")
-            players = xml_dom.getAttribute("players")
-            act = xml_dom.getAttribute("action")
-            pwd = xml_dom.getAttribute("pwd")
-            group_data = (id,name,pwd,players)
-            if act=='new':
-                self.groups[id] = group_data
-                self.on_group_event(mplay_event(GROUP_NEW,group_data))
-            elif act=='del':
-                self.on_group_event(mplay_event(GROUP_DEL,group_data))
-                del self.groups[id]
-            elif act=='update':
-                self.groups[id] = group_data
-                self.on_group_event(mplay_event(GROUP_UPDATE,group_data))
-        elif tag_name == "role":
-            act = xml_dom.getAttribute("action")
-            role = xml_dom.getAttribute("role")
-            id = xml_dom.getAttribute("id")
-            if (act == "set") or (act == "update"):
-                try:
-                    (a,b,c,d,e,f,g,h) = self.players[id]
-                    if id == self.id:
-                        self.players[id] = (a,b,c,d,e,f,g,role)
-                        self.update_role(role)
-                    else:
-                        self.players[id] = (a,b,c,d,e,f,g,role)
-                    self.on_player_event(mplay_event(PLAYER_UPDATE,self.players[id]))
-                except:
-                    pass
+    def on_role(self, id, msg, xml_dom):
+        act = xml_dom.getAttribute("action")
+        role = xml_dom.getAttribute("role")
 
-        elif tag_name == "player":
-            act = xml_dom.getAttribute("action")
-            ip = xml_dom.getAttribute("ip")
-            id = xml_dom.getAttribute("id")
-            name = xml_dom.getAttribute("name")
-            status = xml_dom.getAttribute("status")
-            version = xml_dom.getAttribute("version")
-            protocol_version = xml_dom.getAttribute("protocol_version")
-            client_string = xml_dom.getAttribute("client_string")
+        if (act == "set") or (act == "update"):
             try:
-                player = (name,ip,id,status,version,protocol_version,client_string,self.players[id][7])
-            except Exception, e:
-                player = (name,ip,id,status,version,protocol_version,client_string,"Player")
-            if act == "new":
-                self.players[id] = player
-                self.on_player_event(mplay_event(PLAYER_NEW,self.players[id]))
-            elif act == "group":
-                self.group_id = xml_dom.getAttribute("group_id")
-                self.clear_players()
-                self.on_mplay_event(mplay_event(MPLAY_GROUP_CHANGE,self.groups[self.group_id]))
-                self.players[self.id] = self.get_my_info() #(self.name,self.ip,self.id,self.text_status)
-                self.on_player_event(mplay_event(PLAYER_NEW,self.players[self.id]))
-            elif act == "failed":
-                self.on_mplay_event(mplay_event(MPLAY_GROUP_CHANGE_F))
-            elif act == "del":
-                self.on_player_event(mplay_event(PLAYER_DEL,self.players[id]))
-                del self.players[id]
+                (a,b,c,d,e,f,g,h) = self.players[id]
                 if id == self.id:
-                    self.do_disconnect()
-            #  the next two cases handle the events that are used to let you know when others are typing
-            elif act == "update":
-                if id == self.id:
-                    self.players[id] = player
-                    self.update_self_from_player(player)
+                    self.players[id] = (a,b,c,d,e,f,g,role)
+                    self.update_role(role)
                 else:
-                    self.players[id] = player
-                dont_send = 0
-                for m in self.ignore_id:
-                    if m == id:
-                        dont_send=1
-                if dont_send <> 1:
-                    self.on_player_event(mplay_event(PLAYER_UPDATE,self.players[id]))
-        elif tag_name == "password":
-            signal = type = id = data = None
-            id = xml_dom.getAttribute("id")
-            type = xml_dom.getAttribute("type")
-            signal = xml_dom.getAttribute("signal")
-            data = xml_dom.getAttribute("data")
-            self.on_password_signal( signal,type,id,data )
+                    self.players[id] = (a,b,c,d,e,f,g,role)
+                self.on_player_event(mplay_event(PLAYER_UPDATE,self.players[id]))
+            except:
+                pass
+        if xml_dom:
+            xml_dom.unlink()
+
+    def on_player(self, id, msg, xml_dom):
+        act = xml_dom.getAttribute("action")
+        ip = xml_dom.getAttribute("ip")
+        name = xml_dom.getAttribute("name")
+        status = xml_dom.getAttribute("status")
+        version = xml_dom.getAttribute("version")
+        protocol_version = xml_dom.getAttribute("protocol_version")
+        client_string = xml_dom.getAttribute("client_string")
+
+        try:
+            player = (name,ip,id,status,version,protocol_version,client_string,self.players[id][7])
+        except Exception, e:
+            player = (name,ip,id,status,version,protocol_version,client_string,"Player")
+        if act == "new":
+            self.players[id] = player
+            self.on_player_event(mplay_event(PLAYER_NEW,self.players[id]))
+        elif act == "group":
+            self.group_id = xml_dom.getAttribute("group_id")
+            self.clear_players()
+            self.on_mplay_event(mplay_event(MPLAY_GROUP_CHANGE,self.groups[self.group_id]))
+            self.players[self.id] = self.get_my_info() #(self.name,self.ip,self.id,self.text_status)
+            self.on_player_event(mplay_event(PLAYER_NEW,self.players[self.id]))
+        elif act == "failed":
+            self.on_mplay_event(mplay_event(MPLAY_GROUP_CHANGE_F))
+        elif act == "del":
+            self.on_player_event(mplay_event(PLAYER_DEL,self.players[id]))
+            if self.players.has_key(id):
+                del self.players[id]
+            if id == self.id:
+                self.do_disconnect()
+        #  the next two cases handle the events that are used to let you know when others are typing
+        elif act == "update":
+            if id == self.id:
+                self.players[id] = player
+                self.update_self_from_player(player)
+            else:
+                self.players[id] = player
+            dont_send = 0
+            for m in self.ignore_id:
+                if m == id:
+                    dont_send=1
+            if dont_send != 1:
+                self.on_player_event(mplay_event(PLAYER_UPDATE,self.players[id]))
+        if xml_dom:
+            xml_dom.unlink()
+
+    def on_password(self, id, msg, xml_dom):
+        signal = type = id = data = None
+        id = xml_dom.getAttribute("id")
+        type = xml_dom.getAttribute("type")
+        signal = xml_dom.getAttribute("signal")
+        data = xml_dom.getAttribute("data")
+        self.on_password_signal( signal,type,id,data )
 
         if xml_dom:
             xml_dom.unlink()
@@ -824,48 +933,9 @@ class mplay_client(client_base):
             self.do_disconnect()
 
 
-## Not sure what this is doing here.  Obsolete concept.  Not needed.
-## If someone has been booted, we probably really don't want them
-## to automatically reconnect.  If we are trying to reconnect for some
-## other reason, then this is just going to poorly mask a bug which dearly
-## needs to be fixed.  Either way, this concept and code shouldn't be anywhere
-## near here.
-##    def reconnect(self):
-##        xml_dom = None
-##        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-##        (address,port) = self.host_server.split(":")
-
-##        if not port:
-##            port = 6774
-##        else:
-##            port = int(port)
-
-##        try:
-##            sock.connect((address,port))
-##            # send client into with id=0
-##            self.sendMsg( sock, self.toxml("update") )
-##            data = sock.recvMsg( self.sock )
-##            # get new id and group_id
-##            xml_dom = parseXml(data)
-##            xml_dom = xml_dom._get_documentElement()
-##            self.id = xml_dom.getAttribute("id")
-##            self.group_id = xml_dom.getAttribute("group_id")
-##            #send confirmation
-##            self.sendMsg( sock, self.toxml("update") )
-##        except Exception, e:
-##            self.log_msg(e)
-##            if xml_dom:
-##                xml_dom.unlink()
-##            return 0
-##        self.reset(sock)
-##        #self.status = MPLAY_CONNECTED
-##        self.on_mplay_event(mplay_event(MPLAY_CONNECTED))
-##        if xml_dom:
-##            xml_dom.unlink()
-##        return 1
 
 
-    def connect(self,addressport):
+    def connect(self, addressport):
         """Establish a connection to a server while still using sendThread & recvThread for its
         communication."""
 
@@ -880,7 +950,7 @@ class mplay_client(client_base):
         addressport_ar = addressport.split(":")
         if len(addressport_ar) == 1:
             address = addressport_ar[0]
-            port = 6774
+            port = OPENRPG_PORT
         else:
             address = addressport_ar[0]
             port = int(addressport_ar[1])
@@ -899,6 +969,18 @@ class mplay_client(client_base):
             xml_dom = xml_dom._get_documentElement()
             self.id = xml_dom.getAttribute("id")
             self.group_id = xml_dom.getAttribute("group_id")
+            if xml_dom.hasAttribute('useCompression') and xml_dom.getAttribute('useCompression') == 'True':
+                self.useCompression = True
+
+                if xml_dom.hasAttribute('cmpType'):
+                    if cmpBZ2 and xml_dom.getAttribute('cmpType') == 'bz2':
+                        self.compressionType = bz2
+                    elif cmpZLIB and xml_dom.getAttribute('cmpType') == 'zlib':
+                        self.compressionType = zlib
+                    else:
+                        self.compressionType = None
+                else:
+                    self.compressionType = bz2
 
             #send confirmation
             self.sendMsg( self.sock, self.toxml("new") )
@@ -906,7 +988,7 @@ class mplay_client(client_base):
         except Exception, e:
             self.log_msg(e)
             if xml_dom:
-                 xml_dom.unlink()
+                xml_dom.unlink()
             return 0
 
 
@@ -924,7 +1006,7 @@ class mplay_client(client_base):
     def start_disconnect(self):
         self.on_mplay_event(mplay_event(MPLAY_DISCONNECTING))
         self.outbox.put( self.toxml("del") )
-          ## Client Side Disconect Forced -- Snowdog 10-09-2003
+            ## Client Side Disconect Forced -- Snowdog 10-09-2003
         #pause to allow GUI events time to sync.
         time.sleep(1)
         self.do_disconnect()
@@ -936,6 +1018,7 @@ class mplay_client(client_base):
         self.clear_groups()
         self.useroles = 0
         self.on_mplay_event(mplay_event(MPLAY_DISCONNECTED))
+        self.useCompression = False
 
     def is_connected(self):
         return (self.status == MPLAY_CONNECTED)
