@@ -5,8 +5,8 @@
 #
 
 __appname__=' OpenRPG GUI Server v0.7 '
-__version__='$Revision: 1.16 $'[11:-2]
-__cvsinfo__='$Id: mplay_server_gui.py,v 1.16 2005/06/05 20:12:39 digitalxero Exp $'[5:-2]
+__version__='$Revision: 1.25 $'[11:-2]
+__cvsinfo__='$Id: mplay_server_gui.py,v 1.25 2006/11/04 21:24:22 digitalxero Exp $'[5:-2]
 __doc__="""
 OpenRPG Server Graphical Interface
 """
@@ -18,11 +18,7 @@ import types
 
 import orpg.dirpath
 import orpg.systempath
-
-from wxPython.wx import *
-from wxPython.lib.splashscreen import SplashScreen
-from wxPython.html import *
-import wxPython.lib.wxpTag
+from orpg.orpg_wx import *
 
 import webbrowser
 
@@ -37,39 +33,37 @@ from mplay_server import mplay_server
 SERVER_RUNNING = 1
 SERVER_STOPPED = 0
 
-MENU_START_SERVER = wxNewId()
-MENU_STOP_SERVER = wxNewId()
-MENU_EXIT = wxNewId()
+MENU_START_SERVER = wx.NewId()
+MENU_STOP_SERVER = wx.NewId()
+MENU_EXIT = wx.NewId()
 
-MENU_REGISTER_SERVER = wxNewId()
-MENU_UNREGISTER_SERVER = wxNewId()
+MENU_REGISTER_SERVER = wx.NewId()
+MENU_UNREGISTER_SERVER = wx.NewId()
 
-MENU_START_PING_PLAYERS = wxNewId()
-MENU_STOP_PING_PLAYERS = wxNewId()
-MENU_PING_INTERVAL = wxNewId()
+MENU_START_PING_PLAYERS = wx.NewId()
+MENU_STOP_PING_PLAYERS = wx.NewId()
+MENU_PING_INTERVAL = wx.NewId()
 
 # Add our menu id's for our right click popup
-MENU_PLAYER_BOOT = wxNewId()
-MENU_PLAYER_CREATE_ROOM = wxNewId()
-MENU_PLAYER_SEND_MESSAGE = wxNewId()
-MENU_PLAYER_SEND_ROOM_MESSAGE = wxNewId()
-MENU_PLAYER_SEND_SERVER_MESSAGE = wxNewId()
+MENU_PLAYER_BOOT = wx.NewId()
+MENU_PLAYER_CREATE_ROOM = wx.NewId()
+MENU_PLAYER_SEND_MESSAGE = wx.NewId()
+MENU_PLAYER_SEND_ROOM_MESSAGE = wx.NewId()
+MENU_PLAYER_SEND_SERVER_MESSAGE = wx.NewId()
 
 
 # Our new event type that gets posted from one
 # thread to another
-wxEVT_LOG_MESSAGE = wxNewId()*100+50
-wxEVT_FUNCTION_MESSAGE = wxNewId()*100+50
+wxEVT_LOG_MESSAGE = wx.NewEventType()
+wxEVT_FUNCTION_MESSAGE = wx.NewEventType()
 
 
 # Our event connector -- wxEVT_LOG_MESSAGE
-def EVT_LOG_MESSAGE( win, func ):
-    win.Connect( -1, -1, wxEVT_LOG_MESSAGE, func )
+EVT_LOG_MESSAGE = wx.PyEventBinder(wxEVT_LOG_MESSAGE, 1)
 
 
 # Our event connector -- wxEVT_FUNCTION_MESSAGE
-def EVT_FUNCTION_MESSAGE( win, func ):
-    win.Connect( -1, -1, wxEVT_FUNCTION_MESSAGE, func )
+EVT_FUNCTION_MESSAGE = wx.PyEventBinder(wxEVT_FUNCTION_MESSAGE, 1)
 
 
 
@@ -89,19 +83,19 @@ def format_bytes(b):
 
 # wxEVT_LOG_MESSAGE
 # MessageLogEvent ###############################
-class MessageLogEvent( wxPyEvent ):
+class MessageLogEvent(wx.PyEvent):
     def __init__( self, message ):
-        wxPyEvent.__init__( self )
-        self.SetEventType( wxEVT_LOG_MESSAGE )
+        wx.PyEvent.__init__( self )
+        self.SetEventType(wxEVT_LOG_MESSAGE)
         self.message = message
 
 
 # wxEVT_TUPLE_MESSAGE
 # MessageLogEvent ###############################
-class MessageFunctionEvent( wxPyEvent ):
+class MessageFunctionEvent(wx.PyEvent):
     def __init__( self, func, message ):
-        wxPyEvent.__init__( self )
-        self.SetEventType( wxEVT_FUNCTION_MESSAGE )
+        wx.PyEvent.__init__( self )
+        self.SetEventType(wxEVT_FUNCTION_MESSAGE)
         self.func = func
         self.message = message
 
@@ -161,7 +155,7 @@ class ServerMonitor(Thread):
         else:
             event = MessageLogEvent( mesg )
 
-        wxPostEvent( self.conf.owner, event )
+        wx.PostEvent( self.conf.owner, event )
         del event
 
 
@@ -189,39 +183,32 @@ class ServerMonitor(Thread):
 # GUI Server #####################################
 # Parent = notebook
 # Main = GUI
-class Connections(wxListCtrl):
+class Connections(wx.ListCtrl):
     def __init__( self, parent, main ):
-        wxListCtrl.__init__( self, parent, -1, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER|wxEXPAND|wxLC_HRULES )
+        wx.ListCtrl.__init__( self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.LC_REPORT|wx.SUNKEN_BORDER|wx.EXPAND|wx.LC_HRULES )
         self.main = main
         self.roomList = { "0" : "Lobby" }
 
-        self._imageList = wxImageList( 16, 16, false )
-        img = wxImage(orpg.dirpath.dir_struct["icon"]+"player.gif", wxBITMAP_TYPE_GIF).ConvertToBitmap()
+        self._imageList = wx.ImageList( 16, 16, False )
+        img = wx.Image(orpg.dirpath.dir_struct["icon"]+"player.gif", wx.BITMAP_TYPE_GIF).ConvertToBitmap()
         self._imageList.Add( img )
-        img = wxImage(orpg.dirpath.dir_struct["icon"]+"player-whisper.gif", wxBITMAP_TYPE_GIF).ConvertToBitmap()
+        img = wx.Image(orpg.dirpath.dir_struct["icon"]+"player-whisper.gif", wx.BITMAP_TYPE_GIF).ConvertToBitmap()
         self._imageList.Add( img )
-        self.SetImageList( self._imageList, wxIMAGE_LIST_SMALL )
+        self.SetImageList( self._imageList, wx.IMAGE_LIST_SMALL )
 
         # Set The columns
         self.InsertColumn(0, "ID")
         self.InsertColumn(1, "Player")
-        self.InsertColumn(2, "IP Address")
-        self.InsertColumn(3, "Status")
-        self.InsertColumn(4, "Room")
-        self.InsertColumn(5, "Version")
-        self.InsertColumn(6, "Role")
+        self.InsertColumn(2, "Status")
+        self.InsertColumn(3, "Room")
+        self.InsertColumn(4, "Version")
+        self.InsertColumn(5, "Role")
 
         # Set the column widths
-        self.SetColumnWidth(0, 60)
-        self.SetColumnWidth(1, 200)
-        self.SetColumnWidth(2, 100)
-        self.SetColumnWidth(3, 100)
-        self.SetColumnWidth(4, 120)
-        self.SetColumnWidth(5, 80)
-        self.SetColumnWidth(6,80)
+        self.AutoAjust()
 
         # Build our pop up menu to do cool things with the players in the list
-        self.menu = wxMenu()
+        self.menu = wx.Menu()
         self.menu.SetTitle( "Player Menu" )
         self.menu.Append( MENU_PLAYER_BOOT, "Boot Player" )
         self.menu.AppendSeparator()
@@ -230,36 +217,48 @@ class Connections(wxListCtrl):
 
 
         # Associate our events
-        EVT_RIGHT_DOWN( self, self.OnPopupMenu )
-        EVT_MENU( self, MENU_PLAYER_BOOT, self.OnPopupMenuItem )
-        EVT_MENU( self, MENU_PLAYER_SEND_MESSAGE, self.OnPopupMenuItem )
-        EVT_MENU( self, MENU_PLAYER_SEND_ROOM_MESSAGE, self.OnPopupMenuItem )
-        EVT_MENU( self, MENU_PLAYER_SEND_SERVER_MESSAGE, self.OnPopupMenuItem )
+        self.Bind(wx.EVT_RIGHT_DOWN, self.OnPopupMenu)
+        self.Bind(wx.EVT_MENU, self.OnPopupMenuItem, id=MENU_PLAYER_BOOT)
+        self.Bind(wx.EVT_MENU, self.OnPopupMenuItem, id=MENU_PLAYER_SEND_MESSAGE)
+        self.Bind(wx.EVT_MENU, self.OnPopupMenuItem, id=MENU_PLAYER_SEND_ROOM_MESSAGE)
+        self.Bind(wx.EVT_MENU, self.OnPopupMenuItem, id=MENU_PLAYER_SEND_SERVER_MESSAGE)
 
 
 
     def add(self, player):
         i = self.InsertImageStringItem( 0, player["id"], 0 )
         self.SetStringItem( i, 1, self.stripHtml( player["name"] ) )
-        self.SetStringItem( i, 2, player["ip"] )
-        self.SetStringItem( i, 3, "New - Idle" )
-        self.SetStringItem( i, 4, self.roomList[player["group_id"]] )
-        self.SetStringItem( i, 5, player["version"] )
-        self.SetStringItem( i, 6, "Lurker" )
+        self.SetStringItem( i, 2, "New - Idle" )
+        self.SetStringItem( i, 3, '' )
+        self.SetStringItem( i, 4, '' )
+        self.SetStringItem( i, 5, "Lurker" )
         self.SetItemData( i, int(player["id"]) )
+        self.AutoAjust()
 
 
     def remove(self, id):
         i = self.FindItemData( -1, int(id) )
         self.DeleteItem( i )
-        self.Refresh()
+        self.AutoAjust()
 
 
+    def AutoAjust(self):
+        self.SetColumnWidth(0, -1)
+        self.SetColumnWidth(1, -1)
+        self.SetColumnWidth(2, -1)
+        self.SetColumnWidth(3, -1)
+        self.SetColumnWidth(4, -1)
+        self.SetColumnWidth(5, -1)
+        self.Refresh()
+
     def update(self, player):
         i = self.FindItemData( -1, int(player["id"]) )
-        self.SetStringItem(i, 1, player["name"])
-        self.SetStringItem(i, 3, self.stripHtml( player["status"] ) )
-        self.Refresh()
+        if i > -1:
+            self.SetStringItem(i, 1, player["name"])
+            self.SetStringItem(i, 2, self.stripHtml( player["status"] ) )
+            self.AutoAjust()
+        else:
+            self.add(player)
 
 
     def updateRoom( self, data ):
@@ -297,7 +296,7 @@ class Connections(wxListCtrl):
 
     # When we right click, cause our popup menu to appear
     def OnPopupMenu( self, event ):
-        pos = wxPoint( event.GetX(), event.GetY() )
+        pos = wx.Point( event.GetX(), event.GetY() )
         (item, flag) = self.HitTest( pos )
         if item > -1:
             self.selectedItem = item
@@ -343,7 +342,7 @@ class Connections(wxListCtrl):
 
     def GetMessageInput( self, title ):
         prompt = "Please enter the message you wish to send:"
-        msg = wxTextEntryDialog(self, prompt, title)
+        msg = wx.TextEntryDialog(self, prompt, title)
         msg.ShowModal()
         msg.Destroy()
         return msg.GetValue()
@@ -351,27 +350,27 @@ class Connections(wxListCtrl):
 
 
 
-class ServerGUI(wxFrame):
+class ServerGUI(wx.Frame):
 
     STATUS = SERVER_STOPPED
 
     def __init__(self, parent, id, title):
-        wxFrame.__init__(self, parent, id, title, size = (760, 560) )
+        wx.Frame.__init__(self, parent, id, title, size = (760, 560) )
 
 
-        if wxPlatform == '__WXMSW__':
-            icon = wxIcon( orpg.dirpath.dir_struct["icon"]+'WAmisc9.ico', wxBITMAP_TYPE_ICO )
+        if wx.Platform == '__WXMSW__':
+            icon = wx.Icon( orpg.dirpath.dir_struct["icon"]+'WAmisc9.ico', wx.BITMAP_TYPE_ICO )
 
         else:
-            icon = wxIcon( orpg.dirpath.dir_struct["icon"]+'connect.gif', wxBITMAP_TYPE_GIF )
+            icon = wx.Icon( orpg.dirpath.dir_struct["icon"]+'connect.gif', wx.BITMAP_TYPE_GIF )
 
         self.SetIcon(icon)
         self.serverName = "Server Name"
 
         # Register our events to process -- notice the custom event handler
-        EVT_CLOSE( self, self.OnExit )
-        EVT_LOG_MESSAGE( self, self.OnLogMessage )
-        EVT_FUNCTION_MESSAGE( self, self.OnFunctionMessage )
+        self.Bind(wx.EVT_CLOSE, self.OnExit)
+        self.Bind(EVT_LOG_MESSAGE, self.OnLogMessage)
+        self.Bind(EVT_FUNCTION_MESSAGE, self.OnFunctionMessage)
 
         # Creat GUI
         self.build_menu()
@@ -405,89 +404,88 @@ class ServerGUI(wxFrame):
         """ Build the GUI menu. """
 
 
-        self.mainMenu = wxMenuBar()
+        self.mainMenu = wx.MenuBar()
 
         # File Menu
-        menu = wxMenu()
+        menu = wx.Menu()
 
         # Start
         menu.Append( MENU_START_SERVER, 'Start', 'Start server.')
-        EVT_MENU(self, MENU_START_SERVER, self.OnStart)
+        self.Bind(wx.EVT_MENU, self.OnStart, id=MENU_START_SERVER)
 
         # Stop
         menu.Append( MENU_STOP_SERVER, 'Stop', 'Shutdown server.')
-        EVT_MENU(self, MENU_STOP_SERVER, self.OnStop)
+        self.Bind(wx.EVT_MENU, self.OnStop, id=MENU_STOP_SERVER)
 
         # Exit
         menu.AppendSeparator()
         menu.Append( MENU_EXIT, 'E&xit', 'Exit application.')
-        EVT_MENU(self, MENU_EXIT, self.OnExit)
+        self.Bind(wx.EVT_MENU, self.OnExit, id=MENU_EXIT)
 
         self.mainMenu.Append(menu, '&Server')
 
         # Registration Menu
-        menu = wxMenu()
+        menu = wx.Menu()
 
         # Register
         menu.Append( MENU_REGISTER_SERVER, 'Register', 'Register with OpenRPG server directory.')
-        EVT_MENU( self, MENU_REGISTER_SERVER, self.OnRegister )
+        self.Bind(wx.EVT_MENU, self.OnRegister, id=MENU_REGISTER_SERVER)
 
         # Unregister
         menu.Append( MENU_UNREGISTER_SERVER, 'Unregister', 'Unregister from OpenRPG server directory.')
-        EVT_MENU( self, MENU_UNREGISTER_SERVER, self.OnUnregister )
+        self.Bind(wx.EVT_MENU, self.OnUnregister, id=MENU_UNREGISTER_SERVER)
 
         # Add the registration menu
         self.mainMenu.Append( menu, '&Registration' )
 
         # Server Configuration Menu
-        menu = wxMenu()
+        menu = wx.Menu()
 
         # Ping Connected Players
         menu.Append( MENU_START_PING_PLAYERS, 'Start Ping', 'Ping players to validate remote connection.' )
-        EVT_MENU( self, MENU_START_PING_PLAYERS, self.PingPlayers )
+        self.Bind(wx.EVT_MENU, self.PingPlayers, id=MENU_START_PING_PLAYERS)
 
         # Stop Pinging Connected Players
         menu.Append( MENU_STOP_PING_PLAYERS, 'Stop Ping', 'Stop validating player connections.' )
-        EVT_MENU( self, MENU_STOP_PING_PLAYERS, self.StopPingPlayers )
+        self.Bind(wx.EVT_MENU, self.StopPingPlayers, id=MENU_STOP_PING_PLAYERS)
 
         # Set Ping Interval
         menu.Append( MENU_PING_INTERVAL, 'Ping Interval', 'Change the ping interval.' )
-        EVT_MENU( self, MENU_PING_INTERVAL, self.ConfigPingInterval )
+        self.Bind(wx.EVT_MENU, self.ConfigPingInterval, id=MENU_PING_INTERVAL)
         self.mainMenu.Append( menu, '&Configuration' )
 
         # Add the menus to the main menu bar
         self.SetMenuBar( self.mainMenu )
 
         # Disable register, unregister & stop server by default
-        self.mainMenu.Enable( MENU_STOP_SERVER, false )
-        self.mainMenu.Enable( MENU_REGISTER_SERVER, false )
-        self.mainMenu.Enable( MENU_UNREGISTER_SERVER, false )
+        self.mainMenu.Enable( MENU_STOP_SERVER, False )
+        self.mainMenu.Enable( MENU_REGISTER_SERVER, False )
+        self.mainMenu.Enable( MENU_UNREGISTER_SERVER, False )
 
         # Disable the ping menu items
-        self.mainMenu.Enable( MENU_START_PING_PLAYERS, false )
-        self.mainMenu.Enable( MENU_STOP_PING_PLAYERS, false )
-        self.mainMenu.Enable( MENU_PING_INTERVAL, false )
+        self.mainMenu.Enable( MENU_START_PING_PLAYERS, False )
+        self.mainMenu.Enable( MENU_STOP_PING_PLAYERS, False )
+        self.mainMenu.Enable( MENU_PING_INTERVAL, False )
 
 
 
     def build_body(self):
         """ Create the ViewNotebook and logger. """
-        splitter = wxSplitterWindow(self, -1, style=wxNO_3D|wxSP_3D)
+        splitter = wx.SplitterWindow(self, -1, style=wx.NO_3D | wx.SP_3D)
 
-        nb = wxNotebook( splitter, -1 )
+        nb = wx.Notebook( splitter, -1 )
         self.conns = Connections( nb, self )
         nb.AddPage( self.conns, "Players" )
 
         ##nb.AddPage( self.conns, "Rooms" )
 
-        self.msgWindow = HTMLMessageWindow( nb )
-        nb.AddPage( self.msgWindow, "Messages" )
+        #self.msgWindow = HTMLMessageWindow( nb )
+        #nb.AddPage( self.msgWindow, "Messages" )
 
-        log = wxTextCtrl(splitter, -1, style = wxTE_MULTILINE|wxTE_READONLY|wxHSCROLL)
-        wxLog_SetActiveTarget( wxLogTextCtrl(log) )
+        log = wx.TextCtrl(splitter, -1, style=wx.TE_MULTILINE | wx.TE_READONLY | wx.HSCROLL)
+        wx.Log.SetActiveTarget( wx.LogTextCtrl(log) )
 
         splitter.SplitHorizontally(nb, log, 400)
-        #splitter.SetSashPosition(400, true)
         splitter.SetMinimumPaneSize(40)
 
         self.nb = nb
@@ -496,7 +494,7 @@ class ServerGUI(wxFrame):
 
     def build_status(self):
         """ Create status bar and set defaults. """
-        sb = wxStatusBar(self, -1)
+        sb = wx.StatusBar(self, -1)
         sb.SetFieldsCount(5)
         sb.SetStatusWidths([-1, 115, 115, 65, 200])
         sb.SetStatusText("Sent: 0", 1)
@@ -512,7 +510,7 @@ class ServerGUI(wxFrame):
             mesg (str) -- error message to display
             title (str) -- title of window
         """
-        dlg = wxMessageDialog(self, mesg, title, wxOK | wxICON_EXCLAMATION)
+        dlg = wx.MessageDialog(self, mesg, title, wx.OK | wx.ICON_EXCLAMATION)
         dlg.ShowModal()
         dlg.Destroy()
 
@@ -529,7 +527,7 @@ class ServerGUI(wxFrame):
 
     ### Server Callbacks #####################################
     def Log(self, log):
-        wxLogMessage(str(log))
+        wx.LogMessage(str(log))
 
 
     def OnConnect(self, player):
@@ -583,23 +581,23 @@ class ServerGUI(wxFrame):
     def OnStart(self, event = None):
         """ Start server. """
         if self.STATUS == SERVER_STOPPED:
-            serverNameEntry = wxTextEntryDialog( self, "Please Enter The Server Name You Wish To Use:",
-                                                 "Server's Name", self.serverName, wxOK|wxCANCEL|wxCENTRE )
+            serverNameEntry = wx.TextEntryDialog( self, "Please Enter The Server Name You Wish To Use:",
+                                                 "Server's Name", self.serverName, wx.OK|wx.CANCEL|wx.CENTRE )
 
-            if serverNameEntry.ShowModal() == wxID_OK:
+            if serverNameEntry.ShowModal() == wx.ID_OK:
                 self.serverName = serverNameEntry.GetValue()
 
                 if len( self.serverName ):
-                    wxBeginBusyCursor()
+                    wx.BeginBusyCursor()
                     self.server = ServerMonitor( self.callbacks, self.conf, self.serverName )
                     self.server.start()
                     self.STATUS = SERVER_RUNNING
                     self.sb.SetStatusText("Running", 3)
                     self.SetTitle(__appname__ + "- (running) - (unregistered)")
-                    self.mainMenu.Enable( MENU_START_SERVER, false )
-                    self.mainMenu.Enable( MENU_STOP_SERVER, true )
-                    self.mainMenu.Enable( MENU_REGISTER_SERVER, true )
-                    wxEndBusyCursor()
+                    self.mainMenu.Enable( MENU_START_SERVER, False )
+                    self.mainMenu.Enable( MENU_STOP_SERVER, True )
+                    self.mainMenu.Enable( MENU_REGISTER_SERVER, True )
+                    wx.EndBusyCursor()
                 else:
                     self.show_error("Server is already running.", "Error Starting Server")
 
@@ -612,10 +610,10 @@ class ServerGUI(wxFrame):
             self.STATUS = SERVER_STOPPED
             self.sb.SetStatusText("Stopped", 3)
             self.SetTitle(__appname__ + "- (stopped) - (unregistered)")
-            self.mainMenu.Enable( MENU_STOP_SERVER, false )
-            self.mainMenu.Enable( MENU_START_SERVER, true )
-            self.mainMenu.Enable( MENU_REGISTER_SERVER, false )
-            self.mainMenu.Enable( MENU_UNREGISTER_SERVER, false )
+            self.mainMenu.Enable( MENU_STOP_SERVER, False )
+            self.mainMenu.Enable( MENU_START_SERVER, True )
+            self.mainMenu.Enable( MENU_REGISTER_SERVER, False )
+            self.mainMenu.Enable( MENU_UNREGISTER_SERVER, False )
 
             # Delete any items that are still in the player list
             self.conns.DeleteAllItems()
@@ -629,15 +627,15 @@ class ServerGUI(wxFrame):
         """
 
         if len( self.serverName ):
-            wxBeginBusyCursor()
+            wx.BeginBusyCursor()
             self.server.server.register(self.serverName)
 
             self.sb.SetStatusText( ("%s" % (self.serverName)), 4 )
-            self.mainMenu.Enable( MENU_REGISTER_SERVER, false )
-            self.mainMenu.Enable( MENU_UNREGISTER_SERVER, true )
-            self.mainMenu.Enable( MENU_STOP_SERVER, false )
+            self.mainMenu.Enable( MENU_REGISTER_SERVER, False )
+            self.mainMenu.Enable( MENU_UNREGISTER_SERVER, True )
+            self.mainMenu.Enable( MENU_STOP_SERVER, False )
             self.SetTitle(__appname__ + "- (running) - (registered)")
-            wxEndBusyCursor()
+            wx.EndBusyCursor()
 
 
 
@@ -648,23 +646,23 @@ class ServerGUI(wxFrame):
             from all metas
         """
 
-        wxBeginBusyCursor()
+        wx.BeginBusyCursor()
         self.server.server.unregister()
 
         self.sb.SetStatusText( "Unregistered", 4 )
-        self.mainMenu.Enable( MENU_UNREGISTER_SERVER, false )
-        self.mainMenu.Enable( MENU_REGISTER_SERVER, true )
-        self.mainMenu.Enable( MENU_STOP_SERVER, true )
+        self.mainMenu.Enable( MENU_UNREGISTER_SERVER, False )
+        self.mainMenu.Enable( MENU_REGISTER_SERVER, True )
+        self.mainMenu.Enable( MENU_STOP_SERVER, True )
         self.SetTitle(__appname__ + "- (running) - (unregistered)")
-        wxEndBusyCursor()
+        wx.EndBusyCursor()
 
 
 
     def PingPlayers( self, event = None ):
         "Ping all players that are connected at a periodic interval, detecting dropped connections."
-        wxBeginBusyCursor()
-        wxYield()
-        wxEndBusyCursor()
+        wx.BeginBusyCursor()
+        wx.Yield()
+        wx.EndBusyCursor()
 
 
     def StopPingPlayers( self, event = None ):
@@ -678,36 +676,39 @@ class ServerGUI(wxFrame):
     def OnExit(self, event = None):
         """ Quit the program. """
         self.OnStop()
-        self.Destroy()
+        wx.CallAfter(self.Destroy)
 
 
 
-class ServerGUIApp(wxApp):
+class ServerGUIApp(wx.App):
     def OnInit(self):
         # Make sure our image handlers are loaded before we try to display anything
-        wxInitAllImageHandlers()
-        self.splash = SplashScreen(None, bitmapfile=orpg.dirpath.dir_struct["icon"]+'splash.gif',
-                              duration=2000, callback=self.AfterSplash)
-        self.splash.Show(true)
-        wxYield()
-        return true
+        wx.InitAllImageHandlers()
+        self.splash = wx.SplashScreen(wx.Bitmap(orpg.dirpath.dir_struct["icon"]+'splash.gif'),
+                              wx.SPLASH_CENTRE_ON_SCREEN|wx.SPLASH_TIMEOUT,
+                              2000,
+                              None)
+        self.splash.Show(True)
+        wx.Yield()
+        wx.CallAfter(self.AfterSplash)
+        return True
 
 
     def AfterSplash(self):
-        self.splash.Close(true)
+        self.splash.Close(True)
         frame = ServerGUI(None, -1, __appname__ + "- (stopped) - (unregistered)")
-        frame.Show(true)
+        frame.Show(True)
         frame.Raise()
         self.SetTopWindow(frame)
 
 
 
-class HTMLMessageWindow( wxHtmlWindow ):
+class HTMLMessageWindow(wx.html.HtmlWindow):
     "Widget used to present user to admin messages, in HTML format, to the server administrator"
 
     # Init using the derived from class
     def __init__( self, parent ):
-        wxHtmlWindow.__init__( self, parent )
+        wx.html.HtmlWindow.__init__( self, parent )
 
 
     def OnLinkClicked( self, ref ):
@@ -721,4 +722,3 @@ class HTMLMessageWindow( wxHtmlWindow ):
 if __name__ == '__main__':
     app = ServerGUIApp(0)
     app.MainLoop()
-
