@@ -22,12 +22,12 @@
 # Author: Chris Davis
 # Maintainer:
 # Version:
-#   $Id: player_list.py,v 1.15 2005/10/24 02:06:04 tdb30_ Exp $
+#   $Id: player_list.py,v 1.28 2007/02/09 01:42:48 digitalxero Exp $
 #
 # Description: This is the main entry point of the oprg application
 #
 
-__version__ = "$Id: player_list.py,v 1.15 2005/10/24 02:06:04 tdb30_ Exp $"
+__version__ = "$Id: player_list.py,v 1.28 2007/02/09 01:42:48 digitalxero Exp $"
 
 from orpg.orpg_windows import *
 import orpg.dirpath
@@ -42,19 +42,19 @@ global ROLE_LURKER; ROLE_LURKER = "LURKER"
 #########################
 #player frame window
 #########################
-PLAYER_BOOT = wxNewId()
-PLAYER_WHISPER = wxNewId()
-PLAYER_IGNORE = wxNewId()
-PLAYER_ROLE_MENU = wxNewId()
-PLAYER_ROLE_LURKER = wxNewId()
-PLAYER_ROLE_PLAYER = wxNewId()
-PLAYER_ROLE_GM = wxNewId()
-PLAYER_MODERATE_MENU = wxNewId()
-PLAYER_MODERATE_ROOM_ON = wxNewId()
-PLAYER_MODERATE_ROOM_OFF = wxNewId()
-PLAYER_MODERATE_GIVE_VOICE = wxNewId()
-PLAYER_MODERATE_TAKE_VOICE = wxNewId()
-PLAYER_SHOW_VERSION = wxNewId()
+PLAYER_BOOT = wx.NewId()
+PLAYER_WHISPER = wx.NewId()
+PLAYER_IGNORE = wx.NewId()
+PLAYER_ROLE_MENU = wx.NewId()
+PLAYER_ROLE_LURKER = wx.NewId()
+PLAYER_ROLE_PLAYER = wx.NewId()
+PLAYER_ROLE_GM = wx.NewId()
+PLAYER_MODERATE_MENU = wx.NewId()
+PLAYER_MODERATE_ROOM_ON = wx.NewId()
+PLAYER_MODERATE_ROOM_OFF = wx.NewId()
+PLAYER_MODERATE_GIVE_VOICE = wx.NewId()
+PLAYER_MODERATE_TAKE_VOICE = wx.NewId()
+PLAYER_SHOW_VERSION = wx.NewId()
 
 
 WG_LIST = {}
@@ -62,9 +62,9 @@ WG_LIST = {}
 #---------------------------------------------------------
 # [START] Digitalxero Multi Whisper Group 1/1/05
 #---------------------------------------------------------
-PLAYER_WG_MENU = wxNewId()
-PLAYER_WG_CREATE = wxNewId()
-PLAYER_WG_CLEAR_ALL = wxNewId()
+PLAYER_WG_MENU = wx.NewId()
+PLAYER_WG_CREATE = wx.NewId()
+PLAYER_WG_CLEAR_ALL = wx.NewId()
 WG_MENU_LIST = {}
 #---------------------------------------------------------
 # [END] Digitalxero Multi Whisper Group 1/1/05
@@ -74,30 +74,33 @@ WG_MENU_LIST = {}
 # [START] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
 
-PLAYER_COMMAND_MENU = wxNewId()
-PLAYER_COMMAND_PASSWORD_ALTER = wxNewId()
-PLAYER_COMMAND_ROOM_RENAME = wxNewId()
+PLAYER_COMMAND_MENU = wx.NewId()
+PLAYER_COMMAND_PASSWORD_ALTER = wx.NewId()
+PLAYER_COMMAND_ROOM_RENAME = wx.NewId()
 
 #---------------------------------------------------------
 # [END] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
 
 
-class player_list(wxListCtrl):
+class player_list(wx.ListCtrl):
     def __init__( self, parent, openrpg ):
-##        wxListCtrl.__init__( self, parent, -1, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER|wxEXPAND )
-        wxListCtrl.__init__( self, parent, -1, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER|wxEXPAND|wxLC_HRULES )
+##        wx.ListCtrl.__init__( self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.LC_REPORT|wx.SUNKEN_BORDER|wx.EXPAND )
+        wx.ListCtrl.__init__( self, parent, -1, wx.DefaultPosition, wx.DefaultSize, wx.LC_REPORT|wx.SUNKEN_BORDER|wx.EXPAND|wx.LC_HRULES )
 
-        self.myopenrpg = openrpg
-        self.session = self.myopenrpg.get_component("session")
+        self.openrpg = openrpg
+        self.session = self.openrpg.get_component("session")
+        self.settings = self.openrpg.get_component('settings')
+        self.chat = self.openrpg.get_component('chat')
+        self.password_manager = self.openrpg.get_component("password_manager")
         # Create in image list -- for whatever reason...guess it will be nice when we can tell which is a bot
         self.whisperCount = 0
-        self._imageList = wxImageList( 16, 16, false )
-        img = wxImage(orpg.dirpath.dir_struct["icon"]+"player.gif", wxBITMAP_TYPE_GIF).ConvertToBitmap()
+        self._imageList = wx.ImageList( 16, 16, False )
+        img = wx.Image(orpg.dirpath.dir_struct["icon"]+"player.gif", wx.BITMAP_TYPE_GIF).ConvertToBitmap()
         self._imageList.Add( img )
-        img = wxImage(orpg.dirpath.dir_struct["icon"]+"player-whisper.gif", wxBITMAP_TYPE_GIF).ConvertToBitmap()
+        img = wx.Image(orpg.dirpath.dir_struct["icon"]+"player-whisper.gif", wx.BITMAP_TYPE_GIF).ConvertToBitmap()
         self._imageList.Add( img )
-        self.SetImageList( self._imageList, wxIMAGE_LIST_SMALL )
+        self.SetImageList( self._imageList, wx.IMAGE_LIST_SMALL )
 
         # Create our column headers
         self.InsertColumn( 0, "ID" )
@@ -107,7 +110,7 @@ class player_list(wxListCtrl):
 # [START] Digitalxero Multi Whisper Group 1/1/05
 #---------------------------------------------------------
         ##Main Menu
-        self.wgMenu = wxMenu()
+        self.wgMenu = wx.Menu()
 
         #Add the Base Menu items, so they are always at the bottom
         self.wgMenu.Append(PLAYER_WG_CREATE, "Create")
@@ -119,14 +122,14 @@ class player_list(wxListCtrl):
 #---------------------------------------------------------
 
         # Create the role menu
-        self.roleMenu = wxMenu()
+        self.roleMenu = wx.Menu()
         self.roleMenu.SetTitle( "Assign Role" )
         self.roleMenu.Append( PLAYER_ROLE_LURKER, "Lurker" )
         self.roleMenu.Append( PLAYER_ROLE_PLAYER, "Player" )
         self.roleMenu.Append( PLAYER_ROLE_GM, "GM" )
 
         # Create the moderation menu
-        self.moderateMenu = wxMenu()
+        self.moderateMenu = wx.Menu()
         self.moderateMenu.SetTitle( "Moderate" )
         self.moderateMenu.Append( PLAYER_MODERATE_ROOM_ON, "Room Moderation ON" )
         self.moderateMenu.Append( PLAYER_MODERATE_ROOM_OFF, "Room Moderation OFF" )
@@ -140,7 +143,7 @@ class player_list(wxListCtrl):
 
 
         # Create the room control menu
-        self.commandMenu = wxMenu()
+        self.commandMenu = wx.Menu()
         self.commandMenu.SetTitle( "Room Controls" )
         self.commandMenu.Append( PLAYER_COMMAND_PASSWORD_ALTER, "Password" )
         self.commandMenu.Append( PLAYER_COMMAND_ROOM_RENAME, "Room Name" )
@@ -151,7 +154,7 @@ class player_list(wxListCtrl):
 #---------------------------------------------------------
 
         # Create the pop up menu
-        self.menu = wxMenu()
+        self.menu = wx.Menu()
         self.menu.SetTitle( "Player Menu" )
         self.menu.Append( PLAYER_BOOT, "Boot" )
         self.menu.AppendSeparator()
@@ -174,38 +177,35 @@ class player_list(wxListCtrl):
         self.menu.Append( PLAYER_SHOW_VERSION, "Version" )
 
         # Event processing for our menu
-        EVT_MENU( self, PLAYER_BOOT, self.on_menu_item )
-        EVT_MENU( self, PLAYER_IGNORE, self.on_menu_item )
-        EVT_MENU( self, PLAYER_WHISPER, self.on_menu_item )
-        EVT_MENU( self, PLAYER_MODERATE_ROOM_ON, self.on_menu_moderate )
-        EVT_MENU( self, PLAYER_MODERATE_ROOM_OFF, self.on_menu_moderate )
-        EVT_MENU( self, PLAYER_MODERATE_GIVE_VOICE, self.on_menu_moderate )
-        EVT_MENU( self, PLAYER_MODERATE_TAKE_VOICE, self.on_menu_moderate )
-        EVT_MENU( self, PLAYER_ROLE_LURKER, self.on_menu_role_change )
-        EVT_MENU( self, PLAYER_ROLE_PLAYER, self.on_menu_role_change )
-        EVT_MENU( self, PLAYER_ROLE_GM, self.on_menu_role_change )
-        EVT_MENU( self, PLAYER_SHOW_VERSION, self.on_menu_item )
+        self.Bind(wx.EVT_MENU, self.on_menu_item, id=PLAYER_BOOT)
+        self.Bind(wx.EVT_MENU, self.on_menu_item, id=PLAYER_IGNORE)
+        self.Bind(wx.EVT_MENU, self.on_menu_item, id=PLAYER_WHISPER)
+        self.Bind(wx.EVT_MENU, self.on_menu_moderate, id=PLAYER_MODERATE_ROOM_ON)
+        self.Bind(wx.EVT_MENU, self.on_menu_moderate, id=PLAYER_MODERATE_ROOM_OFF)
+        self.Bind(wx.EVT_MENU, self.on_menu_moderate, id=PLAYER_MODERATE_GIVE_VOICE)
+        self.Bind(wx.EVT_MENU, self.on_menu_moderate, id=PLAYER_MODERATE_TAKE_VOICE)
+        self.Bind(wx.EVT_MENU, self.on_menu_role_change, id=PLAYER_ROLE_LURKER)
+        self.Bind(wx.EVT_MENU, self.on_menu_role_change, id=PLAYER_ROLE_PLAYER)
+        self.Bind(wx.EVT_MENU, self.on_menu_role_change, id=PLAYER_ROLE_GM)
+        self.Bind(wx.EVT_MENU, self.on_menu_item, id=PLAYER_SHOW_VERSION)
 #---------------------------------------------------------
 # [START] Digitalxero Multi Whisper Group 1/1/05
 #---------------------------------------------------------
-        EVT_MENU( self, PLAYER_WG_CREATE, self.on_menu_whispergroup )
-        EVT_MENU( self, PLAYER_WG_CLEAR_ALL, self.on_menu_whispergroup )
+        self.Bind(wx.EVT_MENU, self.on_menu_whispergroup, id=PLAYER_WG_CREATE)
+        self.Bind(wx.EVT_MENU, self.on_menu_whispergroup, id=PLAYER_WG_CLEAR_ALL)
 #---------------------------------------------------------
 # [END] Digitalxero Multi Whisper Group 1/1/05
 #---------------------------------------------------------
 #---------------------------------------------------------
 # [START] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
-        EVT_MENU( self, PLAYER_COMMAND_PASSWORD_ALTER, self.on_menu_password )
-        EVT_MENU( self, PLAYER_COMMAND_ROOM_RENAME, self.on_menu_room_rename )
+        self.Bind(wx.EVT_MENU, self.on_menu_password, id=PLAYER_COMMAND_PASSWORD_ALTER)
+        self.Bind(wx.EVT_MENU, self.on_menu_room_rename, id=PLAYER_COMMAND_ROOM_RENAME)
 #---------------------------------------------------------
 # [END] Snowdog Password/Room Name altering code 12/02
 #---------------------------------------------------------
-        EVT_LEFT_DCLICK(self,self.on_d_lclick)
-        EVT_RIGHT_DOWN( self, self.on_menu )
-        #EVT_SIZE( self, self.on_size )
-
-        #self.on_size(None)
+        self.Bind(wx.EVT_LEFT_DCLICK, self.on_d_lclick)
+        self.Bind(wx.EVT_RIGHT_DOWN, self.on_menu)
         self.sized = 1
 
 #---------------------------------------------------------
@@ -217,29 +217,29 @@ class player_list(wxListCtrl):
 
     def on_menu_password( self, evt ):
         id = evt.GetId()
-        session = self.myopenrpg.get_component("session")
-        password_manager = self.myopenrpg.get_component("password_manager")
-        chat = self.myopenrpg.get_component("chat")
-        boot_pwd = password_manager.GetPassword("admin",int(session.group_id))
+        self.session = self.openrpg.get_component("session")
+        self.password_manager = self.openrpg.get_component("password_manager")
+        self.chat = self.openrpg.get_component("chat")
+        boot_pwd = self.password_manager.GetPassword("admin",int(self.session.group_id))
         if boot_pwd != None:
-            alter_pwd_dialog = wxTextEntryDialog(self,"Enter new room password: (blank for no password)","Alter Room Password")
-            if alter_pwd_dialog.ShowModal() == wxID_OK:
+            alter_pwd_dialog = wx.TextEntryDialog(self,"Enter new room password: (blank for no password)","Alter Room Password")
+            if alter_pwd_dialog.ShowModal() == wx.ID_OK:
                 new_pass = alter_pwd_dialog.GetValue()
-                chat.InfoPost( "Requesting password change on server..." )
-                session.set_room_pass(new_pass, boot_pwd)
+                self.chat.InfoPost( "Requesting password change on server..." )
+                self.session.set_room_pass(new_pass, boot_pwd)
 
 
     def on_menu_room_rename( self, evt ):
         id = evt.GetId()
-        session = self.myopenrpg.get_component("session")
-        password_manager = self.myopenrpg.get_component("password_manager")
-        chat = self.myopenrpg.get_component("chat")
-        boot_pwd = password_manager.GetPassword("admin",int(session.group_id))
+        self.session = self.openrpg.get_component("session")
+        self.password_manager = self.openrpg.get_component("password_manager")
+        self.chat = self.openrpg.get_component("chat")
+        boot_pwd = self.password_manager.GetPassword("admin",int(self.session.group_id))
         if boot_pwd != None:
-            alter_name_dialog = wxTextEntryDialog(self,"Enter new room name: ","Change Room Name")
-            if alter_name_dialog.ShowModal() == wxID_OK:
+            alter_name_dialog = wx.TextEntryDialog(self,"Enter new room name: ","Change Room Name")
+            if alter_name_dialog.ShowModal() == wx.ID_OK:
                 new_name = alter_name_dialog.GetValue()
-                chat.InfoPost( "Requesting room name change on server..." )
+                self.chat.InfoPost( "Requesting room name change on server..." )
 
                 loc = new_name.find("&")
                 oldloc=0
@@ -250,7 +250,7 @@ class player_list(wxListCtrl):
                         e = new_name[loc+1:]
                         new_name = b + "&amp;" + e
                         oldloc = loc +1
-			
+
                 loc = new_name.find("'")
                 oldloc=0
                 while loc > -1:
@@ -268,10 +268,10 @@ class player_list(wxListCtrl):
                     if loc > -1:
                         b = new_name[:loc]
                         e = new_name[loc+1:]
-                        new_name = b + "&#39;&#39;" + e
+                        new_name = b + "&quote" + e
                         oldloc = loc +1
 
-                session.set_room_name(new_name, boot_pwd)
+                self.session.set_room_name(new_name, boot_pwd)
 
 #---------------------------------------------------------
 # [END] Snowdog Password/Room Name altering code 12/02
@@ -293,39 +293,41 @@ class player_list(wxListCtrl):
         return
 
     def on_menu_whispergroup( self, evt ):
-            "Add/Remove players from Whisper Groups"
+        self.session = self.openrpg.get_component("session")
+        self.settings = self.openrpg.get_component('settings')
+        self.chat = self.openrpg.get_component('chat')
+        "Add/Remove players from Whisper Groups"
 
-            id = evt.GetId()
-            item = self.GetItem( self.selected_item )
-            chat = self.myopenrpg.get_component("chat")
-
-            #See if it is the main menu
-            if id == PLAYER_WG_CREATE:
-                create_new_group_dialog = wxTextEntryDialog(self,"Enter Group Name","Create New Whisper Group")
-                if create_new_group_dialog.ShowModal() == wxID_OK:
-                    group_name = create_new_group_dialog.GetValue()
-                    WG_LIST[group_name] = {}
-                return
-            elif id == PLAYER_WG_CLEAR_ALL:
-                WG_LIST.clear()
-                return
-
-            #Check Sub Menus
-            for mid in WG_MENU_LIST:
-                if id == WG_MENU_LIST[mid]["add"]:
-                    WG_LIST[mid][int(item.GetText())] = int(item.GetText())
-                    return
-                elif id == WG_MENU_LIST[mid]["remove"]:
-                    del WG_LIST[mid][int(item.GetText())]
-                    return
-                elif id == WG_MENU_LIST[mid]["clear"]:
-                    WG_LIST[mid].clear()
-                    return
-                elif id == WG_MENU_LIST[mid]["whisper"]:
-                    chat.set_chat_text("/gw " + mid + "=")
-                    return
+        id = evt.GetId()
+        item = self.GetItem( self.selected_item )
 
+        #See if it is the main menu
+        if id == PLAYER_WG_CREATE:
+            create_new_group_dialog = wx.TextEntryDialog(self,"Enter Group Name","Create New Whisper Group")
+            if create_new_group_dialog.ShowModal() == wx.ID_OK:
+                group_name = create_new_group_dialog.GetValue()
+                WG_LIST[group_name] = {}
             return
+        elif id == PLAYER_WG_CLEAR_ALL:
+            WG_LIST.clear()
+            return
+
+        #Check Sub Menus
+        for mid in WG_MENU_LIST:
+            if id == WG_MENU_LIST[mid]["add"]:
+                WG_LIST[mid][int(item.GetText())] = int(item.GetText())
+                return
+            elif id == WG_MENU_LIST[mid]["remove"]:
+                del WG_LIST[mid][int(item.GetText())]
+                return
+            elif id == WG_MENU_LIST[mid]["clear"]:
+                WG_LIST[mid].clear()
+                return
+            elif id == WG_MENU_LIST[mid]["whisper"]:
+                self.chat.set_chat_text("/gw " + mid + "=")
+                return
+
+        return
 
 #---------------------------------------------------------
 # [END] Digitalxero Multi Whisper Group 1/1/05
@@ -337,7 +339,8 @@ class player_list(wxListCtrl):
         "Change the moderated status of a room or player."
 
         id = evt.GetId()
-        chat = self.myopenrpg.get_component( "chat" )
+        self.chat = self.openrpg.get_component( "chat" )
+        self.session = self.openrpg.get_component("session")
         playerID = self.GetItemData( self.selected_item )
 
         moderationString = None
@@ -356,26 +359,27 @@ class player_list(wxListCtrl):
 
         elif id == PLAYER_MODERATE_GIVE_VOICE:
             moderationString = (moderatePlayerBase % (playerID, "on"))
-            infoString = (infoPlayerBase % ("GIVE", chat.session.get_player_by_player_id( str(playerID) )[0], playerID))
+            infoString = (infoPlayerBase % ("GIVE", self.session.get_player_by_player_id( str(playerID) )[0], playerID))
 
         elif id == PLAYER_MODERATE_TAKE_VOICE:
             moderationString = (moderatePlayerBase % (playerID, "off"))
-            infoString = (infoPlayerBase % ("TAKE", chat.session.get_player_by_player_id( str(playerID) )[0], playerID))
+            infoString = (infoPlayerBase % ("TAKE", self.session.get_player_by_player_id( str(playerID) )[0], playerID))
 
         # Now, send it to the server
         if moderationString:
-            chat.chat_cmds.docmd( moderationString )
+            self.chat.chat_cmds.docmd( moderationString )
 
             # Now, provide local feedback as to what we requested
-            chat.InfoPost( infoString )
+            self.chat.InfoPost( infoString )
 
 
 
     def on_menu_role_change( self, evt ):
+        self.session = self.openrpg.get_component("session")
         "Change the role of the selected id."
 
         id = evt.GetId()
-        chat = self.myopenrpg.get_component( "chat" )
+        self.chat = self.openrpg.get_component( "chat" )
         playerID = self.GetItemData( self.selected_item )
 
         roleString = None
@@ -397,66 +401,63 @@ class player_list(wxListCtrl):
 
         # Now, send it to the server
         if roleString:
-            chat.chat_cmds.docmd( roleString )
+            self.chat.chat_cmds.docmd( roleString )
 
             # Now, provide local feedback as to what we requested
-            displayName = chat.session.get_player_by_player_id( str(playerID) )[0]
+            displayName = self.session.get_player_by_player_id( str(playerID) )[0]
             infoString = (infoBase % ( roleName, playerID, displayName ))
-            chat.InfoPost( infoString )
+            self.chat.InfoPost( infoString )
 
     def on_d_lclick(self,evt):
-        pos = wxPoint(evt.GetX(),evt.GetY())
+        pos = wx.Point(evt.GetX(),evt.GetY())
         (item, flag) = self.HitTest(pos)
         id = self.GetItemText(item)
-        chat = self.myopenrpg.get_component("chat")
-#        if wx.wxKeyEvent.ShiftDown():
-#            chat_text = chat.get_chat_text()
-#            print chat_text.find("/w")
-        chat.set_chat_text("/w " + id + "=")
+        self.chat = self.openrpg.get_component("chat")
+        self.chat.set_chat_text("/w " + id + "=")
 
     def on_menu_item(self,evt):
         id = evt.GetId()
-        session = self.myopenrpg.get_component("session")
-        password_manager = self.myopenrpg.get_component("password_manager")
+        self.session = self.openrpg.get_component("session")
+        self.password_manager = self.openrpg.get_component("password_manager")
 
         if id == PLAYER_BOOT:
             id = str(self.GetItemData(self.selected_item))
-            boot_pwd = password_manager.GetPassword("admin",int(session.group_id))
+            boot_pwd = self.password_manager.GetPassword("admin",int(self.session.group_id))
             if boot_pwd != None:
-                session.boot_player(id,boot_pwd)
+                self.session.boot_player(id,boot_pwd)
 
         elif id == PLAYER_WHISPER:
             id = self.GetItemText(self.selected_item)
-            chat = self.myopenrpg.get_component("chat")
-            chat.set_chat_text("/w " + id + "=")
+            self.chat = self.openrpg.get_component("chat")
+            self.chat.set_chat_text("/w " + id + "=")
 
         elif id == PLAYER_IGNORE:
             id = str(self.GetItemData(self.selected_item))
-            chat = self.myopenrpg.get_component("chat")
+            self.chat = self.openrpg.get_component("chat")
             (result,id,name) = session.toggle_ignore(id)
             if result == 0:
-                  chat.Post(chat.colorize(chat.syscolor, "Player " + name + " with ID:" + id +" no longer ignored"))
+                self.chat.Post(chat.colorize(chat.syscolor, "Player " + name + " with ID:" + id +" no longer ignored"))
             else:
-                  chat.Post(chat.colorize(chat.syscolor, "Player " + name + " with ID:" + id +" now being ignored"))
+                self.chat.Post(chat.colorize(chat.syscolor, "Player " + name + " with ID:" + id +" now being ignored"))
 
         elif id == PLAYER_SHOW_VERSION:
             id = str(self.GetItemData(self.selected_item))
-            version_string = session.players[id][4]
+            version_string = self.session.players[id][6]
             if version_string:
-                wxMessageBox("Running client version " + version_string,"Version")
+                wx.MessageBox("Running client version " + version_string,"Version")
             else:
-                wxMessageBox("No client version available for this player","Version")
+                wx.MessageBox("No client version available for this player","Version")
 
 
 
-    def on_menu(self,evt):
-        pos = wxPoint(evt.GetX(),evt.GetY())
+    def on_menu(self, evt):
+        pos = wx.Point(evt.GetX(),evt.GetY())
         (item, flag) = self.HitTest(pos)
         if item > -1:
             self.selected_item = item
 
             #  This if-else block makes the menu item to boot players active or inactive, as appropriate
-            if 0:     #self.myopenrpg.get_component("session").group_id == "0":
+            if 0:     #self.openrpg.get_component("session").group_id == "0":
                 self.menu.Enable(PLAYER_BOOT,0)
                 self.menu.SetLabel(PLAYER_BOOT,"Can't boot from Lobby")
             else:
@@ -465,26 +466,27 @@ class player_list(wxListCtrl):
 #---------------------------------------------------------
 # [START] Digitalxero Multi Whisper Group 1/1/05
 #---------------------------------------------------------
+            self.menu.Enable(PLAYER_WG_MENU, True)
             item = self.GetItem( self.selected_item )
 
             if len(WG_MENU_LIST) > len(WG_LIST):
                 self.clean_sub_menus()
 
             if len(WG_LIST) == 0:
-                self.wgMenu.Enable(PLAYER_WG_CLEAR_ALL, false)
+                self.wgMenu.Enable(PLAYER_WG_CLEAR_ALL, False)
             else:
-                self.wgMenu.Enable(PLAYER_WG_CLEAR_ALL, true)
+                self.wgMenu.Enable(PLAYER_WG_CLEAR_ALL, True)
 
 
             for gid in WG_LIST:
                 if not WG_MENU_LIST.has_key(gid):
                     WG_MENU_LIST[gid] = {}
-                    WG_MENU_LIST[gid]["menuid"] = wxNewId()
-                    WG_MENU_LIST[gid]["whisper"] = wxNewId()
-                    WG_MENU_LIST[gid]["add"] = wxNewId()
-                    WG_MENU_LIST[gid]["remove"] = wxNewId()
-                    WG_MENU_LIST[gid]["clear"] = wxNewId()
-                    WG_MENU_LIST[gid]["menu"] = wxMenu()
+                    WG_MENU_LIST[gid]["menuid"] = wx.NewId()
+                    WG_MENU_LIST[gid]["whisper"] = wx.NewId()
+                    WG_MENU_LIST[gid]["add"] = wx.NewId()
+                    WG_MENU_LIST[gid]["remove"] = wx.NewId()
+                    WG_MENU_LIST[gid]["clear"] = wx.NewId()
+                    WG_MENU_LIST[gid]["menu"] = wx.Menu()
 
                     WG_MENU_LIST[gid]["menu"].SetTitle(gid)
                     WG_MENU_LIST[gid]["menu"].Append(WG_MENU_LIST[gid]["whisper"], "Whisper")
@@ -494,24 +496,24 @@ class player_list(wxListCtrl):
                     self.wgMenu.PrependMenu(WG_MENU_LIST[gid]["menuid"], gid, WG_MENU_LIST[gid]["menu"])
 
                 if WG_LIST[gid].has_key(int(item.GetText())):
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["remove"], true)
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["add"], false)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["remove"], True)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["add"], False)
                 else:
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["remove"], false)
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["add"], true)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["remove"], False)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["add"], True)
 
                 if len(WG_LIST[gid]) == 0:
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["whisper"], false)
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["clear"], false)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["whisper"], False)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["clear"], False)
                 else:
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["whisper"], true)
-                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["clear"], true)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["whisper"], True)
+                    WG_MENU_LIST[gid]["menu"].Enable(WG_MENU_LIST[gid]["clear"], True)
 
                 #Event Stuff
-                EVT_MENU( self, WG_MENU_LIST[gid]["whisper"], self.on_menu_whispergroup )
-                EVT_MENU( self, WG_MENU_LIST[gid]["add"], self.on_menu_whispergroup )
-                EVT_MENU( self, WG_MENU_LIST[gid]["remove"], self.on_menu_whispergroup )
-                EVT_MENU( self, WG_MENU_LIST[gid]["clear"], self.on_menu_whispergroup )
+                self.Bind(wx.EVT_MENU, self.on_menu_whispergroup, id=WG_MENU_LIST[gid]["whisper"] )
+                self.Bind(wx.EVT_MENU, self.on_menu_whispergroup, id=WG_MENU_LIST[gid]["add"] )
+                self.Bind(wx.EVT_MENU, self.on_menu_whispergroup, id=WG_MENU_LIST[gid]["remove"] )
+                self.Bind(wx.EVT_MENU, self.on_menu_whispergroup, id=WG_MENU_LIST[gid]["clear"] )
 #---------------------------------------------------------
 # [END] Digitalxero Multi Whisper Group 1/1/05
 #---------------------------------------------------------
@@ -523,15 +525,16 @@ class player_list(wxListCtrl):
         i = self.InsertImageStringItem(0,player[2],0)
         self.SetStringItem(i,1,self.strip_html(player))
         self.SetItemData(i,int(player[2]))
-        self.SetStringItem (i, 2,player[3])
+        self.SetStringItem(i, 2,player[3])
         self.colorize_player_list()
         self.Refresh()
 
         # play sound
-        setobj = self.myopenrpg.get_component('settings')
+        setobj = self.openrpg.get_component('settings')
         sound_file = setobj.get_setting("AddSound")
-        sound_player = orpg.tools.orpg_sound.orpg_sound(setobj.get_setting("UnixSoundPlayer"));
-        sound_player.play(sound_file)
+        if sound_file != '':
+            sound_player = self.openrpg.get_component('sound')
+            sound_player.play(sound_file)
 
 
     def del_player(self,player):
@@ -549,10 +552,11 @@ class player_list(wxListCtrl):
 #---------------------------------------------------------
 
         # play sound
-        setobj = self.myopenrpg.get_component('settings')
+        setobj = self.openrpg.get_component('settings')
         sound_file = setobj.get_setting("DelSound")
-        sound_player = orpg.tools.orpg_sound.orpg_sound(setobj.get_setting("UnixSoundPlayer"));
-        sound_player.play(sound_file)
+        if sound_file != '':
+            sound_player = self.openrpg.get_component('sound')
+            sound_player.play(sound_file)
 
         ic = self.GetItemCount()
         self.whisperCount = 0
@@ -581,8 +585,8 @@ class player_list(wxListCtrl):
         self.Refresh()
 
     def colorize_player_list(self):
-        session = self.myopenrpg.get_component("session")
-        settings = self.myopenrpg.get_component('settings')
+        session = self.openrpg.get_component("session")
+        settings = self.openrpg.get_component('settings')
         mode = settings.get_setting("ColorizeRoles")
         if mode.lower() == "off":
             return
@@ -594,13 +598,13 @@ class player_list(wxListCtrl):
             player_info = session.get_player_by_player_id(m)
             item = self.GetItem(item_list_location)
             role = player_info[7].lower()
-            color = wxGREEN
+            color = wx.GREEN
             if role == "lurker":
-                color = wxColour(red=160,green=160,blue=160)
+                color = wx.Colour(red=160,green=160,blue=160)
             elif role == "player":
-                color = wxBLACK
+                color = wx.BLACK
             elif role == "gm":
-                color = wxRED
+                color = wx.RED
             if self.session.group_id != "0":
                 item.SetTextColour(color)
             self.SetItem(item)
@@ -645,4 +649,3 @@ class player_list(wxListCtrl):
 ##        self.SetColumnWidth( 1, w*2 )
 ##        self.SetColumnWidth( 2, w*3 )
         pass
-
