@@ -1,6 +1,6 @@
 # Copyright (C) 2000-2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#       openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 # Author: Todd "Snowdog" Faris
 # Maintainer:
 # Version:
-#   $Id: passtool.py,v 1.2 2004/06/20 04:58:52 tdb30_ Exp $
+#   $Id: passtool.py,v 1.9 2006/11/04 21:24:22 digitalxero Exp $
 #
 # Description: password helper. remembers passwords so user
 #              doesn't have to type passwords over and over
@@ -30,7 +30,7 @@ import orpg.orpg_windows
 import traceback
 
 #####################
-## Password Assistant 
+## Password Assistant
 #####################
 class PassSet:
     "set of passwords for a given room id on a server"
@@ -41,15 +41,20 @@ class PassSet:
         #room password
         self.room = None
 
-        
-        
+
+
 class PassTool:
     "Password Management System"
-    def __init__(self):
+    def __init__(self, openrpg):
+        self.openrpg = openrpg
+        self.settings = self.openrpg.get_component("settings")
         #server admin password
-        self.server = None 
+        self.server = None
         self.groups = {}
-        self.enabled = 0 #off by default
+        if self.settings.get_setting('PWMannager') == 'On':
+            self.enabled = 1
+        else:
+            self.enabled = 0
 
 
     def DumpPasswords(self):
@@ -59,7 +64,7 @@ class PassTool:
             ad = self.groups[c].admin
             rm = self.groups[c].room
             print( " #"+str(c)+"  R:\""+str(rm)+"\"  A:\""+str(ad)+"\"")
-        
+
     def ClearPassword( self, type="ALL", groupid=0):
         if type == "ALL" and groupid == 0:
             self.server = None
@@ -74,20 +79,20 @@ class PassTool:
         else: pass
 
     def QueryUser(self,info_string):
-        pwd_dialog = orpg.orpg_windows.wxTextEntryDialog(None,info_string,"Password Required")
-        if pwd_dialog.ShowModal() == orpg.orpg_windows.wxID_OK:
+        pwd_dialog = orpg.orpg_windows.wx.TextEntryDialog(None,info_string,"Password Required")
+        if pwd_dialog.ShowModal() == orpg.orpg_windows.wx.ID_OK:
             pwd_dialog.Destroy()
             return str(pwd_dialog.GetValue())
         else:
             pwd_dialog.Destroy()
             return None
-        
+
     def CheckGroupData(self, id ):
         try: #see if group exists
             group=self.groups[ int(id) ]
         except: #group doesn't exist... create it
-            self.groups[ int(id) ] = PassSet() 
-        
+            self.groups[ int(id) ] = PassSet()
+
     def RemoveGroupData(self, id ):
         try:
             #if PassSet exists for group remove it.
@@ -110,10 +115,10 @@ class PassTool:
         except:
             traceback.print_exc()
             #return None
-    
+
     def GetPassword(self, type="room", groupid=0):
         if self.Is_Enabled():
-            self.CheckGroupData( groupid )   
+            self.CheckGroupData( groupid )
             if type == "admin": return self.AdminPass(int(groupid))
             elif type == "room": return self.RoomPass(int(groupid))
             elif type == "server": return self.ServerPass()
@@ -126,7 +131,7 @@ class PassTool:
             elif type == "server": return self.QueryUser( "Enter Server Administrator Password" )
             else:
                 querystring = "Enter password for \""+str(type)+"\""
-                return self.QueryUser( querystring )     
+                return self.QueryUser( querystring )
 
 
     def Is_Enabled(self):
@@ -134,9 +139,11 @@ class PassTool:
 
     def Enable(self):
         self.enabled = 1
+        self.settings.set_setting('PWMannager', 'On')
 
     def Disable(self):
         self.enabled = 0
+        self.settings.set_setting('PWMannager', 'Off')
 
 
     def AdminPass( self, groupid ):
@@ -160,7 +167,7 @@ class PassTool:
         else:
             self.server = self.QueryUser("Please enter the Server Administrator password:")
             return str(self.server)
-        
+
     def FailPassword( self, type="room", groupid=0):
         self.CheckGroupData( groupid )
         if type == "admin":
