@@ -1,6 +1,6 @@
 # Copyright (C) 2001 The OpenRPG Project
 #
-#	openrpg-dev@lists.sourceforge.net
+#   openrpg-dev@lists.sourceforge.net
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 # Maintainer: Andrew Bennett
 # Version:  $id:$
 #
-# Description: This file contains an extension to the wxPython wxTextCtrl that provides predictive word completion
+# Description: This file contains an extension to the wxPython wx.TextCtrl that provides predictive word completion
 #              based on a word file loaded at instantiation.  Also, it learns new words as you type, dynamically
 #              adjusting a weight for each word based on how often you type it.
 #
@@ -32,7 +32,6 @@
 ##
 
 import string
-from wxPython.wx import *
 from orpg.orpg_windows import *
 
 #  This line added to test CVS commit
@@ -121,7 +120,7 @@ class LetterTree:
     # self : instance of self
     # wordText : string representing word to add
     # priority : integer priority to set the word
-    # sumFlag : if true, add the priority to the existing, else assign the priority
+    # sumFlag : if True, add the priority to the existing, else assign the priority
     #
     # Returns:  None
     #
@@ -133,16 +132,16 @@ class LetterTree:
         for ch in wordText:                     # for each character in the word
             if cur.children.has_key(ch):        # check to see if we've found a new word
 
-              cur = cur.children[ch]            # if we haven't found a new word, move to the next letter and try again
+                cur = cur.children[ch]            # if we haven't found a new word, move to the next letter and try again
 
             else:                               # in this clause, we're creating a new branch, as the word is new
-              newLetter = Letter(ch,cur)        # create a new class Letter using this ascii code and the current letter as a parent
+                newLetter = Letter(ch,cur)        # create a new class Letter using this ascii code and the current letter as a parent
 
-              if cur is self.rootNode:          # special case:  Others expect the top level letters to point to None, not self.rootNode
-                  newLetter.parentNode = None
+                if cur is self.rootNode:          # special case:  Others expect the top level letters to point to None, not self.rootNode
+                    newLetter.parentNode = None
 
-              cur.children[ch] = newLetter      #  add the new letter to the list of children of the current letter
-              cur = newLetter                   #  make the new letter the current one for the next time through
+                cur.children[ch] = newLetter      #  add the new letter to the list of children of the current letter
+                cur = newLetter                   #  make the new letter the current one for the next time through
 
         #  at this point, cur is pointing to the last letter of either a new or existing word.
 
@@ -279,17 +278,17 @@ class LetterTree:
 
 
 
-# This class extends wxTextCtrl
+# This class extends wx.TextCtrl
 #
-# Extends:  wxTextCtrl
+# Extends:  wx.TextCtrl
 #
 # Overrides:
-#    wxTextCtrl.__init__(self,parent,id,value,size,style,name)
-#    wxTextCtrl.OnChar(self,Event)
+#    wx.TextCtrl.__init__(self,parent,id,value,size,style,name)
+#    wx.TextCtrl.OnChar(self,Event)
 #
 # Defines:
 #    findWord(self,insert,st)
-class predTextCtrl(orpgTextCtrl):
+class predTextCtrl(wx.TextCtrl):
 
     # Initialization subroutine.
     #
@@ -297,26 +296,29 @@ class predTextCtrl(orpgTextCtrl):
     # parent:  reference to parent window (wxWindow, me-thinks)
     # id:      new Window Id, default to -1 to create new (I think: see docs for wxPython)
     # value:   String that is the initial value the control holds, defaulting to ""
-    # size:    defaults to wxDefaultSize
+    # size:    defaults to wx.DefaultSize
     # style:   defaults to 0
     # name:    defaults to "text"
-    # keyHook: must be a function pointer that takes self and a KeyCode object
+    # keyHook: must be a function pointer that takes self and a GetKeyCode object
     # validator: defaults to None
     #
-    # Note:  These parameters are essentially just passed back to the native wxTextCtrl.
+    # Note:  These parameters are essentially just passed back to the native wx.TextCtrl.
     #        I basically just included (stole) enough of them from chatutils.py to make
     #        it work.  Known missing args are pos and validator, which aren't used by
     #        chatutils.py.
     #
     # Returns:  None
     #
-    # Purpose:  Constructor for predTextCtrl.  Calls wxTextCtrl.__init__ to get default init
+    # Purpose:  Constructor for predTextCtrl.  Calls wx.TextCtrl.__init__ to get default init
     #           behavior and then inits a LetterTree and captures the parent for later use in
     #           passing events up the chain.
-    def __init__(self, parent, id = -1, value = "" , size = wxDefaultSize, style = 0, name = "text",keyHook = None, validator=None):
+    def __init__(self, parent, id = -1, value = "" , size = wx.DefaultSize, style = 0, name = "text",keyHook = None, validator=None):
 
         #  Call super() for default behavior
-        orpgTextCtrl.__init__(self,parent,id = id,value = value,size = size,style = style,name = name, validator = validator )
+        if validator:
+            wx.TextCtrl.__init__(self, parent, id=id, value=value, size=size, style=style, name=name, validator=validator )
+        else:
+            wx.TextCtrl.__init__(self, parent, id=id, value=value, size=size, style=style, name=name)
 
         self.tree = LetterTree("defaultwordlist.txt")      #  Instantiate a new LetterTree.
         #  TODO:  make name of word file an argument.
@@ -368,7 +370,7 @@ class predTextCtrl(orpgTextCtrl):
     # OnChar subroutine.
     #
     # self :  instance of self
-    # event:  a KeyCode object
+    # event:  a GetKeyCode object
     #
     # Returns:  None
     #
@@ -380,21 +382,21 @@ class predTextCtrl(orpgTextCtrl):
         #    This is currently used to implement the typing/not_typing messages in a manner that
         #         doesn't place the code here.  Maybe I should reconsider that.  :)
         if(self.keyHook):
-          if self.keyHook(event) == 1:   #  if the passed in keyHook routine returns a one, it wants no predictive behavior
-              self.parent.OnChar(event)
-              return
+            if self.keyHook(event) == 1:   #  if the passed in keyHook routine returns a one, it wants no predictive behavior
+                self.parent.OnChar(event)
+                return
 
 
 
-        #  This bit converts the KeyCode() return (int) to a char if it's in a certain range
+        #  This bit converts the GetKeyCode() return (int) to a char if it's in a certain range
         asciiKey = ""
-        if (event.KeyCode() < 256) and (event.KeyCode() > 19):
-            asciiKey = chr(event.KeyCode())
+        if (event.GetKeyCode() < 256) and (event.GetKeyCode() > 19):
+            asciiKey = chr(event.GetKeyCode())
 
 
-        if asciiKey == "":                                 #  If we didn't convert it to a char, then process based on the int KeyCodes
+        if asciiKey == "":                                 #  If we didn't convert it to a char, then process based on the int GetKeyCodes
 
-            if  event.KeyCode() == WXK_TAB:                #  We want to hook tabs to allow the user to signify acceptance of a
+            if  event.GetKeyCode() == wx.WXK_TAB:                #  We want to hook tabs to allow the user to signify acceptance of a
                                                            #  predicted word.
                 #  Handle Tab key
 
@@ -416,7 +418,7 @@ class predTextCtrl(orpgTextCtrl):
 
                     return                                 #  Don't pass tab on in this case
 
-            elif event.KeyCode() == WXK_RETURN:            #  We want to hook returns, so that we can update the word list
+            elif event.GetKeyCode() == wx.WXK_RETURN:            #  We want to hook returns, so that we can update the word list
 
                 st = self.GetValue()                       #  Grab the text from the control
                 newSt = ""                                 #  Init a buffer
@@ -434,7 +436,7 @@ class predTextCtrl(orpgTextCtrl):
                 # back = st[endSel:]                                      #  Slice off the text to the end from where we are
                 # st = front + back                          #  This expression creates a string that get rid of any selected text.
                 # self.SetValue(st)
-                
+
                 self.Remove( startSel, endSel )
                 st = string.strip( self.GetValue() )
                 #
@@ -464,14 +466,14 @@ class predTextCtrl(orpgTextCtrl):
             #  out of a selection.  I set the InsertionPoint to the beginning of the selection.  When the default
             #  right arrow event occurs, the selection goes away, but the cursor is in an unexpected location.
             #  This snippet fixes this behavior and then passes on the event.
-            elif event.KeyCode() == WXK_RIGHT:
+            elif event.GetKeyCode() == wx.WXK_RIGHT:
                 (startSel,endSel) = self.GetSelection()
                 self.SetInsertionPoint(endSel)
                 self.parent.OnChar(event)
                 return
 
-            #  Ditto as WXK_RIGHT, but for completeness sake
-            elif event.KeyCode() == WXK_LEFT:
+            #  Ditto as wx.WXK_RIGHT, but for completeness sake
+            elif event.GetKeyCode() == wx.WXK_LEFT:
                 (startSel,endSel) = self.GetSelection()
                 self.SetInsertionPoint(startSel)
                 self.parent.OnChar(event)
@@ -486,7 +488,7 @@ class predTextCtrl(orpgTextCtrl):
 
         elif asciiKey in string.letters:
            #  This is the real meat and potatoes of predTextCtrl.  This is where most of the
-           #  wxTextCtrl logic is changed.
+           #  wx.TextCtrl logic is changed.
 
             (startSel,endSel) = self.GetSelection()                 #  get the curren selection
             st = self.GetValue()                                    #  and the text in the control
@@ -592,4 +594,4 @@ class predTextCtrl(orpgTextCtrl):
             self.parent.OnChar(event)     #Call super.OnChar to get default behavior
             return
 
-#  End of class predTextCtrl!
+#  End of class predTextCtrl!
\ No newline at end of file
