@@ -21,16 +21,17 @@
 # Author: Ted Berg
 # Maintainer:
 # Version:
-#   $Id: scriptkit.py,v 1.5 2005/06/12 03:47:41 digitalxero Exp $
+#   $Id: scriptkit.py,v 1.15 2006/11/04 21:24:22 digitalxero Exp $
 #
 # Description: Class that contains convenience methods for various operations.  Was created with the purpose
-#	of exposing a simple API to users of an as yet uncreated scripting interface.
+#       of exposing a simple API to users of an as yet uncreated scripting interface.
 #
 
 
 import time
 from orpg.orpg_windows import *
 from orpg.orpg_xml import *
+from orpg.orpg_wx import *
 import orpg.chat.chat_msg
 
 class scriptkit:
@@ -48,15 +49,16 @@ class scriptkit:
         self.map = self.__openrpg.get_component( 'map' )
         self.settings = self.__openrpg.get_component( 'settings' )
         self.session = self.__openrpg.get_component('session')
+        self.xml = self.__openrpg.get_component('xml')
 
     def addMiniatureToMap( self, min_label, min_url, unique=0 ):
         """Adds a new miniature icon to the map.  Miniature <em>will</em> be labeled unless autolabel is
         turned off on the map <em>and</em> the min_label field is blank.  Miniature will be numbered unless
-        the 'unique' argument evaluates to true ( i.e. nonzero or a non-empty string ).
+        the 'unique' argument evaluates to True ( i.e. nonzero or a non-empty string ).
         <ul>
             <li>min_label - text string to be used as a label for the miniature
             <li>min_url - the URL for the image to be displayed on the map
-            <li>unique - the mini will be numbered if this evaluates to false.
+            <li>unique - the mini will be numbered if this evaluates to False.
         </ul>
         """
 
@@ -78,21 +80,22 @@ class scriptkit:
         self.map.canvas.add_miniature( min_url, label, unique )
 
     def become( self, name ):
-        self.sendToChat( '/name '+name )
+        try:
+            self.chat.aliasList.SetStringSelection(name)
+        except:
+            msg = 'Alias: %s Does not exist' % (name)
+            print msg
 
-    def sendToChat( self, text, name=false ):
+    def sendToChat( self, text ):
         """Broadcasts the specified text to the chatbuffer.
         <ul>
             <li>text - the text to send.
         </ul>
         """
-        # chat = self.__openrpg.get_component( 'chat' )
-        if len( text ) == 0:
-            return
-        if text[0] == '/':
-            self.chat.chat_cmds.docmd( text )
+        if text[0] != "/":
+            self.chat.ParsePost(text, send=1, myself=1)
         else:
-            self.chat.ParsePost( self.chat.colorize( self.chat.mytextcolor, text ), send=1, myself=1, alias=name )
+            self.chat.chat_cmds.docmd(text)
 
     def sendToChatAs( self, name, text ):
         """Broadcasts the specified text to the chatbuffer as the specified alias
@@ -101,46 +104,44 @@ class scriptkit:
             <li>text - The text to broadcast to the chatbuffer
         </ul>
         """
-        chat_cmds = self.chat.chat_cmds
-        msg = orpg.chat.chat_msg.chat_msg()
-        playername = self.settings.get_setting( 'player' )
-        self.become( name )
-        self.sendToChat( text, name )
-        self.become( playername )
+        self.become(name)
+        self.sendToChat( text )
+        self.become("Use Real Name")
 
-    def emoteToChat( self, text, alias=false ):
+    def emoteToChat( self, text):
         if text[0] != '/':
             text = '/me ' + text
-        self.sendToChat( text, name=alias )
+        self.sendToChat( text )
 
     def emoteToChatAs( self, name, text ):
-        playername = self.settings.get_setting( 'player' )
-        self.become( name )
-        self.emoteToChat( text, name )
-        self.become( playername )
+        text = '/me ' + text
+        self.become(name)
+        self.sendToChat( text )
+        self.become("Use Real Name")
 
-    def whisperToChat( self, who, text, alias=false ):
+    def whisperToChat( self, who, text):
         if text[0] != '/':
             text = '/w %s=%s' % ( who, text )
-        self.sendToChat( text, name=alias )
+        self.sendToChat( text )
 
-    def whisperToChatAs( self, who, alias, text ):
-        playername = self.settings.get_setting( 'player' )
-        self.become( alias )
-        self.whisperToChat( who, text, name )
-        self.become( playername )
+    def whisperToChatAs( self, who, name, text ):
+        if text[0] != '/':
+            text = '/w %s=%s' % ( who, text )
+        self.become(name)
+        self.sendToChat( text )
+        self.become("Use Real Name")
 
     def chatMessage( self, message ):
         self.chat.Post( self.chat.colorize( self.chat.syscolor, message ) )
 
     def get_input( self, message, title, default ):
-        dlg = rpgutils.wxTextEntryDialog( self, message, title, default )
-        if dlg.ShowModal() == rpgutils.wxID_OK:
+        dlg = wx.TextEntryDialog( self, message, title, default )
+        if dlg.ShowModal() == rpgutils.wx.ID_OK:
             return dlg.GetValue()
         dlg.Destroy()
         return None
 
     def show_info( self, title, message ):
-        dlg.rpgutils.wxMessageDialog( None, message, title, rpgutils.wxOK | rpgutils.wxICON_INFORMATION )
+        dlg = wx.MessageDialog( None, message, title, wx.OK | wx.ICON_INFORMATION )
         dlg.ShowModal()
         dlg.Destroy()
