@@ -63,13 +63,15 @@ if __name__ == '__main__':
         opt = raw_input("Do you want to post your server to the OpenRPG Meta Server list? (y,n)")
         if opt[0] == 'y' or opt[0] == 'Y':
             post = 'Y'
-            
+
     # If we are going to post make sure we have a server name, if not, ask for it
     if ( post == 'Y' ) and (len(name) == 0 ):
         name = raw_input("Server Name?")
     # start server!
     orpg_server = orpg.networking.mplay_server.mplay_server()
     orpg_server.force_check = 1
+    orpg_server.remoteadmin = 1
+
     for index in range(len(sys.argv)-1):
         if (sys.argv[index] == "-v"):
             orpg_server.force_check=0
@@ -83,8 +85,9 @@ if __name__ == '__main__':
     print "-----------------------------------------------------"
     #orpg_server.print_help()
     orpg_server.groups['0'].boot_pwd = lobby_boot_pwd
-    
+
     opt = "None"
+    orpg_server.console_log()
     try:
         while (opt != "kill") and ( opt != "quit"):
             opt = raw_input("action?:")
@@ -119,9 +122,14 @@ if __name__ == '__main__':
                 print "You might consider going to that room and letting them know what you are about to do."
                 groupnumber = raw_input("Room group number:")
                 orpg_server.remove_room(groupnumber)
-            elif opt == "uptime": 
+            elif opt == "remotekill":
+                if orpg_server.toggleRemoteKill():
+                    print "Remote Kill has been allowed!"
+                else:
+                    print "Remote Kill has been disallowed"
+            elif opt == "uptime":
                 orpg_server.uptime()
-            elif opt == "roompasswords": 
+            elif opt == "roompasswords":
                 print orpg_server.RoomPasswords()
             elif opt == "list":
                 orpg_server.player_list()
@@ -138,7 +146,7 @@ if __name__ == '__main__':
                     elif words[1] == "split":
                         orpg_server.NetworkLogging(2)
                     else:
-                        print "<command useage> logfile [off|on|split]" 
+                        print "<command useage> logfile [off|on|split]"
                 else:
                     print orpg_server.NetworkLoggingStatus()
             elif (len(words) > 0 and words[0]) == "monitor":
@@ -174,16 +182,28 @@ if __name__ == '__main__':
                 kick_id = raw_input("Kick Player #  ")
                 kick_msg = raw_input("Reason(optional):  ")
                 orpg_server.admin_kick(kick_id,kick_msg)
+            elif opt == "ban":
+                ban_id = raw_input("Ban Player #  ")
+                ban_msg = raw_input("Reason(optional):  ")
+                orpg_server.admin_ban(ban_id, ban_msg)
+            elif opt == "sendsize":
+                send_len = raw_input("Send Size #  ")
+                orpg_server.admin_setSendSize(send_len)
+            elif opt == "remoteadmin":
+                if orpg_server.toggleRemoteAdmin():
+                    print "Remote Admin has been allowed!"
+                else:
+                    print "Remote Admin has been disallowed"
             else:
                 if (opt == "kill") or (opt == "quit"):
-                    print ("Closing down OpenRPG server. Please wait...") 
+                    orpg_server.saveBanList()
+                    print ("Closing down OpenRPG server. Please wait...")
                 else:
                     print ("[UNKNOWN COMMAND: \""+opt+"\" ]")
-                
+
     except Exception, e:
         print "EXCEPTION: "+str(e)
         traceback.print_exc()
         raw_input("press <enter> key to terminate program")
 
     orpg_server.kill_server()
-
