@@ -1,17 +1,15 @@
 import sys
 import time
 import platform
-try:
-    from wxPython.wx import *
-except ImportError:
-    print "\n\nImporting wxPython Failed! You must install wxPython for OpenRPG to run"
-    print "Download the latest version here: http://www.openrpg.com/orpgnuke/modules.php?name=GetORPG"
+import wx
+import orpg.orpg_version
 
 class system_check:
 
     def start(self,log_file='openrpg_sysinfo.txt'):
         self.log_file = open(log_file,'w')
-        self.log_file.write("OpenRPG System Info " + time.strftime( '%d-%m-%y', time.localtime( time.time() ) ))
+        self.log_file.write("OpenRPG System Info " + time.strftime( '%m-%d-%y', time.localtime( time.time() ) ))
+        self.check_openrpg()
         self.check_py()
         self.check_wxpython()
         self.check_platform()
@@ -26,6 +24,11 @@ class system_check:
     def check_platform(self):
         self.log_file.write("\nPlatform: " + platform.platform())
 
+    def check_openrpg(self):
+        self.log_file.write("\nOpenRPG Version: " + orpg.orpg_version.VERSION)
+        self.log_file.write("\nOpenRPG Build: " + orpg.orpg_version.BUILD)
+
+
 
 if __name__ == "__main__":
     syscheck = system_check()
